@@ -54,6 +54,12 @@ public class CalcEngineConfig
      */
     public static final String PROP_SIMULATOR = PROP_PREFIX+".simulator";
 
+    //-------------------------------------------------------------------------
+    /** enable/disable the performance tests on top of any real mode
+     *  set it to TRUE or FALSE.
+     */
+    public static final String PROP_PERFORMANCE_TESTS = PROP_PREFIX+".performance-tests";
+
     //-------------------------------------------------------------------------
     public static final String PROP_REQUEST_TIMEOUT = PROP_PREFIX+".request.timeout";
     
@@ -176,6 +182,26 @@ public class CalcEngineConfig
         return false;
     }
 
+    //-------------------------------------------------------------------------
+    public boolean isPerformanceMeasurementOn ()
+        throws Exception
+    {
+        try
+        {
+            final String  sMode = mem_CfgSrv ().getProperty(PROP_PERFORMANCE_TESTS);
+        	final boolean bMode = Boolean.parseBoolean(sMode);
+        	return bMode;
+        }
+        catch (Throwable ex)
+        {
+        	// NO LOGGING - NO HANDLING !
+        	// This value is a 'hidden feature' useful for development and QA only.
+        	// Don't disturb official product ...
+        }
+
+        return false;
+    }
+
     //-------------------------------------------------------------------------
     public int getRequestTimeout ()
         throws Exception
