@@ -8,7 +8,7 @@
  *
  *    In some countries OX, OX Open-Xchange, open xchange and OXtender
  *    as well as the corresponding Logos OX Open-Xchange and OX are registered
- *    trademarks of the Open-Xchange, Inc. group of companies.
+ *    trademarks.
  *    The use of the Logos is not covered by the GNU General Public License.
  *    Instead, you are allowed to use these Logos according to the terms and
  *    conditions of the Creative Commons License, Version 2.5, Attribution,
@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2012 Open-Xchange, Inc.
+ *     Copyright (C) 2016 OX Software GmbH
  *     Mail: info@open-xchange.com
  *
  *
@@ -88,7 +88,7 @@ public class CalcEngineClientNative implements ICalcEngineClient
 
     //-------------------------------------------------------------------------
     @Override
-    public String createDocument()
+    public /*no synchronized*/ String createDocument()
         throws Exception
     {
         final String                  sHandle = CalcEngineHandleGenerator.newHandle();
@@ -103,7 +103,7 @@ public class CalcEngineClientNative implements ICalcEngineClient
     
     //-------------------------------------------------------------------------
     @Override
-    public void destroyDocument(final String sHandle)
+    public /*no synchronized*/ void destroyDocument(final String sHandle)
         throws Exception
     {
         Validate.isTrue(CalcEngineHandleGenerator.validateHandle(sHandle), "'"+sHandle+"' is an invalid handle.");
@@ -125,9 +125,9 @@ public class CalcEngineClientNative implements ICalcEngineClient
 
     //-------------------------------------------------------------------------
     @Override
-    public ECalcEngineError executeOperation(final String       sHandle       ,
-                                   			 final String       sOperationJSON,
-                                   			 final StringBuffer sResultJSON   )
+    public /*no synchronized*/ ECalcEngineError executeOperation(final String       sHandle       ,
+                                   			                     final String       sOperationJSON,
+                                   			                     final StringBuffer sResultJSON   )
         throws Exception
     {
         Validate.isTrue(CalcEngineHandleGenerator.validateHandle(sHandle), "'"+sHandle+"' is an invalid handle.");
@@ -141,7 +141,7 @@ public class CalcEngineClientNative implements ICalcEngineClient
         }
 
         final CalcEngineNativeWrapper aEngine = mem_Engine ();
-        final String sResult     = aEngine.executeOperation(sHandle, sOperationJSON);
+        final String                  sResult = aEngine.executeOperation(sHandle, sOperationJSON);
         
         if (sResult.isEmpty())
         	impl_logAndThrowError ("Execute operation on calc engine document '"+sHandle+"' failed.");
@@ -154,8 +154,8 @@ public class CalcEngineClientNative implements ICalcEngineClient
     
     //-------------------------------------------------------------------------
     @Override
-    public ECalcEngineError restoreDocument (final String    sHandle             ,
-			 				                 final String... lPagedOperationJSONs)
+    public /*no synchronized*/ ECalcEngineError restoreDocument (final String    sHandle             ,
+			 				                                     final String... lPagedOperationJSONs)
         throws Exception
     {
         Validate.isTrue(CalcEngineHandleGenerator.validateHandle(sHandle), "'"+sHandle+"' is an invalid handle.");
@@ -195,8 +195,8 @@ public class CalcEngineClientNative implements ICalcEngineClient
     
     //-------------------------------------------------------------------------
 	@Override
-	public ECalcEngineError copy(final String                   sDocHandle,
-								 final CalcEngineClipBoardEvent aEvent    )
+	public /*no synchronized*/ ECalcEngineError copy(final String                   sDocHandle,
+								                     final CalcEngineClipBoardEvent aEvent    )
 		throws Exception
 	{
         Validate.isTrue(CalcEngineHandleGenerator.validateHandle(sDocHandle), "'"+sDocHandle+"' is an invalid handle.");
@@ -227,8 +227,8 @@ public class CalcEngineClientNative implements ICalcEngineClient
 
     //-------------------------------------------------------------------------
 	@Override
-	public ECalcEngineError paste(final String                   sDocHandle,
-								  final CalcEngineClipBoardEvent aEvent    )
+	public /*no synchronized*/ ECalcEngineError paste(final String                   sDocHandle,
+								                      final CalcEngineClipBoardEvent aEvent    )
 		throws Exception
 	{
         Validate.isTrue(CalcEngineHandleGenerator.validateHandle(sDocHandle), "'"+sDocHandle+"' is an invalid handle.");
@@ -259,7 +259,7 @@ public class CalcEngineClientNative implements ICalcEngineClient
 
     //-------------------------------------------------------------------------
     @Override
-    public String getVersion() 
+    public /*no synchronized*/ String getVersion() 
         throws Exception
     {
         final CalcEngineNativeWrapper aEngine  = mem_Engine ();
@@ -269,13 +269,21 @@ public class CalcEngineClientNative implements ICalcEngineClient
 
     //-------------------------------------------------------------------------
     @Override
-    public void setLogLevel (final ELogLevel eLevel) 
+    public /*no synchronized*/ void setLogLevel (final ELogLevel eLevel) 
     	throws Exception
     {
         final CalcEngineNativeWrapper aEngine  = mem_Engine ();
         aEngine.setLogLevel(eLevel);
     }
 
+    //-------------------------------------------------------------------------
+    @Override
+    public /*no synchronized*/ void dispose ()
+    	throws Exception
+    {
+    	// TODO
+    }
+
 	//-------------------------------------------------------------------------
     private boolean impl_isHandleKnown (final String sHandle)
        throws Exception
@@ -297,7 +305,7 @@ public class CalcEngineClientNative implements ICalcEngineClient
     }
     
     //-------------------------------------------------------------------------
-    private CalcEngineNativeWrapper mem_Engine ()
+    private synchronized CalcEngineNativeWrapper mem_Engine ()
        throws Exception
     {
         if (m_aEngine == null)
@@ -306,7 +314,7 @@ public class CalcEngineClientNative implements ICalcEngineClient
     }
     
     //-------------------------------------------------------------------------
-    private ContextAwareLogHelp mem_Log ()
+    private synchronized ContextAwareLogHelp mem_Log ()
         throws Exception
     {
     	if (m_aContextLog == null)
