@@ -8,7 +8,7 @@
  *
  *    In some countries OX, OX Open-Xchange, open xchange and OXtender
  *    as well as the corresponding Logos OX Open-Xchange and OX are registered
- *    trademarks of the Open-Xchange, Inc. group of companies.
+ *    trademarks.
  *    The use of the Logos is not covered by the GNU General Public License.
  *    Instead, you are allowed to use these Logos according to the terms and
  *    conditions of the Creative Commons License, Version 2.5, Attribution,
@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2012 Open-Xchange, Inc.
+ *     Copyright (C) 2016 OX Software GmbH
  *     Mail: info@open-xchange.com
  *
  *
@@ -98,7 +98,7 @@ public class CalcEngineServlet
     
     //-------------------------------------------------------------------------
     @GET
-    public Response createDocument()
+    public /*no synchronized*/ Response createDocument()
         throws Exception
     {
         try
@@ -119,7 +119,7 @@ public class CalcEngineServlet
     //-------------------------------------------------------------------------
     @DELETE
     @Path("{handle}")
-    public Response destroyDocument(@PathParam("handle") final String sHandle)
+    public /*no synchronized*/ Response destroyDocument(@PathParam("handle") final String sHandle)
         throws Exception
     {
     	try
@@ -145,8 +145,8 @@ public class CalcEngineServlet
     //-------------------------------------------------------------------------
     @POST
     @Path("{handle}/"+CalcEngineConst.RELPATH_EXECUTE)
-    public Response executeOperation(@PathParam("handle") final String sHandle,
-                                                          final String sOpJSON)
+    public /*no synchronized*/ Response executeOperation(@PathParam("handle") final String sHandle,
+                                                                              final String sOpJSON)
         throws Exception
     {
     	try
@@ -183,8 +183,8 @@ public class CalcEngineServlet
     //-------------------------------------------------------------------------
     @POST
     @Path("{handle}/"+CalcEngineConst.RELPATH_RESTORE)
-    public Response restoreDocument(@PathParam("handle") final String sHandle,
-                                                         final String sOpJSON)
+    public /*no synchronized*/ Response restoreDocument(@PathParam("handle") final String sHandle,
+                                                                             final String sOpJSON)
         throws Exception
     {
     	try
@@ -219,8 +219,8 @@ public class CalcEngineServlet
     //-------------------------------------------------------------------------
     @POST
     @Path("{handle}/"+CalcEngineConst.RELPATH_COPY)
-    public Response copy(@PathParam("handle") final String               sHandle,
-                                              final CalcEngineHttpEntity aEntity)
+    public /*no synchronized*/ Response copy(@PathParam("handle") final String               sHandle,
+                                                                  final CalcEngineHttpEntity aEntity)
         throws Exception
     {
     	try
@@ -256,8 +256,8 @@ public class CalcEngineServlet
     //-------------------------------------------------------------------------
     @POST
     @Path("{handle}/"+CalcEngineConst.RELPATH_PASTE)
-    public Response paste(@PathParam("handle") final String               sHandle,
-                                               final CalcEngineHttpEntity aEntity)
+    public /*no synchronized*/ Response paste(@PathParam("handle") final String               sHandle,
+                                                                   final CalcEngineHttpEntity aEntity)
         throws Exception
     {
     	try
@@ -293,7 +293,7 @@ public class CalcEngineServlet
     //-------------------------------------------------------------------------
     @POST
     @Path(CalcEngineConst.RELPATH_SETLOGLEVEL)
-    public Response setLogLevel(final CalcEngineHttpEntity aEntity)
+    public /*no synchronized*/ Response setLogLevel(final CalcEngineHttpEntity aEntity)
         throws Exception
     {
     	try
@@ -319,7 +319,7 @@ public class CalcEngineServlet
     //-------------------------------------------------------------------------
     @POST
     @Path(CalcEngineConst.RELPATH_ISALIVE)
-    public Response isAlive()
+    public /*no synchronized*/ Response isAlive()
         throws Exception
     {
     	final ContextAwareLogHelp aLog = mem_Log ();
@@ -352,7 +352,7 @@ public class CalcEngineServlet
     //-------------------------------------------------------------------------
     @POST
     @Path(CalcEngineConst.RELPATH_SHUTDOWN)
-    public Response shutdown()
+    public /*no synchronized*/ Response shutdown()
         throws Exception
     {
     	final ContextAwareLogHelp aLog = mem_Log ();
@@ -413,7 +413,7 @@ public class CalcEngineServlet
     //-------------------------------------------------------------------------
     @POST
     @Path(CalcEngineConst.RELPATH_KILL)
-    public void kill()
+    public /*no synchronized*/ void kill()
         throws Exception
     {
     	// no logging
@@ -424,14 +424,14 @@ public class CalcEngineServlet
     }
 
     //-------------------------------------------------------------------------
-    public void setServerPort (final int nPort)
+    public synchronized void setServerPort (final int nPort)
         throws Exception
     {
     	m_nServerPort = nPort;
     }
     
     //-------------------------------------------------------------------------
-    private ICalcEngineClient mem_Impl ()
+    private synchronized ICalcEngineClient mem_Impl ()
         throws Exception
     {
         if (m_iImpl == null)
@@ -444,7 +444,7 @@ public class CalcEngineServlet
     }
 
     //-------------------------------------------------------------------------
-    private ContextAwareLogHelp mem_Log ()
+    private synchronized ContextAwareLogHelp mem_Log ()
         throws Exception
     {
         if (m_aLog == null)
