@@ -8,7 +8,7 @@
  *
  *    In some countries OX, OX Open-Xchange, open xchange and OXtender
  *    as well as the corresponding Logos OX Open-Xchange and OX are registered
- *    trademarks of the Open-Xchange, Inc. group of companies.
+ *    trademarks.
  *    The use of the Logos is not covered by the GNU General Public License.
  *    Instead, you are allowed to use these Logos according to the terms and
  *    conditions of the Creative Commons License, Version 2.5, Attribution,
@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2012 Open-Xchange, Inc.
+ *     Copyright (C) 2016 OX Software GmbH
  *     Mail: info@open-xchange.com
  *
  *
@@ -135,7 +135,6 @@ public class CalcEngineEnvActivator extends HousekeepingActivator
             impl_initCalcEngineConfig   ();
             impl_initCalcEngineFactory  ();
             impl_registerClasspathProtocolHandler (super.context);
-        	impl_initClusterNodeManager ();
 
             // analyze configuration ...
             // and setup a HTTP/JMS server environment if needed. 
@@ -170,8 +169,7 @@ public class CalcEngineEnvActivator extends HousekeepingActivator
     {
         LOG.info(LOGPREFIX+"deinitialize calc engine environment ...");
         
-        impl_deinitHTTPServerMode     ();
-        impl_deinitClusterNodeManager ();
+        impl_deinitHTTPServerMode ();
         
         LOG.info(LOGPREFIX+"OK.");                        
     }
@@ -293,34 +291,6 @@ public class CalcEngineEnvActivator extends HousekeepingActivator
     			                  lProps                                  );
     }
    
-    // -----------------------------------------------------------------------------------
-    private void impl_initClusterNodeManager ()
-    	throws Exception
-    {
-//        LOG.info (LOGPREFIX+"start calc engine server (JMS mode) ...");                        
-//
-//        final ClusterNodeManager aClusterMgr = ClusterNodeManager.get ();
-//        aClusterMgr.start();
-//        m_aClusterManager = aClusterMgr;
-//
-//        LOG.info (LOGPREFIX+"OK.");
-    }
-
-    // -----------------------------------------------------------------------------------
-    private void impl_deinitClusterNodeManager ()
-    	throws Exception
-    {
-//    	ClusterNodeManager aClusterMgr = m_aClusterManager;
-//    	m_aClusterManager = null;
-//    	
-//    	if (aClusterMgr != null)
-//    	{
-//            LOG.info (LOGPREFIX+"stop calc engine server (JMS mode) ...");                        
-//    		aClusterMgr.stop();
-//        	LOG.info (LOGPREFIX+"OK.");
-//    	}
-    }
-
 //    // -----------------------------------------------------------------------------------
 //    private void impl_test ()
 //        throws Exception
