@@ -1,19 +1,19 @@
 /*
-   Licensed to Plutext Pty Ltd under one or more contributor license agreements.  
-   
+   Licensed to Plutext Pty Ltd under one or more contributor license agreements.
+
  *  This file is part of docx4j.
 
-    docx4j is licensed under the Apache License, Version 2.0 (the "License"); 
-    you may not use this file except in compliance with the License. 
+    docx4j is licensed under the Apache License, Version 2.0 (the "License");
+    you may not use this file except in compliance with the License.
 
-    You may obtain a copy of the License at 
+    You may obtain a copy of the License at
 
-        http://www.apache.org/licenses/LICENSE-2.0 
+        http://www.apache.org/licenses/LICENSE-2.0
 
-    Unless required by applicable law or agreed to in writing, software 
-    distributed under the License is distributed on an "AS IS" BASIS, 
-    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. 
-    See the License for the specific language governing permissions and 
+    Unless required by applicable law or agreed to in writing, software
+    distributed under the License is distributed on an "AS IS" BASIS,
+    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+    See the License for the specific language governing permissions and
     limitations under the License.
 
  */
@@ -46,12 +46,9 @@ import org.docx4j.convert.out.fo.FOExporterVisitor;
 import org.docx4j.convert.out.fo.FOExporterXslt;
 import org.docx4j.convert.out.html.HTMLExporterVisitor;
 import org.docx4j.convert.out.html.HTMLExporterXslt;
-import org.docx4j.customXmlProperties.DatastoreItem;
-import org.docx4j.customXmlProperties.SchemaRefs.SchemaRef;
 import org.docx4j.jaxb.Context;
 import org.docx4j.jaxb.NamespacePrefixMapperUtils;
 import org.docx4j.model.datastorage.BindingHandler;
-import org.docx4j.model.datastorage.CustomXmlDataStorage;
 import org.docx4j.model.datastorage.CustomXmlDataStoragePartSelector;
 import org.docx4j.model.datastorage.OpenDoPEHandler;
 import org.docx4j.model.datastorage.RemovalHandler;
@@ -59,7 +56,6 @@ import org.docx4j.openpackaging.exceptions.Docx4JException;
 import org.docx4j.openpackaging.io.SaveToZipFile;
 import org.docx4j.openpackaging.packages.WordprocessingMLPackage;
 import org.docx4j.openpackaging.parts.CustomXmlDataStoragePart;
-import org.docx4j.openpackaging.parts.CustomXmlDataStoragePropertiesPart;
 import org.docx4j.openpackaging.parts.Part;
 import org.docx4j.openpackaging.parts.PartName;
 import org.docx4j.openpackaging.parts.WordprocessingML.FooterPart;
@@ -70,30 +66,29 @@ import org.docx4j.relationships.Relationship;
 import org.docx4j.utils.TraversalUtilVisitor;
 import org.docx4j.wml.SdtElement;
 import org.docx4j.wml.SdtPr;
-import org.opendope.xpaths.Xpaths.Xpath;
 import org.w3c.dom.Document;
 
 /** This is a facade for some typical uses of Docx4J:
  * <ul>
- * <li>Loading a document</li> 
- * <li>Saving a document</li> 
- * <li>Binding xml to content controls in a document</li> 
- * <li>Exporting the document (to HTML, or PDF and other formats supported by the FO renderer) </li> 
+ * <li>Loading a document</li>
+ * <li>Saving a document</li>
+ * <li>Binding xml to content controls in a document</li>
+ * <li>Exporting the document (to HTML, or PDF and other formats supported by the FO renderer) </li>
  * </ul>
- * 
+ *
  */
 public class Docx4J {
 	public static final String MIME_PDF = FOSettings.MIME_PDF;
 	public static final String MIME_FO = FOSettings.INTERNAL_FO_MIME;
-	
+
 	/** No flags passed, do the default
 	 */
 	public static final int FLAG_NONE = 0;
-	
+
 	/** If available export the document using a xsl transformation
 	 */
 	public static final int FLAG_EXPORT_PREFER_XSL = 1;
-	
+
 	/** If available export the document using a visitor
 	 */
 	public static final int FLAG_EXPORT_PREFER_NONXSL = 2;
@@ -101,46 +96,46 @@ public class Docx4J {
 	/** Save the document in a zip container (default docx)
 	 */
 	public static final int FLAG_SAVE_ZIP_FILE = 1;
-	
+
 	/** Save the document as a flat xml document
 	 */
 	public static final int FLAG_SAVE_FLAT_XML = 2;
 
 	/** inject the passed xml into the document
-	 *  if you don't do this step, then the xml in 
+	 *  if you don't do this step, then the xml in
 	 *  the document will be used.
 	 */
 	public static final int FLAG_BIND_INSERT_XML = 1;
-	
-	/** Insert the data of the xml in the content controls 
-	 *  Not needed, if the document will only be opened in word 
+
+	/** Insert the data of the xml in the content controls
+	 *  Not needed, if the document will only be opened in word
 	 *  and not converted to other formats.
 	 */
 	public static final int FLAG_BIND_BIND_XML = 2;
-	
+
 	/** Remove the content controls of the document
 	 */
 	public static final int FLAG_BIND_REMOVE_SDT = 4;
-	
-	/** Remove any xml parts from the document that 
+
+	/** Remove any xml parts from the document that
 	 *  are used with the content controls.
 	 */
 	public static final int FLAG_BIND_REMOVE_XML = 8;
-	
+
 	protected static class FindContentControlsVisitor extends TraversalUtilVisitor<SdtElement> {
 		public static class BreakException extends RuntimeException {
 		}
-		
+
 		protected Set<String> definedStoreItemIds = null;
 		protected String storeItemId = null;
 		public FindContentControlsVisitor(Set<String> definedStoreItemIds) {
 			this.definedStoreItemIds = definedStoreItemIds;
 		}
-		
+
 		@Override
 		public void apply(SdtElement element) {
 		SdtPr sdtPr = element.getSdtPr();
-			
+
 			if ((sdtPr.getDataBinding() != null) &&
 				(sdtPr.getDataBinding().getStoreItemID() != null)) {
 				String tmp = sdtPr.getDataBinding().getStoreItemID().toLowerCase();
@@ -150,18 +145,18 @@ public class Docx4J {
 				}
 			}
 		}
-		
+
 		public String getdefinedStoreItemId() {
 			return storeItemId;
 		}
 	}
-	
+
 	protected static final String NS_CONDITIONS = "http://opendope.org/conditions";
 	protected static final String NS_XPATHS = "http://opendope.org/xpaths";
 	protected static final String NS_QUESTIONS = "http://opendope.org/questions";
 	protected static final String NS_COMPONENTS = "http://opendope.org/components";
 	protected static final Set<String> PART_TO_REMOVE_SCHEMA_TYPES = new TreeSet<String>();
-	
+
 	static {
 		PART_TO_REMOVE_SCHEMA_TYPES.add(NS_CONDITIONS);
 		PART_TO_REMOVE_SCHEMA_TYPES.add(NS_XPATHS);
@@ -171,21 +166,21 @@ public class Docx4J {
 
 	/**
 	 *  Load a Docx Document from a File
-	 */	
+	 */
 	public static WordprocessingMLPackage load(File inFile) throws Docx4JException {
 		return WordprocessingMLPackage.load(inFile);
 	}
-	
+
 	/**
 	 *  Load a Docx Document from an InputStream
-	 */	
+	 */
 	public static WordprocessingMLPackage load(InputStream inStream) throws Docx4JException {
 		return WordprocessingMLPackage.load(inStream);
 	}
-	
+
 	/**
 	 *  Save a Docx Document to a File
-	 */	
+	 */
 	public static void save(WordprocessingMLPackage wmlPackage, File outFile, int flags) throws Docx4JException {
 	OutputStream outStream = null;
 		try {
@@ -203,21 +198,21 @@ public class Docx4J {
 			}
 		}
 	}
-	
+
 	/**
 	 *  Save a Docx Document to an OutputStream
-	 */	
+	 */
 	public static void save(WordprocessingMLPackage wmlPackage, OutputStream outStream, int flags) throws Docx4JException {
 		if (flags == FLAG_SAVE_FLAT_XML) {
-			JAXBContext jc = Context.jcXmlPackage;
+			JAXBContext jc = Context.getJcXmlPackage();
 			FlatOpcXmlCreator opcXmlCreator = new FlatOpcXmlCreator(wmlPackage);
 			org.docx4j.xmlPackage.Package pkg = opcXmlCreator.get();
 			Marshaller marshaller;
 			try {
 				marshaller = jc.createMarshaller();
-				NamespacePrefixMapperUtils.setProperty(marshaller, 
-						NamespacePrefixMapperUtils.getPrefixMapper());			
-				marshaller.marshal(pkg, outStream);				
+				NamespacePrefixMapperUtils.setProperty(marshaller,
+						NamespacePrefixMapperUtils.getPrefixMapper());
+				marshaller.marshal(pkg, outStream);
 			} catch (JAXBException e) {
 				throw new Docx4JException("Exception marshalling document for output: " + e.getMessage(), e);
 			}
@@ -227,12 +222,12 @@ public class Docx4J {
 			saver.save(outStream);
 		}
 	}
-	
+
 	/**
 	 *  Bind the content controls of the passed document to the xml.
-	 */	
+	 */
 	public static void bind(WordprocessingMLPackage wmlPackage, String xmlDocument, int flags) throws Docx4JException {
-		
+
 		ByteArrayInputStream xmlStream = null;
 		if (flags == FLAG_NONE) {
 			//do everything
@@ -250,10 +245,10 @@ public class Docx4J {
 		}
         bind(wmlPackage, xmlStream, flags);
 	}
-	
+
 	/**
 	 *  Bind the content controls of the passed document to the xml.
-	 */	
+	 */
 	public static void bind(WordprocessingMLPackage wmlPackage, InputStream xmlDocument, int flags) throws Docx4JException {
 		if (flags == FLAG_NONE) {
 			//do everything
@@ -264,9 +259,9 @@ public class Docx4J {
 		}
 	    Document xmlDoc = null;
 		if ((flags & FLAG_BIND_INSERT_XML) == FLAG_BIND_INSERT_XML) {
-		    DocumentBuilder documentBuilder = null; 
+		    DocumentBuilder documentBuilder = null;
 				try {
-		            documentBuilder = XmlUtils.getDocumentBuilderFactory().newDocumentBuilder(); 
+		            documentBuilder = XmlUtils.getDocumentBuilderFactory().newDocumentBuilder();
 		            xmlDoc = documentBuilder.parse(xmlDocument);
 				} catch (Exception e) {
 					throw new Docx4JException("Problems creating a org.w3c.dom.Document for the passed input stream.", e);
@@ -274,12 +269,12 @@ public class Docx4J {
 		}
         bind(wmlPackage, xmlDoc, flags);
 	}
-	
+
 	/**
 	 *  Bind the content controls of the passed document to the xml.
-	 */	
+	 */
 	public static void bind(WordprocessingMLPackage wmlPackage, Document xmlDocument, int flags) throws Docx4JException {
-		
+
 		OpenDoPEHandler	openDoPEHandler = null;
 		CustomXmlDataStoragePart customXmlDataStoragePart = null;
 		RemovalHandler removalHandler = null;
@@ -292,13 +287,13 @@ public class Docx4J {
 					 FLAG_BIND_REMOVE_SDT |
 					 FLAG_BIND_REMOVE_XML);
 		}
-		
-		customXmlDataStoragePart 
+
+		customXmlDataStoragePart
 			= CustomXmlDataStoragePartSelector.getCustomXmlDataStoragePart(wmlPackage);
 		if (customXmlDataStoragePart==null) {
 			throw new Docx4JException("Couldn't find CustomXmlDataStoragePart! exiting..");
 		}
-	
+
 		if ((flags & FLAG_BIND_INSERT_XML) == FLAG_BIND_INSERT_XML) {
 			insertXMLData(customXmlDataStoragePart, xmlDocument);
 		}
@@ -318,14 +313,14 @@ public class Docx4J {
 	}
 
 	protected static void insertXMLData(CustomXmlDataStoragePart customXmlDataStoragePart, Document xmlDocument) throws Docx4JException {
-		
+
 		customXmlDataStoragePart.getData().setDocument(xmlDocument);
 	}
 
 
 	protected static String findXPathStorageItemIdInContentControls(WordprocessingMLPackage wmlPackage) {
 	FindContentControlsVisitor visitor = null;
-		if ((wmlPackage.getCustomXmlDataStorageParts() != null) && 
+		if ((wmlPackage.getCustomXmlDataStorageParts() != null) &&
 			(!wmlPackage.getCustomXmlDataStorageParts().isEmpty())) {
 			try {
 				visitor = new FindContentControlsVisitor(wmlPackage.getCustomXmlDataStorageParts().keySet());
@@ -354,7 +349,7 @@ public class Docx4J {
 	protected static void removeDefinedCustomXmlParts(WordprocessingMLPackage wmlPackage, CustomXmlDataStoragePart customXmlDataStoragePart) {
 	List<PartName> partsToRemove = new ArrayList<PartName>();
 	RelationshipsPart relationshipsPart = wmlPackage.getMainDocumentPart().getRelationshipsPart();
-	List<Relationship> relationshipsList = ((relationshipsPart != null) && 
+	List<Relationship> relationshipsList = ((relationshipsPart != null) &&
 										    (relationshipsPart.getRelationships() != null) ?
 										    relationshipsPart.getRelationships().getRelationship() : null);
 	Part part = null;
@@ -378,10 +373,10 @@ public class Docx4J {
 //	protected static boolean IsPartToRemove(Part part, String xpathStorageItemId) {
 //	boolean ret = false;
 //	RelationshipsPart relationshipsPart = part.getRelationshipsPart();
-//	List<Relationship> relationshipsList = ((relationshipsPart != null) && 
+//	List<Relationship> relationshipsList = ((relationshipsPart != null) &&
 //										    (relationshipsPart.getRelationships() != null) ?
 //										    relationshipsPart.getRelationships().getRelationship() : null);
-//	
+//
 //	CustomXmlDataStoragePropertiesPart propertiesPart = null;
 //	DatastoreItem datastoreItem = null;
 //		if ((relationshipsList != null) && (!relationshipsList.isEmpty())) {
@@ -399,8 +394,8 @@ public class Docx4J {
 //			if ((datastoreItem.getItemID() != null) && (datastoreItem.getItemID().length() > 0)) {
 //				ret = datastoreItem.getItemID().equals(xpathStorageItemId);
 //			}
-//			if ((!ret) && 
-//				(datastoreItem.getSchemaRefs() != null) && 
+//			if ((!ret) &&
+//				(datastoreItem.getSchemaRefs() != null) &&
 //				(datastoreItem.getSchemaRefs().getSchemaRef() != null) &&
 //				(!datastoreItem.getSchemaRefs().getSchemaRef().isEmpty())) {
 //				for (SchemaRef ref : datastoreItem.getSchemaRefs().getSchemaRef()) {
@@ -413,40 +408,40 @@ public class Docx4J {
 //		}
 //		return ret;
 //	}
-	
+
 	/**
 	 *  Duplicate the document
-	 */	
+	 */
 	public static WordprocessingMLPackage clone(WordprocessingMLPackage wmlPackage) throws Docx4JException {
 		//Using the PartialDeepCopy is probably faster than serializing and deserializing the complete document.
 		return (WordprocessingMLPackage)PartialDeepCopy.process(wmlPackage, null);
 	}
-	
+
 	/**
 	 *  Create the configuration object for conversions that are done via xsl-fo
-	 */	
+	 */
 	public static FOSettings createFOSettings() {
 		return new FOSettings();
 	}
-	
+
 	/**
 	 *  Convert the document via xsl-fo
-	 */	
+	 */
 	public static void toFO(FOSettings settings, OutputStream outputStream, int flags) throws Docx4JException {
 	Exporter<FOSettings> exporter = getFOExporter(flags);
 		exporter.export(settings, outputStream);
 	}
-	
+
 	/**
 	 *  Convenience method to convert the document to PDF
-	 */	
+	 */
 	public static void toPDF(WordprocessingMLPackage wmlPackage, OutputStream outputStream) throws Docx4JException {
 	FOSettings settings = createFOSettings();
 		settings.setWmlPackage(wmlPackage);
 		settings.setApacheFopMime("application/pdf");
 		toFO(settings, outputStream, FLAG_NONE);
 	}
-	
+
 	protected static Exporter<FOSettings> getFOExporter(int flags) {
 		switch (flags) {
 			case FLAG_EXPORT_PREFER_NONXSL:
@@ -459,22 +454,22 @@ public class Docx4J {
 
 	/**
 	 *  Create the configuration object for conversions to html
-	 */	
+	 */
 	public static HTMLSettings createHTMLSettings() {
 		return new HTMLSettings();
 	}
-	
+
 	/**
 	 *  Convert the document to HTML
-	 */	
+	 */
 	public static void toHTML(HTMLSettings settings, OutputStream outputStream, int flags) throws Docx4JException {
 	Exporter<HTMLSettings> exporter = getHTMLExporter(flags);
 		exporter.export(settings, outputStream);
 	}
-	
+
 	/**
 	 *  Convert the document to HTML
-	 */	
+	 */
 	public static void toHTML(WordprocessingMLPackage wmlPackage, String imageDirPath, String imageTargetUri, OutputStream outputStream) throws Docx4JException {
 	HTMLSettings settings = createHTMLSettings();
 		settings.setWmlPackage(wmlPackage);
@@ -486,7 +481,7 @@ public class Docx4J {
 		}
 		toHTML(settings, outputStream, FLAG_NONE);
 	}
-	
+
 	protected static Exporter<HTMLSettings> getHTMLExporter(int flags) {
 		switch (flags) {
 			case FLAG_EXPORT_PREFER_NONXSL:
