@@ -22,9 +22,6 @@ package org.docx4j.jaxb;
 
 import java.io.IOException;
 import java.io.InputStream;
-import java.lang.management.ManagementFactory;
-import java.lang.management.MemoryMXBean;
-import java.lang.management.MemoryUsage;
 import java.net.URL;
 import java.util.Enumeration;
 import java.util.jar.Attributes;
@@ -40,42 +37,35 @@ import org.slf4j.LoggerFactory;
 
 public class Context {
 
-	public static JAXBContext jc;
+    private static Thread jcThread;
+    private static boolean jcThreadJoined = false;
 
-	// TEMP/Experimental
-//	public static void setJc(JAXBContext jc) {
-//		Context.jc = jc;
-//	}
+    private static JAXBContext jc;
 
-	@Deprecated
-	public static JAXBContext jcThemePart;
+	private static JAXBContext jcDocPropsCore;
+	private static JAXBContext jcDocPropsCustom;
+	private static JAXBContext jcDocPropsExtended;
+	private static JAXBContext jcRelationships;
+	private static JAXBContext jcCustomXmlProperties;
+	private static JAXBContext jcContentTypes;
 
-	public static JAXBContext jcDocPropsCore;
-	public static JAXBContext jcDocPropsCustom;
-	public static JAXBContext jcDocPropsExtended;
-	public static JAXBContext jcRelationships;
-	public static JAXBContext jcCustomXmlProperties;
-	public static JAXBContext jcContentTypes;
-
-	public static JAXBContext jcXmlPackage;
+	private static JAXBContext jcXmlPackage;
 
 	private static JAXBContext jcXslFo;
-	public static JAXBContext jcSectionModel;
+	private static JAXBContext jcSectionModel;
 
-	public static JAXBContext jcXmlDSig;
+	private static JAXBContext jcXmlDSig;
 
 	/** @since 3.0.1 */
-	public static JAXBContext jcMCE;
+	private static JAXBContext jcMCE;
 
 	private static Logger log = LoggerFactory.getLogger(Context.class);
-	
-	private static int memCount;
-	
-	private static long freeHeapSizeLimit = 75000000;
+
+	private static boolean lowMemoryAbort = false;
 
 	static {
 
-		// Display diagnostic info about version of JAXB being used.
+	    // Display diagnostic info about version of JAXB being used.
 		log.info("java.vendor="+System.getProperty("java.vendor"));
 		log.info("java.version="+System.getProperty("java.version"));
 
@@ -120,133 +110,151 @@ public class Context {
 				e.printStackTrace();
 			}
 		}
+        jcThread = new Thread(
+            new Runnable() {
+                public void run() {
+                    try {
+                        // JAXBContext.newInstance uses the context class loader of the current thread.
+                        // To specify the use of a different class loader,
+                        // either set it via the Thread.setContextClassLoader() api
+                        // or use the newInstance method.
+                        // JBOSS (older versions only?) might use a different class loader to load JAXBContext,
+                        // which caused problems, so in docx4j we explicitly specify our class loader.
+                        // IKVM 7.3.4830 also needs this to be done
+                        // (java.lang.Thread.currentThread().setContextClassLoader doesn't seem to help!)
+                        // and there are no environments in which this approach is known to be problematic
 
-      try {
-			// JAXBContext.newInstance uses the context class loader of the current thread.
-			// To specify the use of a different class loader,
-			// either set it via the Thread.setContextClassLoader() api
-			// or use the newInstance method.
-			// JBOSS (older versions only?) might use a different class loader to load JAXBContext,
-    	  	// which caused problems, so in docx4j we explicitly specify our class loader.
-    	  	// IKVM 7.3.4830 also needs this to be done
-    	  	// (java.lang.Thread.currentThread().setContextClassLoader doesn't seem to help!)
-    	  	// and there are no environments in which this approach is known to be problematic
+                        java.lang.ClassLoader classLoader = Context.class.getClassLoader();
 
-			java.lang.ClassLoader classLoader = Context.class.getClassLoader();
+                        jc = JAXBContext.newInstance("org.docx4j.wml:org.docx4j.w14:org.docx4j.w15:" +
+                                "org.docx4j.schemas.microsoft.com.office.word_2006.wordml:" +
+                                "org.docx4j.dml:org.docx4j.dml.chart:org.docx4j.dml.chartDrawing:org.docx4j.dml.compatibility:org.docx4j.dml.diagram:org.docx4j.dml.lockedCanvas:org.docx4j.dml.picture:org.docx4j.dml.wordprocessingDrawing:org.docx4j.dml.spreadsheetdrawing:org.docx4j.dml.diagram2008:" +
+                                // All VML stuff is here, since compiling it requires WML and DML (and MathML), but not PML or SML
+                                "org.docx4j.vml:org.docx4j.vml.officedrawing:org.docx4j.vml.wordprocessingDrawing:org.docx4j.vml.presentationDrawing:org.docx4j.vml.spreadsheetDrawing:org.docx4j.vml.root:" +
+                                "org.docx4j.docProps.coverPageProps:" +
+                                "org.opendope.xpaths:org.opendope.conditions:org.opendope.questions:org.opendope.answers:org.opendope.components:org.opendope.SmartArt.dataHierarchy:" +
+                                "org.docx4j.math:" +
+                                "org.docx4j.sharedtypes:org.docx4j.bibliography:org.docx4j.mce:" +
+                                "org.docx4j.dml2010:org.docx4j.dml.wordprocessingCanvas2010:org.docx4j.dml.wordprocessingGroup2010:org.docx4j.dml.wordprocessingShape2010", classLoader );
 
-			jc = JAXBContext.newInstance("org.docx4j.wml:org.docx4j.w14:org.docx4j.w15:" +
-					"org.docx4j.schemas.microsoft.com.office.word_2006.wordml:" +
-					"org.docx4j.dml:org.docx4j.dml.chart:org.docx4j.dml.chartDrawing:org.docx4j.dml.compatibility:org.docx4j.dml.diagram:org.docx4j.dml.lockedCanvas:org.docx4j.dml.picture:org.docx4j.dml.wordprocessingDrawing:org.docx4j.dml.spreadsheetdrawing:org.docx4j.dml.diagram2008:" +
-					// All VML stuff is here, since compiling it requires WML and DML (and MathML), but not PML or SML
-					"org.docx4j.vml:org.docx4j.vml.officedrawing:org.docx4j.vml.wordprocessingDrawing:org.docx4j.vml.presentationDrawing:org.docx4j.vml.spreadsheetDrawing:org.docx4j.vml.root:" +
-					"org.docx4j.docProps.coverPageProps:" +
-					"org.opendope.xpaths:org.opendope.conditions:org.opendope.questions:org.opendope.answers:org.opendope.components:org.opendope.SmartArt.dataHierarchy:" +
-					"org.docx4j.math:" +
-					"org.docx4j.sharedtypes:org.docx4j.bibliography",classLoader );
+                        if (jc.getClass().getName().equals("org.eclipse.persistence.jaxb.JAXBContext")) {
+                            log.info("MOXy JAXB implementation is in use!");
+                        } else {
+                            log.info("Not using MOXy; using " + jc.getClass().getName());
+                        }
+                        jcDocPropsCore = JAXBContext.newInstance("org.docx4j.docProps.core:org.docx4j.docProps.core.dc.elements:org.docx4j.docProps.core.dc.terms",classLoader );
+                        jcDocPropsCustom = JAXBContext.newInstance("org.docx4j.docProps.custom",classLoader );
+                        jcDocPropsExtended = JAXBContext.newInstance("org.docx4j.docProps.extended",classLoader );
+                        jcXmlPackage = JAXBContext.newInstance("org.docx4j.xmlPackage",classLoader );
+                        jcRelationships = JAXBContext.newInstance("org.docx4j.relationships",classLoader );
+                        jcCustomXmlProperties = JAXBContext.newInstance("org.docx4j.customXmlProperties",classLoader );
+                        jcContentTypes = JAXBContext.newInstance("org.docx4j.openpackaging.contenttype",classLoader );
 
-			if (jc.getClass().getName().equals("org.eclipse.persistence.jaxb.JAXBContext")) {
-				log.info("MOXy JAXB implementation is in use!");
-			} else {
-				log.info("Not using MOXy; using " + jc.getClass().getName());
-			}
+                        jcSectionModel = JAXBContext.newInstance("org.docx4j.model.structure.jaxb",classLoader );
 
-			jcThemePart = jc; //JAXBContext.newInstance("org.docx4j.dml",classLoader );
-			jcDocPropsCore = JAXBContext.newInstance("org.docx4j.docProps.core:org.docx4j.docProps.core.dc.elements:org.docx4j.docProps.core.dc.terms",classLoader );
-			jcDocPropsCustom = JAXBContext.newInstance("org.docx4j.docProps.custom",classLoader );
-			jcDocPropsExtended = JAXBContext.newInstance("org.docx4j.docProps.extended",classLoader );
-			jcXmlPackage = JAXBContext.newInstance("org.docx4j.xmlPackage",classLoader );
-			jcRelationships = JAXBContext.newInstance("org.docx4j.relationships",classLoader );
-			jcCustomXmlProperties = JAXBContext.newInstance("org.docx4j.customXmlProperties",classLoader );
-			jcContentTypes = JAXBContext.newInstance("org.docx4j.openpackaging.contenttype",classLoader );
+                        jcXmlDSig = JAXBContext.newInstance("org.plutext.jaxb.xmldsig",classLoader );
 
-			jcSectionModel = JAXBContext.newInstance("org.docx4j.model.structure.jaxb",classLoader );
+                        jcMCE = JAXBContext.newInstance("org.docx4j.mce",classLoader );
 
-			jcXmlDSig = JAXBContext.newInstance("org.plutext.jaxb.xmldsig",classLoader );
-
-			jcMCE = JAXBContext.newInstance("org.docx4j.mce",classLoader );
-
-			log.debug(".. other contexts loaded ..");
+                        log.debug(".. other contexts loaded ..");
 
 
-		} catch (Exception ex) {
-			log.error("Cannot initialize context", ex);
-		}
+                    } catch (Exception ex) {
+                        log.error("Cannot initialize context", ex);
+                    }
+                }
+            }
+        );
+        jcThread.start();
+	}
+	public static boolean isLowMemoryAbort() {
+	    return lowMemoryAbort;
+	}
+	public static void setLowMemoryAbort(boolean l) {
+	    lowMemoryAbort = l;
+	}
+	public static void abortOnLowMemory() {
+	    if(lowMemoryAbort) {
+	        throw new RuntimeException();
+	    }
+	}
+
+	/*
+	 * the jcThread is joined, additional it is checked if it should
+	 * aborted because of low memory
+	 *
+	 */
+	private static final void initializeContexts() {
+	    abortOnLowMemory();
+        if(!jcThreadJoined) {
+            try {
+                jcThread.join();
+            } catch (InterruptedException e) {
+                log.info("DOCX4J, could not get Context");
+            }
+            jcThreadJoined = true;
+        }
 	}
 
     public static final JAXBContext getJc() {
+        initializeContexts();
         return jc;
     }
 
-    public static final JAXBContext getJcThemePart() {
-        return getJc();
-    }
-
     public static final JAXBContext getJcDocPropsCore() {
+        initializeContexts();
         return jcDocPropsCore;
     }
 
     public static final JAXBContext getJcDocPropsCustom() {
+        initializeContexts();
         return jcDocPropsCustom;
     }
 
     public static final JAXBContext getJcDocPropsExtended() {
+        initializeContexts();
         return jcDocPropsExtended;
     }
 
     public static final JAXBContext getJcRelationships() {
+        initializeContexts();
         return jcRelationships;
     }
 
     public static final JAXBContext getJcCustomXmlProperties() {
+        initializeContexts();
         return jcCustomXmlProperties;
     }
 
     public static final JAXBContext getJcContentTypes() {
+        initializeContexts();
         return jcContentTypes;
     }
 
     public static final JAXBContext getJcXmlPackage() {
+        initializeContexts();
         return jcXmlPackage;
     }
 
     public static final JAXBContext getJcSectionModel() {
+        initializeContexts();
         return jcSectionModel;
     }
 
     public static final JAXBContext getJcXmlDSig() {
+        initializeContexts();
         return jcXmlDSig;
     }
-    
-    private static long getFreeMemory() {
-        final MemoryMXBean memoryMXBean = ManagementFactory.getMemoryMXBean();
-        final MemoryUsage heapMemoryUsage = memoryMXBean.getHeapMemoryUsage();
-        final long max = heapMemoryUsage.getMax();
-        final long used = heapMemoryUsage.getUsed();
-        return max - used;
-    }
-    
-    public static final void checkMemory() {
-    	memCount++;
-    	if(memCount>1000) {
-    		memCount=0;
-    		long free = getFreeMemory();
-            if(free<freeHeapSizeLimit) {
-            	System.gc();
-        		free = getFreeMemory();
-        		if(free<freeHeapSizeLimit) {
-        			throw new OutOfMemoryError();
-        		}
-            }
-    	}
-    }
 
-    public static void setFreeHeapSizeLimit(long limit) {
-    	freeHeapSizeLimit = limit;
+    public static final JAXBContext getJcMCE() {
+        initializeContexts();
+        return jcMCE;
     }
 
 	private static org.docx4j.wml.ObjectFactory wmlObjectFactory;
 	public static org.docx4j.wml.ObjectFactory getWmlObjectFactory() {
 
+	    abortOnLowMemory();
 		if (wmlObjectFactory==null) {
 			wmlObjectFactory = new org.docx4j.wml.ObjectFactory();
 		}
@@ -256,6 +264,7 @@ public class Context {
     private static org.pptx4j.pml.ObjectFactory pmlObjectFactory;
     public static org.pptx4j.pml.ObjectFactory getpmlObjectFactory() {
 
+        abortOnLowMemory();
         if (pmlObjectFactory==null) {
             pmlObjectFactory = new org.pptx4j.pml.ObjectFactory();
         }
@@ -265,6 +274,7 @@ public class Context {
     private static org.docx4j.dml.ObjectFactory dmlObjectFactory;
     public static org.docx4j.dml.ObjectFactory getDmlObjectFactory() {
 
+        abortOnLowMemory();
         if (dmlObjectFactory==null) {
             dmlObjectFactory = new org.docx4j.dml.ObjectFactory();
         }
@@ -273,6 +283,8 @@ public class Context {
 
     private static org.docx4j.dml.chart.ObjectFactory dmlChartObjectFactory;
     public static org.docx4j.dml.chart.ObjectFactory getDmlChartObjectFactory() {
+
+        abortOnLowMemory();
         if(dmlChartObjectFactory==null) {
             dmlChartObjectFactory = new org.docx4j.dml.chart.ObjectFactory();
         }
@@ -281,6 +293,8 @@ public class Context {
 
     private static org.docx4j.vml.wordprocessingDrawing.ObjectFactory vmlWordprocessingDrawingObjectFactory;
     public static org.docx4j.vml.wordprocessingDrawing.ObjectFactory getVmlWordprocessingDrawingObjectFactory() {
+
+        abortOnLowMemory();
         if(vmlWordprocessingDrawingObjectFactory==null) {
             vmlWordprocessingDrawingObjectFactory = new org.docx4j.vml.wordprocessingDrawing.ObjectFactory();
         }
@@ -289,6 +303,8 @@ public class Context {
 
     private static org.docx4j.dml.spreadsheetdrawing.ObjectFactory dmlSpreadsheetDrawingObjectFactory;
     public static org.docx4j.dml.spreadsheetdrawing.ObjectFactory getDmlSpreadsheetDrawingObjectFactory() {
+
+        abortOnLowMemory();
         if(dmlSpreadsheetDrawingObjectFactory==null) {
             dmlSpreadsheetDrawingObjectFactory = new org.docx4j.dml.spreadsheetdrawing.ObjectFactory();
         }
