@@ -147,7 +147,9 @@ public class ContentTypes {
 		"application/vnd.openxmlformats-officedocument.wordprocessingml.styles+xml";
 	public final static String WORDPROCESSINGML_WEBSETTINGS =
 		"application/vnd.openxmlformats-officedocument.wordprocessingml.webSettings+xml";
-
+	public final static String WORDPROCESSINGML_PEOPLE =
+		"application/vnd.openxmlformats-officedocument.wordprocessingml.people+xml";
+	
 	// "/word/diagrams/data1.xml"
 	public final static String DRAWINGML_DIAGRAM_DATA =
 		"application/vnd.openxmlformats-officedocument.drawingml.diagramData+xml";
