@@ -31,9 +31,10 @@ import java.util.HashMap;
 import java.util.HashSet;
 import java.util.List;
 import java.util.Set;
+
 import javax.xml.bind.JAXBException;
+
 import org.docx4j.Docx4jProperties;
-import org.docx4j.docProps.core.CoreProperties;
 import org.docx4j.docProps.extended.Properties;
 import org.docx4j.openpackaging.URIHelper;
 import org.docx4j.openpackaging.contenttype.ContentTypeManager;
@@ -43,7 +44,6 @@ import org.docx4j.openpackaging.io3.stores.PartStore;
 import org.docx4j.openpackaging.io3.stores.ZipPartStore;
 import org.docx4j.openpackaging.packages.OpcPackage;
 import org.docx4j.openpackaging.parts.CustomXmlDataStoragePart;
-import org.docx4j.openpackaging.parts.DocPropsCorePart;
 import org.docx4j.openpackaging.parts.DocPropsExtendedPart;
 import org.docx4j.openpackaging.parts.JaxbXmlPart;
 import org.docx4j.openpackaging.parts.Part;
@@ -121,15 +121,15 @@ public class Save {
         "application/vnd.openxmlformats-officedocument.drawing+xml"));
 
     final static Set<String> checkRelations = new HashSet<String>(Arrays.asList(
-        "http://schemas.openxmlformats.org/officeDocument/2006/relationships/image",
-        "http://schemas.openxmlformats.org/officeDocument/2006/relationships/chart",
-        "http://schemas.openxmlformats.org/officeDocument/2006/relationships/drawing",
-        "http://schemas.openxmlformats.org/officeDocument/2006/relationships/hyperlink",
-        "http://schemas.openxmlformats.org/officeDocument/2006/relationships/diagramColors",
-        "http://schemas.openxmlformats.org/officeDocument/2006/relationships/diagramData",
-        "http://schemas.microsoft.com/office/2007/relationships/diagramDrawing",
-        "http://schemas.openxmlformats.org/officeDocument/2006/relationships/diagramLayout",
-        "http://schemas.openxmlformats.org/officeDocument/2006/relationships/diagramQuickStyle"));
+        Namespaces.IMAGE,
+        Namespaces.SPREADSHEETML_CHART,
+        Namespaces.SPREADSHEETML_DRAWING,
+        Namespaces.HYPERLINK,
+        Namespaces.DRAWINGML_DIAGRAM_COLORS,
+        Namespaces.DRAWINGML_DIAGRAM_DATA,
+        Namespaces.DRAWINGML_DIAGRAM_DRAWING,
+        Namespaces.DRAWINGML_DIAGRAM_LAYOUT,
+        Namespaces.DRAWINGML_DIAGRAM_STYLE));
 
     public static int indexOfBytes(byte[] array, byte[] pattern, int index)
     {
@@ -317,7 +317,6 @@ public class Save {
 //				realOS.close();
 //			}
 	    } catch (Exception e) {
-			e.printStackTrace() ;
 			if (e instanceof Docx4JException) {
 				throw (Docx4JException)e;
 			} else {
@@ -373,7 +372,7 @@ public class Save {
 
 					}
 				}
-*/				
+*/
 				if (part instanceof DocPropsExtendedPart) {
 					boolean appWrite= Boolean.parseBoolean(
 							Docx4jProperties.getProperties().getProperty("docx4j.App.write", "false"));
@@ -420,11 +419,8 @@ public class Save {
 			}
 
 		} catch (Exception e) {
-			e.printStackTrace();
-			log.error(e.getMessage(), e);
 			throw new Docx4JException("Problem saving part " + part.getPartName(), e);
 		}
-
 	}
 
 
