@@ -1,19 +1,19 @@
 /*
  *  Copyright 2007-2008, Plutext Pty Ltd.
- *   
+ *
  *  This file is part of docx4j.
 
-    docx4j is licensed under the Apache License, Version 2.0 (the "License"); 
-    you may not use this file except in compliance with the License. 
+    docx4j is licensed under the Apache License, Version 2.0 (the "License");
+    you may not use this file except in compliance with the License.
 
-    You may obtain a copy of the License at 
+    You may obtain a copy of the License at
 
-        http://www.apache.org/licenses/LICENSE-2.0 
+        http://www.apache.org/licenses/LICENSE-2.0
 
-    Unless required by applicable law or agreed to in writing, software 
-    distributed under the License is distributed on an "AS IS" BASIS, 
-    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. 
-    See the License for the specific language governing permissions and 
+    Unless required by applicable law or agreed to in writing, software
+    distributed under the License is distributed on an "AS IS" BASIS,
+    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+    See the License for the specific language governing permissions and
     limitations under the License.
 
  */
@@ -27,12 +27,13 @@ package org.docx4j.openpackaging.parts.WordprocessingML;
 //import javax.xml.bind.JAXBContext;
 //import java.net.URI;
 
+import javax.xml.bind.JAXBException;
+
 import org.docx4j.XmlUtils;
 import org.docx4j.jaxb.Context;
 import org.docx4j.openpackaging.exceptions.InvalidFormatException;
 import org.docx4j.openpackaging.packages.WordprocessingMLPackage;
 import org.docx4j.openpackaging.parts.JaxbXmlPartAltChunkHost;
-import org.docx4j.openpackaging.parts.JaxbXmlPartXPathAware;
 import org.docx4j.openpackaging.parts.Part;
 import org.docx4j.openpackaging.parts.PartName;
 import org.docx4j.openpackaging.parts.PeoplePart;
@@ -51,42 +52,42 @@ import org.w3c.dom.Node;
 
 
 public abstract class DocumentPart<E> extends JaxbXmlPartAltChunkHost<E> {
-	
+
 	/** Parts which can be the target of a relationship from either
 	 *  the Main Document or the Glossary Document
-	 *  
+	 *
 	 *  Microsoft's Microsoft.Office.DocumentFormat.OpenXML has
-	 *  no equivalent of this.  
-	 *  
-	 */ 
-	
-	protected CommentsPart commentsPart; 	
-	protected DocumentSettingsPart documentSettingsPart;	
-	protected EndnotesPart endNotesPart; 	
-	protected FontTablePart fontTablePart; 
-	protected ThemePart themePart;  
-	protected FootnotesPart footnotesPart; 
-	protected NumberingDefinitionsPart numberingDefinitionsPart; 	
-	protected StyleDefinitionsPart styleDefinitionsPart; 	
+	 *  no equivalent of this.
+	 *
+	 */
+
+	protected CommentsPart commentsPart;
+	protected DocumentSettingsPart documentSettingsPart;
+	protected EndnotesPart endNotesPart;
+	protected FontTablePart fontTablePart;
+	protected ThemePart themePart;
+	protected FootnotesPart footnotesPart;
+	protected NumberingDefinitionsPart numberingDefinitionsPart;
+	protected StyleDefinitionsPart styleDefinitionsPart;
 	protected WebSettingsPart webSettingsPart;
 	protected PeoplePart peoplePart;
-	
+
 	// To access headerParts and footerParts, instead
 	// use the DocumentModel.
 
 
 	public boolean setPartShortcut(Part part) {
-		
+
 		if (part == null ){
 			return false;
 		} else {
 			return setPartShortcut(part, part.getRelationshipType() );
 		}
-		
-	}	
-		
+
+	}
+
 	public boolean setPartShortcut(Part part, String relationshipType) {
-		
+
 		// Since each part knows its relationshipsType,
 		// why is this passed in as an arg?
 		// Answer: where the relationshipType is ascertained
@@ -94,39 +95,39 @@ public abstract class DocumentPart<E> extends JaxbXmlPartAltChunkHost<E> {
 		// Note that we normally use the info in [Content_Types]
 		// to create a part of the correct type.  This info
 		// will not necessary correspond to the info in the rel!
-		
+
 		if (relationshipType==null) {
 			log.warn("trying to set part shortcut against a null relationship type.");
 			return false;
 		}
-		
+
 		if (relationshipType.equals(Namespaces.FONT_TABLE)) {
 			fontTablePart = (FontTablePart)part;
-			return true;			
+			return true;
 		} else if (relationshipType.equals(Namespaces.THEME)) {
 			themePart = (ThemePart)part;
-			return true;	
+			return true;
 		} else if (relationshipType.equals(Namespaces.STYLES)) {
 			styleDefinitionsPart = (StyleDefinitionsPart)part;
-			return true;			
+			return true;
 		} else if (relationshipType.equals(Namespaces.WEB_SETTINGS)) {
 			webSettingsPart = (WebSettingsPart)part;
-			return true;	
+			return true;
 		} else if (relationshipType.equals(Namespaces.SETTINGS)) {
 			documentSettingsPart = (DocumentSettingsPart)part;
-			return true;	
+			return true;
 		} else if (relationshipType.equals(Namespaces.COMMENTS)) {
 			commentsPart = (CommentsPart)part;
-			return true;	
+			return true;
 		} else if (relationshipType.equals(Namespaces.ENDNOTES)) {
 			endNotesPart = (EndnotesPart)part;
-			return true;	
+			return true;
 		} else if (relationshipType.equals(Namespaces.FOOTNOTES)) {
 			footnotesPart = (FootnotesPart)part;
-			return true;	
+			return true;
 		} else if (relationshipType.equals(Namespaces.NUMBERING)) {
 			numberingDefinitionsPart = (NumberingDefinitionsPart)part;
-			return true;	
+			return true;
 		} else if (part instanceof ConditionsPart) {
 			conditionsPart = ((ConditionsPart)part);
 			return true;
@@ -150,19 +151,19 @@ public abstract class DocumentPart<E> extends JaxbXmlPartAltChunkHost<E> {
 			return false;
 		}
 	}
-	
-	
+
+
 	/** Other characteristics which both the Main Document and the
 	 *  Glossary Document have.
-	 */ 
+	 */
 	//private VML background; // [1.2.1]
-	
-	
+
+
 	public DocumentPart(PartName partName) throws InvalidFormatException {
 		super(partName);
 	}
 
-	
+
 
 	public CommentsPart getCommentsPart() {
 		return commentsPart;
@@ -194,7 +195,7 @@ public abstract class DocumentPart<E> extends JaxbXmlPartAltChunkHost<E> {
 			// Word seems to add an endnotes part when it adds a footnotes part,
 			// so existence of part is not determinative
 			CTEndnotes endnotes = getEndNotesPart().getJaxbElement();
-			
+
 			if (endnotes.getEndnote().size()<3) {
 				// id's 0 & 1 are:
 				// <w:endnote w:type="separator" w:id="0">
@@ -208,7 +209,7 @@ public abstract class DocumentPart<E> extends JaxbXmlPartAltChunkHost<E> {
 	public FootnotesPart getFootnotesPart() {
 		return footnotesPart;
 	}
-	
+
 	public boolean hasFootnotesPart() {
 		if (getFootnotesPart()==null) {
 			return false;
@@ -218,19 +219,19 @@ public abstract class DocumentPart<E> extends JaxbXmlPartAltChunkHost<E> {
 	}
 
 	@Deprecated // see instead org.docx4j.convert.out.Converter
-	public static Node getFootnote(WordprocessingMLPackage wmlPackage, String id) {	
-		
+	public static Node getFootnote(WordprocessingMLPackage wmlPackage, String id) {
+
 		CTFootnotes footnotes = wmlPackage.getMainDocumentPart().getFootnotesPart().getJaxbElement();
 		int pos = Integer.parseInt(id);
-		
-		// No @XmlRootElement on CTFtnEdn, so .. 
+
+		// No @XmlRootElement on CTFtnEdn, so ..
 		CTFtnEdn ftn = (CTFtnEdn)footnotes.getFootnote().get(pos);
 		Document d = XmlUtils.marshaltoW3CDomDocument( ftn,
-				Context.jc, Namespaces.NS_WORD12, "footnote",  CTFtnEdn.class );
+				Context.getJc(), Namespaces.NS_WORD12, "footnote",  CTFtnEdn.class );
 		log.debug("Footnote " + id + ": " + XmlUtils.w3CDomNodeToString(d));
 		return d;
 	}
-	
+
 	public FontTablePart getFontTablePart() {
 		return fontTablePart;
 	}
@@ -239,7 +240,7 @@ public abstract class DocumentPart<E> extends JaxbXmlPartAltChunkHost<E> {
 //	public List getFooterParts() {
 //		return footerPart;
 //	}
-	
+
 //	public List getHeaderParts() {
 //		return headerPart;
 //	}
@@ -253,7 +254,7 @@ public abstract class DocumentPart<E> extends JaxbXmlPartAltChunkHost<E> {
 	public StyleDefinitionsPart getStyleDefinitionsPart() {
 		return getStyleDefinitionsPart(false);
 	}
-	
+
 	public StyleDefinitionsPart getStyleDefinitionsPart(boolean create) {
 		if (styleDefinitionsPart==null
 				&& create) {
@@ -262,10 +263,12 @@ public abstract class DocumentPart<E> extends JaxbXmlPartAltChunkHost<E> {
 			try {
 				styleDefinitionsPart = new StyleDefinitionsPart();
 				styleDefinitionsPart.unmarshalDefaultStyles();
-				this.addTargetPart(styleDefinitionsPart); 			
-				
-			} catch (Exception e) {
+				this.addTargetPart(styleDefinitionsPart);
+
+			} catch (InvalidFormatException e) {
 				log.error(e.getMessage(), e);
+			} catch (JAXBException e) {
+                log.error(e.getMessage(), e);
 			}
 		}
 		return styleDefinitionsPart;
@@ -274,7 +277,7 @@ public abstract class DocumentPart<E> extends JaxbXmlPartAltChunkHost<E> {
 	public ThemePart getThemePart() {
 		return themePart;
 	}
-	
+
 
 	public WebSettingsPart getWebSettingsPart() {
 		return webSettingsPart;
@@ -295,20 +298,20 @@ public abstract class DocumentPart<E> extends JaxbXmlPartAltChunkHost<E> {
 //	public void setXPathsPart(XPathsPart xPathsPart) {
 //		this.xPathsPart = xPathsPart;
 //	}
-	
+
 	private QuestionsPart questionsPart;
 	public QuestionsPart getQuestionsPart() {
 		return questionsPart;
 	}
-	
+
 	private ComponentsPart componentsPart;
 	public ComponentsPart getComponentsPart() {
 		return componentsPart;
 	}
-	
+
 	private BibliographyPart bibliographyPart;
 	public BibliographyPart getBibliographyPart() {
 		return bibliographyPart;
 	}
-	
+
 }
