@@ -1,19 +1,19 @@
 /*
  *  Copyright 2007-2008, Plutext Pty Ltd.
- *   
+ *
  *  This file is part of docx4j.
 
-    docx4j is licensed under the Apache License, Version 2.0 (the "License"); 
-    you may not use this file except in compliance with the License. 
+    docx4j is licensed under the Apache License, Version 2.0 (the "License");
+    you may not use this file except in compliance with the License.
 
-    You may obtain a copy of the License at 
+    You may obtain a copy of the License at
 
-        http://www.apache.org/licenses/LICENSE-2.0 
+        http://www.apache.org/licenses/LICENSE-2.0
 
-    Unless required by applicable law or agreed to in writing, software 
-    distributed under the License is distributed on an "AS IS" BASIS, 
-    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. 
-    See the License for the specific language governing permissions and 
+    Unless required by applicable law or agreed to in writing, software
+    distributed under the License is distributed on an "AS IS" BASIS,
+    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+    See the License for the specific language governing permissions and
     limitations under the License.
 
  */
@@ -24,14 +24,14 @@ import java.io.IOException;
 import java.math.BigInteger;
 import java.util.List;
 
-import org.slf4j.Logger;
-import org.slf4j.LoggerFactory;
+import javax.xml.bind.JAXBContext;
+import javax.xml.bind.JAXBException;
+import javax.xml.bind.Unmarshaller;
+
 import org.docx4j.XmlUtils;
 import org.docx4j.jaxb.Context;
 import org.docx4j.openpackaging.exceptions.Docx4JException;
 import org.docx4j.openpackaging.exceptions.InvalidFormatException;
-import org.docx4j.openpackaging.packages.WordprocessingMLPackage;
-import org.docx4j.openpackaging.parts.JaxbXmlPart;
 import org.docx4j.openpackaging.parts.JaxbXmlPartXPathAware;
 import org.docx4j.openpackaging.parts.PartName;
 import org.docx4j.openpackaging.parts.relationships.Namespaces;
@@ -41,18 +41,16 @@ import org.docx4j.wml.PPr;
 import org.docx4j.wml.PPrBase.Spacing;
 import org.docx4j.wml.RPr;
 import org.docx4j.wml.Style;
-import org.docx4j.wml.Styles;
 import org.docx4j.wml.Style.BasedOn;
-
-import javax.xml.bind.JAXBContext;
-import javax.xml.bind.JAXBException;
-import javax.xml.bind.Unmarshaller;
+import org.docx4j.wml.Styles;
+import org.slf4j.Logger;
+import org.slf4j.LoggerFactory;
 
 
 public final class StyleDefinitionsPart extends JaxbXmlPartXPathAware<Styles> {
-	
-	private static Logger log = LoggerFactory.getLogger(StyleDefinitionsPart.class);		
-	
+
+	private static Logger log = LoggerFactory.getLogger(StyleDefinitionsPart.class);
+
 	public StyleDefinitionsPart(PartName partName) throws InvalidFormatException {
 		super(partName);
 		init();
@@ -62,21 +60,21 @@ public final class StyleDefinitionsPart extends JaxbXmlPartXPathAware<Styles> {
 		super(new PartName("/word/styles.xml"));
 		init();
 	}
-	
+
 	public void init() {
-		// Used if this Part is added to [Content_Types].xml 
-		setContentType(new  org.docx4j.openpackaging.contenttype.ContentType( 
+		// Used if this Part is added to [Content_Types].xml
+		setContentType(new  org.docx4j.openpackaging.contenttype.ContentType(
 				org.docx4j.openpackaging.contenttype.ContentTypes.WORDPROCESSINGML_STYLES));
 
-		// Used when this Part is added to a rels 
+		// Used when this Part is added to a rels
 		setRelationshipType(Namespaces.STYLES);
 	}
-	
+
 	// A variety of pre-defined styles, available for use in a StyleDefinitionsPart.
 	private static java.util.Map<String, org.docx4j.wml.Style>  knownStyles = null;
-	
+
 	// private PropertyResolver propertyResolver;
-	
+
 	@Override
 	public void setJaxbElement(Styles jaxbElement) {
 		super.setJaxbElement(jaxbElement);
@@ -87,23 +85,23 @@ public final class StyleDefinitionsPart extends JaxbXmlPartXPathAware<Styles> {
 	    defaultTableStyle = null;
 	    css=null;
 	}
-	
-    
+
+
 //	@Override
 //    public Styles unmarshal(org.w3c.dom.Element el) throws JAXBException {
-//    	
-//    	// Note: This is used when we read in a pkg:package 
+//
+//    	// Note: This is used when we read in a pkg:package
 //
 //		try {
 //
 //			Unmarshaller u = jc.createUnmarshaller();
-//						
+//
 //			u.setEventHandler(new org.docx4j.jaxb.JaxbValidationEventHandler());
 //
 //			jaxbElement = (Styles) u.unmarshal( el );
-//			
+//
 //			return jaxbElement;
-//			
+//
 //		} catch (JAXBException e) {
 //			// TODO Auto-generated catch block
 //			e.printStackTrace();
@@ -111,70 +109,70 @@ public final class StyleDefinitionsPart extends JaxbXmlPartXPathAware<Styles> {
 //		}
 //	}
 
-    
+
     /**
      * Unmarshal a default set of styles, useful when creating this
-     * part from scratch. 
+     * part from scratch.
      *
-     * @return the newly created root object of the java content tree 
+     * @return the newly created root object of the java content tree
      *
-     * @throws JAXBException 
+     * @throws JAXBException
      *     If any unexpected errors occur while unmarshalling
      */
     public Object unmarshalDefaultStyles() throws JAXBException {
-    	
-    	
+
+
 //    	Throwable t = new Throwable();
 //    	t.printStackTrace();
-    	  
+
     		java.io.InputStream is = null;
 			try {
 				//Works in Eclipse if the resource is in source/main/java
 				//is = getResource("styles.xml");
-				
+
 				// Works in Eclipse - not absence of leading '/'
 				is = org.docx4j.utils.ResourceUtils.getResource(
 						"org/docx4j/openpackaging/parts/WordprocessingML/styles.xml");
-				
+
 					// styles.xml defines a small subset of common styles
 					// (it is a much smaller set of styles than KnownStyles.xml)
-				
+
 			} catch (IOException e) {
 				// TODO Auto-generated catch block
 				e.printStackTrace();
-			}    		
-    	
-    	return unmarshal( is );    // side-effect is to set jaxbElement 	
+			}
+
+    	return unmarshal( is );    // side-effect is to set jaxbElement
     }
-    
+
     private static void initKnownStyles() {
 
 //    	Throwable t = new Throwable();
 //    	t.printStackTrace();
-    	
+
 		java.io.InputStream is = null;
 		try {
 			is = org.docx4j.utils.ResourceUtils.getResource(
-					"org/docx4j/openpackaging/parts/WordprocessingML/KnownStyles.xml");						
-			
-			JAXBContext jc = Context.jc;
-			Unmarshaller u = jc.createUnmarshaller();			
+					"org/docx4j/openpackaging/parts/WordprocessingML/KnownStyles.xml");
+
+			JAXBContext jc = Context.getJc();
+			Unmarshaller u = jc.createUnmarshaller();
 			u.setEventHandler(new org.docx4j.jaxb.JaxbValidationEventHandler());
 
-			org.docx4j.wml.Styles styles = (org.docx4j.wml.Styles)u.unmarshal( is );			
-			
+			org.docx4j.wml.Styles styles = (org.docx4j.wml.Styles)u.unmarshal( is );
+
 			knownStyles = new java.util.HashMap<String, org.docx4j.wml.Style>();
-			
-			for ( org.docx4j.wml.Style s : styles.getStyle() ) {				
-				knownStyles.put(s.getStyleId(), s);				
+
+			for ( org.docx4j.wml.Style s : styles.getStyle() ) {
+				knownStyles.put(s.getStyleId(), s);
 			}
-			
+
 		} catch (Exception e) {
 			// TODO Auto-generated catch block
 			e.printStackTrace();
-		}    		
-    	
-		
+		}
+
+
     }
 
 	/**
@@ -188,13 +186,13 @@ public final class StyleDefinitionsPart extends JaxbXmlPartXPathAware<Styles> {
 		}
 		return knownStyles;
 	}
-    
+
 	private Style styleDocDefaults;
-	
+
 	/**
-	 * Manufacture a paragraph style from the following, so it can be used as the 
+	 * Manufacture a paragraph style from the following, so it can be used as the
 	 * root of our paragraph style tree.
-	 * 
+	 *
 	 * 	<w:docDefaults>
 			<w:rPrDefault>
 				<w:rPr>
@@ -210,22 +208,22 @@ public final class StyleDefinitionsPart extends JaxbXmlPartXPathAware<Styles> {
 				</w:pPr>
 			</w:pPrDefault>
 		</w:docDefaults>
-		
+
 		BEWARE: in a table, paragraph style ppr trumps table style ppr.
 		The effect of including w:docDefaults in the style hierarchy
 		is that they trump table style ppr, but they should not!
-		
+
 	 * There is no need for a doc defaults character style.
 	 * The reason for this is that Word seems to ignore Default Paragraph Style!
 	 * So the run formatting comes from paragraph style + explicit character style (if any),
 	 * plus direct formatting.
-		
+
 
 	 */
     public void createVirtualStylesForDocDefaults() throws Docx4JException {
-    	
+
     	if (styleDocDefaults!=null) return; // been done already
-    	
+
     	String ROOT_NAME = "DocDefaults";
 
     	// could be in docx which we saved and are now re-opening
@@ -234,34 +232,34 @@ public final class StyleDefinitionsPart extends JaxbXmlPartXPathAware<Styles> {
 
         	styleDocDefaults = Context.getWmlObjectFactory().createStyle();
         	styleDocDefaults.setStyleId(ROOT_NAME);
-        	
+
     		this.getJaxbElement().getStyle().add(styleDocDefaults);
-    		
+
     	} else {
-    		
+
     		log.info("Found existing style named " + ROOT_NAME);
     		log.debug(XmlUtils.marshaltoString(styleDocDefaults, true, true));
-    		
+
         	// TODO: could be a name collision; some other app using that name :-(
     		// We could check whether normal is based on it (see towards end of this method)
-    		
+
     		if (styleDocDefaults.getRPr()!=null) {
         		log.debug(".. reusing");
     			return;
     		} else {
-        		log.debug(".. but no rPr, so re-creating");    			
+        		log.debug(".. but no rPr, so re-creating");
     		}
     	}
-    	
+
     	styleDocDefaults.setType("paragraph");
-    	
+
 		org.docx4j.wml.Style.Name n = Context.getWmlObjectFactory().createStyleName();
     	n.setVal(ROOT_NAME);
     	styleDocDefaults.setName(n);
-    			
-		// Initialise docDefaults		
-		DocDefaults docDefaults = this.getJaxbElement().getDocDefaults(); 		
-		
+
+		// Initialise docDefaults
+		DocDefaults docDefaults = this.getJaxbElement().getDocDefaults();
+
 		if (docDefaults == null) {
 			log.warn("No DocDefaults present");
 			// The only way this can happen is if the
@@ -297,7 +295,7 @@ public final class StyleDefinitionsPart extends JaxbXmlPartXPathAware<Styles> {
 				documentDefaultPPr = Context.getWmlObjectFactory().createPPr();
 			}
 		}
-		
+
 		// If the docDefaults have no setting for w:spacing
 		// then add it:
 		if (documentDefaultPPr.getSpacing()==null) {
@@ -328,7 +326,7 @@ public final class StyleDefinitionsPart extends JaxbXmlPartXPathAware<Styles> {
 			// If default font size is not specified, set it to match Word default when unspecified (ie 10)
 			// It is useful to have this explicitly, especially for XHTML Import
 //	        <w:sz w:val="20"/>
-//	        <w:szCs w:val="20"/>			
+//	        <w:szCs w:val="20"/>
 			if (documentDefaultRPr.getSz()==null) {
 				HpsMeasure s10pt = Context.getWmlObjectFactory().createHpsMeasure();
 				s10pt.setVal(BigInteger.valueOf(20));
@@ -340,10 +338,10 @@ public final class StyleDefinitionsPart extends JaxbXmlPartXPathAware<Styles> {
 				documentDefaultRPr.setSzCs(s10pt);
 			}
 		}
-    	
+
 		styleDocDefaults.setPPr(documentDefaultPPr);
 		styleDocDefaults.setRPr(documentDefaultRPr);
-		
+
 		// Now point Normal at this
 		Style normal = getDefaultParagraphStyle();
 		if (normal==null) {
@@ -351,33 +349,33 @@ public final class StyleDefinitionsPart extends JaxbXmlPartXPathAware<Styles> {
 			normal = Context.getWmlObjectFactory().createStyle();
 			normal.setType("paragraph");
 			normal.setStyleId("Normal");
-			
+
 			n = Context.getWmlObjectFactory().createStyleName();
 			n.setVal("Normal");
 			normal.setName(n);
-			this.getJaxbElement().getStyle().add(normal);			
+			this.getJaxbElement().getStyle().add(normal);
 		}
-		
+
 		BasedOn based = Context.getWmlObjectFactory().createStyleBasedOn();
-		based.setVal(ROOT_NAME);		
+		based.setVal(ROOT_NAME);
 		normal.setBasedOn(based);
-		
+
 		log.info("Set virtual style, id '" + styleDocDefaults.getStyleId() + "', name '"+ styleDocDefaults.getName().getVal() + "'");
-		
+
 		log.debug(XmlUtils.marshaltoString(styleDocDefaults, true, true));
-		
-		
-    	
+
+
+
     }
-    
+
     /**
      * @param id
      * @return
      * @since 3.0.0
      */
     public Style getStyleById(String id) {
-    	
-		return getStyleById( this.getJaxbElement().getStyle(), id ); 				
+
+		return getStyleById( this.getJaxbElement().getStyle(), id );
 
     }
 
@@ -387,18 +385,18 @@ public final class StyleDefinitionsPart extends JaxbXmlPartXPathAware<Styles> {
      * @since 3.0.1
      */
     private static Style getStyleById(List<Style> styles, String id) {
-    	
-		for ( org.docx4j.wml.Style s : styles ) {				
+
+		for ( org.docx4j.wml.Style s : styles ) {
 			if( s.getStyleId().equals(id) ) {
 				return s;
 			}
 		}
     	return null;
     }
-    
+
     private Style defaultCharacterStyle;
     public Style getDefaultCharacterStyle() {
-    	
+
     	if (defaultCharacterStyle==null) {
     		defaultCharacterStyle = getDefaultStyle("character");
     	}
@@ -415,14 +413,14 @@ public final class StyleDefinitionsPart extends JaxbXmlPartXPathAware<Styles> {
     	}
 		return defaultCharacterStyle;
     }
-    
+
     private final static String DEFAULT_CHARACTER_STYLE_DEFAULT = "<w:style w:type=\"character\" w:default=\"1\" w:styleId=\"DefaultParagraphFont\" " + Namespaces.W_NAMESPACE_DECLARATION + "><w:name w:val=\"Default Paragraph Font\" /></w:style>";
-    
-    
-    
+
+
+
     private Style defaultParagraphStyle;
     public Style getDefaultParagraphStyle() {
-    	
+
     	if (defaultParagraphStyle==null) {
     		defaultParagraphStyle = getDefaultStyle("paragraph");
     	}
@@ -430,7 +428,7 @@ public final class StyleDefinitionsPart extends JaxbXmlPartXPathAware<Styles> {
     	// doesn't set default, so use name
     	// (alternatively, could use id=style0)
     	if (defaultParagraphStyle==null) {
-    		for ( org.docx4j.wml.Style s : this.getJaxbElement().getStyle() ) {				
+    		for ( org.docx4j.wml.Style s : this.getJaxbElement().getStyle() ) {
     			if( s.getType().equals("paragraph")
     					&& s.getName()!=null
     					&& s.getName().getVal().equals("Default") ) {
@@ -438,38 +436,38 @@ public final class StyleDefinitionsPart extends JaxbXmlPartXPathAware<Styles> {
     				defaultParagraphStyle=s;
     				break;
     			}
-    		}    		
+    		}
     	}
     	// try using id=style0
     	if (defaultParagraphStyle==null) {
-    		for ( org.docx4j.wml.Style s : this.getJaxbElement().getStyle() ) {				
+    		for ( org.docx4j.wml.Style s : this.getJaxbElement().getStyle() ) {
     			if( s.getType().equals("paragraph")
     					&& s.getStyleId().equals("style0") ) {
     				log.info("Style with name " + s.getName().getVal() + ", id '" + s.getStyleId() + "' is default " + s.getType() + " style");
     				defaultParagraphStyle=s;
     				break;
     			}
-    		}    		
+    		}
     	}
-    	
+
 		return defaultParagraphStyle;
     }
-    
+
     private Style defaultTableStyle;
     /**
      * @since 3.0
      */
     public Style getDefaultTableStyle() {
-    	
+
     	if (defaultTableStyle==null) {
     		defaultTableStyle = getDefaultStyle("table");
     	}
 		return defaultTableStyle;
     }
-    
+
     private Style getDefaultStyle(String type) {
-    	
-		for ( org.docx4j.wml.Style s : this.getJaxbElement().getStyle() ) {				
+
+		for ( org.docx4j.wml.Style s : this.getJaxbElement().getStyle() ) {
 			if( s.isDefault() && s.getType().equals(type)) {
 				log.info("Style with name " + s.getName().getVal() + ", id '" + s.getStyleId() + "' is default " + s.getType() + " style");
 				return s;
@@ -477,12 +475,12 @@ public final class StyleDefinitionsPart extends JaxbXmlPartXPathAware<Styles> {
 		}
 		return null;
     }
-    
-    
-	final static String wNamespaceDec = " xmlns:w=\"" + Namespaces.NS_WORD12 + "\""; 
+
+
+	final static String wNamespaceDec = " xmlns:w=\"" + Namespaces.NS_WORD12 + "\"";
 
 	public final static String rPrDefaultsString = "<w:rPr" + wNamespaceDec + ">"
-		// Word 2007 still uses Times New Roman if there is no theme part, and we'd like to replicate that 
+		// Word 2007 still uses Times New Roman if there is no theme part, and we'd like to replicate that
         // + "<w:rFonts w:asciiTheme=\"minorHAnsi\" w:eastAsiaTheme=\"minorHAnsi\" w:hAnsiTheme=\"minorHAnsi\" w:cstheme=\"minorBidi\" />"
         + "<w:sz w:val=\"20\" />"  // was 11 prior to 3.01, but Word default in absence of this setting is 10.
         + "<w:szCs w:val=\"20\" />"
@@ -499,14 +497,14 @@ public final class StyleDefinitionsPart extends JaxbXmlPartXPathAware<Styles> {
 	    + 	pPrDefaultsString
 	    + "</w:pPrDefault>"
 	  + "</w:docDefaults>";
-	
+
 
 	/**
 	 * It is convenient to have a CSS representation of styles,
 	 * and this part is a natural place to store it.
-	 * 
+	 *
 	 * HtmlCssHelper contains a method createCssForStyles which
-	 * relies on StyleTree to generate CSS.  
+	 * relies on StyleTree to generate CSS.
 	 */
 	private String css;
 	public String getCss() {
@@ -515,16 +513,16 @@ public final class StyleDefinitionsPart extends JaxbXmlPartXPathAware<Styles> {
 	public void setCss(String css) {
 		this.css = css;
 	}
-	
+
 	/**
 	 * For a run/character style return its linked paragraph style (if any),
 	 * or vice versa.
-	 * 
+	 *
 	 * @param rStyleVal
 	 * @return
 	 */
 	public Style getLinkedStyle(String rStyleVal) {
-		
+
 		Style rStyle = getStyleById(rStyleVal);
 		if (rStyle==null) {
 			log.warn("Couldn't find rStyle " + rStyleVal);
@@ -533,28 +531,28 @@ public final class StyleDefinitionsPart extends JaxbXmlPartXPathAware<Styles> {
 			// We have a run level style.  Is there a linked pStyle?
 			Style.Link linkedStyle = rStyle.getLink();
 			if (linkedStyle==null) {
-				log.warn("No linked style for rStyle " + rStyleVal);							
+				log.warn("No linked style for rStyle " + rStyleVal);
 				return null;
 			} else {
 				String pStyleVal = linkedStyle.getVal();
 				log.debug(rStyleVal + " is linked to style " + pStyleVal );
 				Style pStyle = getStyleById(pStyleVal);
-				
+
 				if (pStyle==null) {
-					log.warn("Couldn't find linked pStyle " + pStyleVal 
-							+ " for rStyle " + rStyleVal);		
+					log.warn("Couldn't find linked pStyle " + pStyleVal
+							+ " for rStyle " + rStyleVal);
 				}
 				return pStyle;
 			}
 		}
 	}
 
-	
-    
+
+
 //	public static void main(String[] args) throws Exception {
-//		
-//		StyleDefinitionsPart sdp = new StyleDefinitionsPart ();		
+//
+//		StyleDefinitionsPart sdp = new StyleDefinitionsPart ();
 //		sdp.initKnownStyles();
-//    
-//	}    
+//
+//	}
 }
