@@ -1,25 +1,25 @@
 /*
  *  Copyright 2007-2013, Plutext Pty Ltd.
- *   
+ *
  *  This file is part of docx4j.
 
-    docx4j is licensed under the Apache License, Version 2.0 (the "License"); 
-    you may not use this file except in compliance with the License. 
+    docx4j is licensed under the Apache License, Version 2.0 (the "License");
+    you may not use this file except in compliance with the License.
 
-    You may obtain a copy of the License at 
+    You may obtain a copy of the License at
 
-        http://www.apache.org/licenses/LICENSE-2.0 
+        http://www.apache.org/licenses/LICENSE-2.0
 
-    Unless required by applicable law or agreed to in writing, software 
-    distributed under the License is distributed on an "AS IS" BASIS, 
-    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. 
-    See the License for the specific language governing permissions and 
+    Unless required by applicable law or agreed to in writing, software
+    distributed under the License is distributed on an "AS IS" BASIS,
+    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+    See the License for the specific language governing permissions and
     limitations under the License.
 
  */
 
 
-package org.docx4j.wml; 
+package org.docx4j.wml;
 
 import javax.xml.bind.Unmarshaller;
 import javax.xml.bind.annotation.XmlAccessType;
@@ -30,9 +30,9 @@ import javax.xml.bind.annotation.XmlType;
 
 /**
  * <p>Java class for CT_RPrChange complex type.
- * 
+ *
  * <p>The following schema fragment specifies the expected content contained within this class.
- * 
+ *
  * <pre>
  * &lt;complexType name="CT_RPrChange">
  *   &lt;complexContent>
@@ -54,8 +54,8 @@ import javax.xml.bind.annotation.XmlType;
  *   &lt;/complexContent>
  * &lt;/complexType>
  * </pre>
- * 
- * 
+ *
+ *
  */
 @XmlAccessorType(XmlAccessType.FIELD)
 @XmlType(name = "CT_RPrChange", propOrder = {
@@ -70,11 +70,11 @@ public class CTRPrChange
 
     /**
      * Gets the value of the rPr property.
-     * 
+     *
      * @return
      *     possible object is
      *     {@link CTRPrChange.RPr }
-     *     
+     *
      */
     public CTRPrChange.RPr getRPr() {
         return rPr;
@@ -82,11 +82,11 @@ public class CTRPrChange
 
     /**
      * Sets the value of the rPr property.
-     * 
+     *
      * @param value
      *     allowed object is
      *     {@link CTRPrChange.RPr }
-     *     
+     *
      */
     public void setRPr(CTRPrChange.RPr value) {
         this.rPr = value;
@@ -94,7 +94,7 @@ public class CTRPrChange
 
     /**
      * This method is invoked by the JAXB implementation on each instance when unmarshalling completes.
-     * 
+     *
      * @param parent
      *     The parent object in the object tree.
      * @param unmarshaller
@@ -108,9 +108,9 @@ public class CTRPrChange
 
     /**
      * <p>Java class for anonymous complex type.
-     * 
+     *
      * <p>The following schema fragment specifies the expected content contained within this class.
-     * 
+     *
      * <pre>
      * &lt;complexType>
      *   &lt;complexContent>
@@ -122,8 +122,8 @@ public class CTRPrChange
      *   &lt;/complexContent>
      * &lt;/complexType>
      * </pre>
-     * 
-     * 
+     *
+     *
      */
     @XmlAccessorType(XmlAccessType.FIELD)
     @XmlType(name = "", propOrder = {
@@ -165,11 +165,23 @@ public class CTRPrChange
         "lang",
         "eastAsianLayout",
         "specVanish",
-        "oMath"
+        "oMath",
+        "glow",
+        "shadow2",
+        "reflection",
+        "textOutline",
+        "textFill",
+        "scene3d",
+        "props3d",
+        "ligatures",
+        "numForm",
+        "numSpacing",
+        "stylisticSets",
+        "cntxtAlts"
     })
     public static class RPr extends RPrBase
     {
-    	// 
+    	//
     }
 
 }
