@@ -25,7 +25,6 @@ import org.docx4j.IndexedNodeList;
 import org.jvnet.jaxb2_commons.ppp.Child;
 
 import java.math.BigInteger;
-import java.util.ArrayList;
 import java.util.List;
 
 import javax.xml.bind.JAXBElement;
@@ -39,6 +38,9 @@ import javax.xml.bind.annotation.XmlRootElement;
 import javax.xml.bind.annotation.XmlTransient;
 import javax.xml.bind.annotation.XmlType;
 
+import org.docx4j.mce.AlternateContent;
+import org.docx4j.mce.AlternateContent.Choice;
+import org.docx4j.mce.AlternateContent.Fallback;
 
 /**
  * <p>Java class for anonymous complex type.
@@ -105,7 +107,8 @@ public class R implements Child, ContentAccessor
         @XmlElementRef(name = "delInstrText", namespace = "http://schemas.openxmlformats.org/wordprocessingml/2006/main", type = JAXBElement.class),
         @XmlElementRef(name = "footnoteRef", namespace = "http://schemas.openxmlformats.org/wordprocessingml/2006/main", type = JAXBElement.class),
         @XmlElementRef(name = "dayLong", namespace = "http://schemas.openxmlformats.org/wordprocessingml/2006/main", type = JAXBElement.class),
-        @XmlElementRef(name = "delText", namespace = "http://schemas.openxmlformats.org/wordprocessingml/2006/main", type = DelText.class)
+        @XmlElementRef(name = "delText", namespace = "http://schemas.openxmlformats.org/wordprocessingml/2006/main", type = DelText.class),
+        @XmlElementRef(name = "alternateContent", namespace = "http://schemas.openxmlformats.org/markup-compatibility/2006", type = AlternateContent.class)
     })
     protected IndexedNodeList<Object> content;
     @XmlAttribute(name = "rsidRPr", namespace = "http://schemas.openxmlformats.org/wordprocessingml/2006/main")
@@ -190,6 +193,7 @@ public class R implements Child, ContentAccessor
      * {@link JAXBElement }{@code <}{@link Text }{@code >}
      * {@link JAXBElement }{@code <}{@link R.FootnoteRef }{@code >}
      * {@link DelText }
+     * {@link AlternateContent }
      * {@link JAXBElement }{@code <}{@link R.DayLong }{@code >}
      * 
      * @since 2.7
@@ -303,9 +307,46 @@ public class R implements Child, ContentAccessor
      */
     public void afterUnmarshal(Unmarshaller unmarshaller, Object parent) {
         setParent(parent);
+ 
+        final IndexedNodeList<Object> nodeList = getContent();
+        for(int i=0; i<nodeList.size(); i++) {
+        	final Object o = nodeList.get(i);
+        	if(o instanceof AlternateContent) {
+                // removing each alternate content that we don't understand
+        		final List<Choice> choices = ((AlternateContent)o).getChoice();
+                for(int j=0; j<choices.size(); j++) {
+                	final String requires = choices.get(j).getRequires();
+                	if(requires.equals("wps")) {		// WordprocessingShape
+                		continue;
+                	}
+                	else if(requires.equals("wpg")) {	// WordprocessingGroup
+                		continue;
+                	}
+                	else if(requires.equals("wpc")) {	// WordprocessingCanvas
+                		continue;
+                	}
+                	else {
+                		// removing unsupported choices
+                		choices.remove(j--);
+                	}
+                }
+                if(choices.isEmpty()) {
+                	// removing alternate content and replacing it with the fallback value
+                	nodeList.remove(i);
+                	final Fallback fallback = ((AlternateContent)o).getFallback();
+                	if(fallback!=null) {
+                		for(Object f:fallback.getAny()) {
+                			if(f instanceof Child) {
+                				((Child)f).setParent(this);
+                			}
+                			nodeList.add(i++, f);
+                		}
+                	}
+                }
+        	}
+        }
     }
 
-
     /**
      * <p>Java class for anonymous complex type.
      * 
