@@ -20,7 +20,6 @@
 package org.xlsx4j.sml;
 
 import java.util.ArrayList;
-import java.util.HashMap;
 import java.util.Iterator;
 import java.util.List;
 import java.util.Map;
@@ -31,12 +30,12 @@ import javax.xml.bind.Unmarshaller;
 import javax.xml.bind.annotation.XmlAccessType;
 import javax.xml.bind.annotation.XmlAccessorType;
 import javax.xml.bind.annotation.XmlAttribute;
+import javax.xml.bind.annotation.XmlElement;
 import javax.xml.bind.annotation.XmlRootElement;
 import javax.xml.bind.annotation.XmlSchemaType;
 import javax.xml.bind.annotation.XmlTransient;
 import javax.xml.bind.annotation.XmlType;
 
-import org.jvnet.jaxb2_commons.ppp.Child;
 import org.xlsx4j.jaxb.Context;
 
 
@@ -90,45 +89,24 @@ import org.xlsx4j.jaxb.Context;
     "ph"
 })
 @XmlRootElement(name = "row")
-public class Row implements Child
+public class Row
 {
     protected List<Cell> c;
     @XmlTransient
     private TreeMap<Integer, Cell> cells_impl;
-    protected CTExtensionList extLst;
+    @XmlTransient
+    private RowDataReadonly rowData = RowDataReadonly.EmptyRow;
     @XmlAttribute(name = "r")
     @XmlSchemaType(name = "unsignedInt")
     protected Long r;
-    @XmlAttribute(name = "spans")
-    protected List<String> spans;
-    @XmlAttribute(name = "s")
-    @XmlSchemaType(name = "unsignedInt")
-    protected Long s;
-//  @XmlAttribute(name = "customFormat")	// 0x0003
-//  protected Boolean customFormat;
-    @XmlAttribute(name = "ht")
-    protected Double ht;
-//  @XmlAttribute(name = "hidden")			// 0x000c
-//  protected Boolean hidden;
-//  @XmlAttribute(name = "customHeight")	// 0x0030
-//  protected Boolean customHeight;
-    @XmlAttribute(name = "outlineLevel")
-    @XmlSchemaType(name = "unsignedByte")
-    protected Short outlineLevel;
-//  @XmlAttribute(name = "collapsed")		// 0x00c0
-//  protected Boolean collapsed;
-//  @XmlAttribute(name = "thickTop")		// 0x0300
-//  protected Boolean thickTop;
-//  @XmlAttribute(name = "thickBot")		// 0x0c00
-//  protected Boolean thickBot;
-//  @XmlAttribute(name = "ph")				// 0x3000
-//  protected Boolean ph;
-    @XmlTransient
-    private Object parent;
-    @XmlTransient
-    private Long maxSi;
-    @XmlTransient
-    int flags;
+
+    public RowDataReadonly getRowData() {
+    	return rowData;
+    }
+
+    public void setRowData(RowDataReadonly value) {
+    	rowData = value;
+    }
 
     /**
      * Gets the value of the c property.
@@ -183,11 +161,13 @@ public class Row implements Child
         Cell cell = treeMap.get(column);
         if(forceCreate&&cell==null) {
 
-            // creating a new cell...
-        	org.docx4j.jaxb.Context.checkMemory();
+            org.docx4j.jaxb.Context.abortOnLowMemory();
 
+            if(column<0||column>16383) {
+                throw new RuntimeException();
+            }
+            // creating a new cell...
             cell = Context.getsmlObjectFactory().createCell();
-            cell.setParent(this);
             cell.setColumn(column);
             treeMap.put(column, cell);
         }
@@ -221,15 +201,14 @@ public class Row implements Child
         }
         for(i=0;i<count;i++) {
             final Cell cellClone = Context.getsmlObjectFactory().createCell();
-            cellClone.setParent(this);
             cellClone.setColumn(start+i);
             if(previousCell!=null) {
-                cellClone.setS(previousCell.getS());
+                cellClone.setS(previousCell.getStyle());
             }
             if(previousCell!=null&&i==0) {
                 SheetData.ApplyBorderStyle(stylesheet, cellClone, nextCell);
             }
-            if(cellClone.getS()==0L) {
+            if(cellClone.getStyle()==0L) {
             	// not inserting default cells
             	break;
             }
@@ -274,30 +253,6 @@ public class Row implements Child
     	return getListArray().iterator();
     }
 
-    /**
-     * Gets the value of the extLst property.
-     *
-     * @return
-     *     possible object is
-     *     {@link CTExtensionList }
-     *
-     */
-    public CTExtensionList getExtLst() {
-        return extLst;
-    }
-
-    /**
-     * Sets the value of the extLst property.
-     *
-     * @param value
-     *     allowed object is
-     *     {@link CTExtensionList }
-     *
-     */
-    public void setExtLst(CTExtensionList value) {
-        this.extLst = value;
-    }
-
     /**
      * Gets the value of the r property.
      *
@@ -330,36 +285,6 @@ public class Row implements Child
     	r = new Long(row+1);
     }
 
-    
-    /**
-     * Gets the value of the spans property.
-     *
-     * <p>
-     * This accessor method returns a reference to the live list,
-     * not a snapshot. Therefore any modification you make to the
-     * returned list will be present inside the JAXB object.
-     * This is why there is not a <CODE>set</CODE> method for the spans property.
-     *
-     * <p>
-     * For example, to add a new item, do as follows:
-     * <pre>
-     *    getSpans().add(newItem);
-     * </pre>
-     *
-     *
-     * <p>
-     * Objects of the following type(s) are allowed in the list
-     * {@link String }
-     *
-     *
-     */
-    public List<String> getSpans() {
-        if (spans == null) {
-            spans = new ArrayList<String>();
-        }
-        return this.spans;
-    }
-
     /**
      * Gets the value of the s property.
      *
@@ -368,335 +293,165 @@ public class Row implements Child
      *     {@link Long }
      *
      */
-    public long getS() {
-        if (s == null) {
-            return  0L;
-        } else {
-            return s;
-        }
+    @XmlAttribute(name = "s")
+    @XmlSchemaType(name = "unsignedInt")
+    public Long getS() {
+    	return rowData.getS();
     }
 
-    /**
-     * Sets the value of the s property.
-     *
-     * @param value
-     *     allowed object is
-     *     {@link Long }
-     *
-     */
     public void setS(Long value) {
-        this.s = value;
+    	if(!(rowData instanceof RowDataWritable)) {
+    		rowData  = new RowDataWritable(rowData);
+    	}
+    	((RowDataWritable)rowData).setS(value);
+    }
+
+    public long getStyle() {
+    	if(rowData.getS()==null) {
+    		return 0L;
+    	}
+    	return rowData.getS().longValue();
+    }
+
+    @XmlAttribute(name = "ht")
+    public Double getHt() {
+        return rowData.getHt();
+    }
+
+    public void setHt(Double value) {
+    	if(!(rowData instanceof RowDataWritable)) {
+    		rowData = new RowDataWritable(rowData);
+    	}
+    	((RowDataWritable)rowData).setHt(value);
+    }
+
+    @XmlAttribute(name = "outlineLevel")
+    @XmlSchemaType(name = "unsignedByte")
+    public Short getOutlineLevel() {
+    	return rowData.getOutlineLevel();
+    }
+
+    public void setOutlineLevel(Short value) {
+    	if(!(rowData instanceof RowDataWritable)) {
+    		rowData = new RowDataWritable(rowData);
+    	}
+    	((RowDataWritable)rowData).setOutlineLevel(value);
+    }
+
+    @XmlAttribute(name = "spans")
+    public List<String> getSpans() {
+        return null;
+    }
+
+    public void setSpans(List<String> value) {
+        // we are removing spans when writing as this is only an
+        // optimizing feature.. so we don't need to update these spans
+    }
+
+    @XmlElement
+    public CTExtensionList getExtLst() {
+        return rowData.getExtLst();
+    }
+
+    public void setExtLst(CTExtensionList value) {
+    	if(!(rowData instanceof RowDataWritable)) {
+    		rowData = new RowDataWritable(rowData);
+    	}
+    	((RowDataWritable)rowData).setExtLst(value);
     }
 
-    /**
-     * Gets the value of the customFormat property.
-     *
-     * @return
-     *     possible object is
-     *     {@link Boolean }
-     *
-     */
     @XmlAttribute
     public Boolean isCustomFormat() {
-        if ((flags&0x1)==0) {
-            return null;
-        }
-        return (flags&0x2)!=0;
+    	return rowData.isCustomFormat();
     }
 
-    /**
-     * Sets the value of the customFormat property.
-     *
-     * @param value
-     *     allowed object is
-     *     {@link Boolean }
-     *
-     */
     public void setCustomFormat(Boolean value) {
-		flags&=~0x3;
-    	if(value!=null) {
-    		flags|=value.booleanValue()?0x3:0x1;
+    	if(!(rowData instanceof RowDataWritable)) {
+    		rowData = new RowDataWritable(rowData);
     	}
+    	((RowDataWritable)rowData).setCustomFormat(value);
     }
 
-    /**
-     * Gets the value of the ht property.
-     *
-     * @return
-     *     possible object is
-     *     {@link Double }
-     *
-     */
-    public Double getHt() {
-        return ht;
-    }
-
-    /**
-     * Sets the value of the ht property.
-     *
-     * @param value
-     *     allowed object is
-     *     {@link Double }
-     *
-     */
-    public void setHt(Double value) {
-        this.ht = value;
-    }
-
-    /**
-     * Gets the value of the hidden property.
-     *
-     * @return
-     *     possible object is
-     *     {@link Boolean }
-     *
-     */
     @XmlAttribute
     public Boolean isHidden() {
-        if ((flags&0x4)==0) {
-            return null;
-        }
-        return (flags&0x8)!=0;
+    	return rowData.isHidden();
     }
 
-    /**
-     * Sets the value of the hidden property.
-     *
-     * @param value
-     *     allowed object is
-     *     {@link Boolean }
-     *
-     */
     public void setHidden(Boolean value) {
-		flags&=~0xc;
-    	if(value!=null) {
-    		flags|=value.booleanValue()?0xc:0x4;
+    	if(!(rowData instanceof RowDataWritable)) {
+    		rowData = new RowDataWritable(rowData);
     	}
+    	((RowDataWritable)rowData).setHidden(value);
     }
 
-    /**
-     * Gets the value of the customHeight property.
-     *
-     * @return
-     *     possible object is
-     *     {@link Boolean }
-     *
-     */
     @XmlAttribute
     public Boolean isCustomHeight() {
-        if ((flags&0x10)==0) {
-            return null;
-        }
-        return (flags&0x20)!=0;
+    	return rowData.isCustomHeight();
     }
 
-    /**
-     * Sets the value of the customHeight property.
-     *
-     * @param value
-     *     allowed object is
-     *     {@link Boolean }
-     *
-     */
     public void setCustomHeight(Boolean value) {
-		flags&=~0x30;
-    	if(value!=null) {
-    		flags|=value.booleanValue()?0x30:0x10;
+    	if(!(rowData instanceof RowDataWritable)) {
+    		rowData = new RowDataWritable(rowData);
     	}
+    	((RowDataWritable)rowData).setCustomHeight(value);
     }
 
-    /**
-     * Gets the value of the outlineLevel property.
-     *
-     * @return
-     *     possible object is
-     *     {@link Short }
-     *
-     */
-    public short getOutlineLevel() {
-        if (outlineLevel == null) {
-            return ((short) 0);
-        } else {
-            return outlineLevel;
-        }
-    }
-
-    /**
-     * Sets the value of the outlineLevel property.
-     *
-     * @param value
-     *     allowed object is
-     *     {@link Short }
-     *
-     */
-    public void setOutlineLevel(Short value) {
-        this.outlineLevel = value;
-    }
-
-    /**
-     * Gets the value of the collapsed property.
-     *
-     * @return
-     *     possible object is
-     *     {@link Boolean }
-     *
-     */
     @XmlAttribute
     public Boolean isCollapsed() {
-        if ((flags&0x40)==0) {
-            return null;
-        }
-        return (flags&0x80)!=0;
+    	return rowData.isCollapsed();
     }
 
-    /**
-     * Sets the value of the collapsed property.
-     *
-     * @param value
-     *     allowed object is
-     *     {@link Boolean }
-     *
-     */
     public void setCollapsed(Boolean value) {
-		flags&=~0xc0;
-		if(value!=null) {
-			flags|=value.booleanValue()?0xc0:0x40;
-		}
+    	if(!(rowData instanceof RowDataWritable)) {
+    		rowData = new RowDataWritable(rowData);
+    	}
+    	((RowDataWritable)rowData).setCollapsed(value);
     }
 
-    /**
-     * Gets the value of the thickTop property.
-     *
-     * @return
-     *     possible object is
-     *     {@link Boolean }
-     *
-     */
     @XmlAttribute
     public Boolean isThickTop() {
-        if ((flags&0x100)==0) {
-            return null;
-        }
-        return (flags&0x200)!=0;
+    	return rowData.isThickTop();
     }
 
-    /**
-     * Sets the value of the thickTop property.
-     *
-     * @param value
-     *     allowed object is
-     *     {@link Boolean }
-     *
-     */
     public void setThickTop(Boolean value) {
-		flags&=~0x300;
-    	if(value!=null) {
-    		flags|=value.booleanValue()?0x300:0x100;
+    	if(!(rowData instanceof RowDataWritable)) {
+    		rowData = new RowDataWritable(rowData);
     	}
+    	((RowDataWritable)rowData).setThickTop(value);
     }
 
-    /**
-     * Gets the value of the thickBot property.
-     *
-     * @return
-     *     possible object is
-     *     {@link Boolean }
-     *
-     */
     @XmlAttribute
     public Boolean isThickBot() {
-        if ((flags&0x400)==0) {
-            return null;
-        }
-        return (flags&0x800)!=0;
+    	return rowData.isThickBot();
     }
 
-    /**
-     * Sets the value of the thickBot property.
-     *
-     * @param value
-     *     allowed object is
-     *     {@link Boolean }
-     *
-     */
     public void setThickBot(Boolean value) {
-		flags&=~0xc00;
-    	if(value!=null) {
-    		flags|=value.booleanValue()?0xc00:0x400;
+    	if(!(rowData instanceof RowDataWritable)) {
+    		rowData = new RowDataWritable(rowData);
     	}
+    	((RowDataWritable)rowData).setThickBot(value);
     }
 
-    /**
-     * Gets the value of the ph property.
-     *
-     * @return
-     *     possible object is
-     *     {@link Boolean }
-     *
-     */
     @XmlAttribute
     public Boolean isPh() {
-        if ((flags&0x1000)==0) {
-            return null;
-        }
-        return (flags&0x2000)!=0;
+    	return rowData.isPh();
     }
 
-    /**
-     * Sets the value of the ph property.
-     *
-     * @param value
-     *     allowed object is
-     *     {@link Boolean }
-     *
-     */
     public void setPh(Boolean value) {
-		flags&=~0x3000;
-    	if(value!=null) {
-    		flags|=value.booleanValue()?0x3000:0x1000;
+    	if(!(rowData instanceof RowDataWritable)) {
+    		rowData = new RowDataWritable(rowData);
     	}
+    	((RowDataWritable)rowData).setPh(value);
     }
 
-    /**
-     * Gets the parent object in the object tree representing the unmarshalled xml document.
-     *
-     * @return
-     *     The parent object.
-     */
-    @Override
-    public Object getParent() {
-        return this.parent;
-    }
-
-    @Override
-    public void setParent(Object parent) {
-        this.parent = parent;
-    }
-
-    public void setSi(long si) {
-        if(maxSi==null) {
-            maxSi = si;
-        }
-        else if(si>maxSi) {
-            maxSi = si;
-        }
-    }
-
-    public int getLastColumnNumber() {
-    	if(c!=null&&!c.isEmpty()) {
-    		return c.get(c.size()-1).getColumn();
-    	}
-    	else if (cells_impl!=null&&!cells_impl.isEmpty()) {
-    		return cells_impl.lastKey();
-    	}
-    	return -1;
-    }
-
-    @SuppressWarnings("unused")
     public void beforeMarshal(Marshaller marshaller) {
-        getListArray();
+        final List<Cell> cells = getListArray();
+        for(Cell cell:cells) {
+        	// we have to convert cell column into cell.R
+    		cell.setR(SmlUtils.getCellRef(cell.getColumn(), getRow()));
+        }
     }
-    
+
     /**
      * This method is invoked by the JAXB implementation on each instance when unmarshalling completes.
      *
@@ -706,13 +461,42 @@ public class Row implements Child
      *     The unmarshaller that generated the instance.
      */
     public void afterUnmarshal(Unmarshaller unmarshaller, Object _parent) {
-        setParent(_parent);
-        if(maxSi!=null&&_parent instanceof SheetData) {
-            ((SheetData)_parent).setSi(maxSi);
-        }
         if(r==null) {
         	setRow(((SheetData)_parent).getLastRowNumber()+1);
         }
-    	org.docx4j.jaxb.Context.checkMemory();
+
+        int currentColumn = 0;
+        Long maxSi = null;
+        final Iterator<Cell> iterator = createCellIterator();
+        while(iterator.hasNext()) {
+        	final Cell cell = iterator.next();
+        	// converting cell.R to column
+        	final String r = cell.getR();
+        	if(r!=null) {
+        		currentColumn = SmlUtils.createCellRef(r).getColumn();
+        	}
+        	cell.setColumn(currentColumn++);
+        	final CTCellFormula f = cell.getF();
+        	if(f!=null) {
+        		final Long si = f.getSi();
+	        	if(si!=null) {
+	        		if(maxSi==null) {
+	        			maxSi = si;
+	        		}
+	        		else if(si>maxSi) {
+	        			maxSi = si;
+	        		}
+	        	}
+        	}
+        	// using cell cache
+        	((SheetData)_parent).applyCachedCellData(cell);
+        }
+        // using the row cache
+        ((SheetData)_parent).applyCachedRowData(this);
+
+        if(maxSi!=null) {
+            ((SheetData)_parent).setSi(maxSi);
+        }
+        org.docx4j.jaxb.Context.abortOnLowMemory();
     }
 }
