@@ -19,8 +19,10 @@
  */
 package org.xlsx4j.sml;
 
+import java.lang.ref.WeakReference;
 import java.util.ArrayList;
 import java.util.Arrays;
+import java.util.HashMap;
 import java.util.Iterator;
 import java.util.List;
 import java.util.Map;
@@ -77,6 +79,72 @@ public class SheetData implements Child
     private TreeMap<Integer, Row> rows_impl;
     @XmlTransient
     private Long maxSi;
+    @XmlTransient
+    private HashMap<Integer, List<WeakReference<CellDataReadonly>>> cellCache = new HashMap<Integer, List<WeakReference<CellDataReadonly>>>();
+    @XmlTransient
+    private HashMap<Integer, List<WeakReference<RowDataReadonly>>> rowCache = new HashMap<Integer, List<WeakReference<RowDataReadonly>>>();
+
+    public void applyCachedCellData(Cell cell) {
+
+    	CellDataReadonly cellData = cell.getCellData();
+    	if(cellData instanceof CellDataWritable) {
+    		cellData = new CellDataReadonly(cellData);
+    		cell.setCellData(cellData);
+    	}
+    	final int cellHash = cellData.hashCode();
+    	List<WeakReference<CellDataReadonly>> cells = cellCache.get(cellHash);
+    	if(cells!=null) {
+    		for(int i=0; i<cells.size(); i++) {
+    			final WeakReference<CellDataReadonly> weakCellData = cells.get(i);
+    			final CellDataReadonly cellDataReadonly = weakCellData.get();
+    			if(cellDataReadonly==null) {
+    				cells.remove(i--);
+    			}
+    			else if(cellDataReadonly.equals(cellData)) {
+	    			// using existing cellData instance
+	    			cell.setCellData(cellDataReadonly);
+	    			return;
+    			}
+	    	}
+    	}
+    	else {
+    		cells = new ArrayList<WeakReference<CellDataReadonly>>(1);
+    		cellCache.put(cellHash, cells);
+    	}
+    	// adding new CachedCellData to the cache
+    	cells.add(new WeakReference<CellDataReadonly>(cellData));
+    }
+
+    public void applyCachedRowData(Row row) {
+
+    	RowDataReadonly rowData = row.getRowData();
+    	if(rowData instanceof RowDataWritable) {
+    		rowData = new RowDataReadonly(rowData);
+    		row.setRowData(rowData);
+    	}
+    	final int rowHash = rowData.hashCode();
+    	List<WeakReference<RowDataReadonly>> rows = rowCache.get(rowHash);
+    	if(rows!=null) {
+    		for(int i=0; i<rows.size(); i++) {
+    			final WeakReference<RowDataReadonly> weakRowData = rows.get(i);
+    			final RowDataReadonly rowDataReadonly = weakRowData.get();
+    			if(rowDataReadonly==null) {
+    				rows.remove(i--);
+    			}
+    			else if(rowDataReadonly.equals(rowData)) {
+	    			// using existing cellData instance
+	    			row.setRowData(rowDataReadonly);
+	    			return;
+    			}
+	    	}
+    	}
+    	else {
+    		rows = new ArrayList<WeakReference<RowDataReadonly>>(1);
+    		rowCache.put(rowHash, rows);
+    	}
+    	// adding new CachedCellData to the cache
+    	rows.add(new WeakReference<RowDataReadonly>(rowData));
+    }
 
     /**
      * Gets the value of the row property.
@@ -102,7 +170,7 @@ public class SheetData implements Child
      */
     // this method is now private to ensure that Map<Long, Row> stays up to date..
     private List<Row> getListArray() {
-    	
+
         if (row==null) {
         	if(rows_impl!=null) {
         		row = new ArrayList<Row>(rows_impl.values());
@@ -138,11 +206,14 @@ public class SheetData implements Child
         Row r = treeMap.get(index);
         if(forceCreate&&r==null) {
 
-            // creating a new row...
-        	org.docx4j.jaxb.Context.checkMemory();
+            org.docx4j.jaxb.Context.abortOnLowMemory();
 
+            if(index<0||index>1048575) {
+                throw new RuntimeException();
+            }
+
+            // creating a new row...
             r = Context.getsmlObjectFactory().createRow();
-            r.setParent(this);
             r.setRow(index);
             treeMap.put(index, r);
         }
@@ -213,13 +284,13 @@ public class SheetData implements Child
     }
 
     public static void ApplyBorderStyle(CTStylesheet stylesheet, Cell cellClone, Cell nextRowCell) {
-        final CTXf ctXfPrev = stylesheet.getCellXfByIndex(cellClone.getS());
+        final CTXf ctXfPrev = stylesheet.getCellXfByIndex(cellClone.getStyle());
         // is prevRow using a hard border ?
         if(ctXfPrev!=null&&ctXfPrev.isApplyBorder()!=null&&ctXfPrev.isApplyBorder()&&ctXfPrev.getBorderId()!=null) {
             long borderId = ctXfPrev.getBorderId().longValue();
             long newBorderId = 0;   // this is our new borderId if the cell of the nextRow is not having hard border attributes
             if(nextRowCell!=null) {
-                final CTXf ctXfNext = stylesheet.getCellXfByIndex(nextRowCell.getS());
+                final CTXf ctXfNext = stylesheet.getCellXfByIndex(nextRowCell.getStyle());
                 if(ctXfNext!=null&&ctXfNext.isApplyBorder()!=null&&ctXfNext.isApplyBorder()&&ctXfNext.getBorderId()!=null) {
                     long nextBorderId = ctXfNext.getBorderId().longValue();
                     if(nextBorderId==borderId) {
@@ -315,7 +386,6 @@ public class SheetData implements Child
                 newRow.setHidden(false);
                 newRow.setHt(prevRow.getHt());
                 newRow.setOutlineLevel(prevRow.getOutlineLevel());
-                newRow.setParent(prevRow.getParent());
                 newRow.setPh(prevRow.isPh());
                 newRow.setS(prevRow.getS());
                 newRow.setThickBot(prevRow.isThickBot());
@@ -326,7 +396,7 @@ public class SheetData implements Child
                 while(cellIterator.hasNext()) {
                     Cell cell = cellIterator.next();
                     Cell cellClone = newRow.getCell(cell.getColumn(), true);
-                    cellClone.setS(cell.getS());
+                    cellClone.setS(cell.getStyle());
 
                     // we need to take care of border attributes only if
                     // inserting the first row, second insertion is always
@@ -338,6 +408,7 @@ public class SheetData implements Child
                         }
                         ApplyBorderStyle(stylesheet, cellClone, nextRowCell);
                     }
+                    applyCachedCellData(cellClone);
                 }
                 prevRow = newRow;
             }
@@ -431,12 +502,12 @@ public class SheetData implements Child
     	}
     	return -1;
     }
-    
+
     @SuppressWarnings("unused")
     public void beforeMarshal(Marshaller marshaller) {
         getListArray();
     }
-    
+
     /**
      * This method is invoked by the JAXB implementation on each instance when unmarshalling completes.
      *
