@@ -8,7 +8,7 @@
  *
  *    In some countries OX, OX Open-Xchange, open xchange and OXtender
  *    as well as the corresponding Logos OX Open-Xchange and OX are registered
- *    trademarks of the Open-Xchange, Inc. group of companies.
+ *    trademarks.
  *    The use of the Logos is not covered by the GNU General Public License.
  *    Instead, you are allowed to use these Logos according to the terms and
  *    conditions of the Creative Commons License, Version 2.5, Attribution,
@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2012 Open-Xchange, Inc.
+ *     Copyright (C) 2016 OX Software GmbH
  *     Mail: info@open-xchange.com
  *
  *
@@ -50,8 +50,7 @@
 package org.xlsx4j.sml;
 
 import java.util.Iterator;
-import java.util.List;
-import java.util.Map;
+
 import org.json.JSONArray;
 
 public final class SmlUtils {
@@ -88,17 +87,22 @@ public final class SmlUtils {
         public static CellRefRange insertRowRange(CellRefRange cellRefRange, int startRow, int count, boolean append) {
             final CellRef start = cellRefRange.getStart();
             final CellRef end = cellRefRange.getEnd();
-            int endRow = end.getRow();
-            if(append) {
-                endRow++;
-            }
+            int r1 = start.getRow();
+            int r2 = end.getRow();
             if(startRow<=start.getRow()) {
-                return new CellRefRange(new CellRef(start.getColumn(), start.getRow()+count), new CellRef(end.getColumn(), end.getRow()+count));
+                r1+=count;
+                r2+=count;
             }
-            else if(startRow<=endRow) {
-                return new CellRefRange(new CellRef(start.getColumn(), start.getRow()), new CellRef(end.getColumn(), end.getRow()+count));
+            else if(startRow<=(append?end.getRow()+1:end.getRow())) {
+                r2+=count;
             }
-            return new CellRefRange(new CellRef(start.getColumn(), start.getRow()), new CellRef(end.getColumn(), end.getRow()));
+            if(r2>1048575) {
+                r2=1048575;
+                if(r1>1048575) {
+                    return null;
+                }
+            }
+            return new CellRefRange(new CellRef(start.getColumn(), r1), new CellRef(end.getColumn(), r2));
         }
         public static CellRefRange deleteRowRange(CellRefRange cellRef, int startRow, int endRow) {
             int row1 = cellRef.getStart().getRow();
