@@ -8,7 +8,7 @@
  *
  *    In some countries OX, OX Open-Xchange, open xchange and OXtender
  *    as well as the corresponding Logos OX Open-Xchange and OX are registered
- *    trademarks of the Open-Xchange, Inc. group of companies.
+ *    trademarks.
  *    The use of the Logos is not covered by the GNU General Public License.
  *    Instead, you are allowed to use these Logos according to the terms and
  *    conditions of the Creative Commons License, Version 2.5, Attribution,
@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2012 Open-Xchange, Inc.
+ *     Copyright (C) 2016 OX Software GmbH
  *     Mail: info@open-xchange.com
  *
  *
@@ -52,6 +52,7 @@ package com.openexchange.office.json.actions;
 import java.util.Collection;
 import java.util.HashMap;
 import java.util.Map;
+
 import com.openexchange.ajax.requesthandler.AJAXActionService;
 import com.openexchange.ajax.requesthandler.AJAXActionServiceFactory;
 import com.openexchange.office.json.tools.EmptyDocumentCache;
@@ -103,6 +104,9 @@ public class DocumentFilterActionFactory implements AJAXActionServiceFactory {
         actions.put("gettemplateandrecentlist", new GetTemplateAndRecentListAction(services, templateFilesScanner));
         actions.put("prefetchofficeparts", new PrefetchOfficePartsAction(services, emptyDocCache));
         actions.put("getuserinfo", new GetUserInfoAction(services));
+        actions.put("sort", new SortAction(services));
+        actions.put("getcontexttemplatefolders", new GetContextTemplateFoldersAction(services));
+        
     }
 
     @Override
