@@ -8,7 +8,7 @@
  *
  *    In some countries OX, OX Open-Xchange, open xchange and OXtender
  *    as well as the corresponding Logos OX Open-Xchange and OX are registered
- *    trademarks of the Open-Xchange, Inc. group of companies.
+ *    trademarks.
  *    The use of the Logos is not covered by the GNU General Public License.
  *    Instead, you are allowed to use these Logos according to the terms and
  *    conditions of the Creative Commons License, Version 2.5, Attribution,
@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2012 Open-Xchange, Inc.
+ *     Copyright (C) 2016 OX Software GmbH
  *     Mail: info@open-xchange.com
  *
  *
@@ -77,10 +77,12 @@ import com.openexchange.documentconverter.Feature;
 import com.openexchange.documentconverter.IManager;
 import com.openexchange.documentconverter.Properties;
 import com.openexchange.office.tools.ConfigurationHelper;
+import com.openexchange.office.tools.DocFileHelper;
 import com.openexchange.office.tools.FileHelper;
-import com.openexchange.office.tools.FileHelper.StreamInfo;
 import com.openexchange.office.tools.Resource;
 import com.openexchange.office.tools.ResourceManager;
+import com.openexchange.office.tools.StorageHelper;
+import com.openexchange.office.tools.StreamInfo;
 import com.openexchange.server.ServiceLookup;
 import com.openexchange.tools.session.ServerSession;
 
@@ -150,7 +152,7 @@ public class GetFileAction extends DocumentFilterAction {
                 final Resource nodeResource = resourceManager.getResource(uid);
                 byte[] resdata = ((nodeResource != null) ? nodeResource.getBuffer() : null);
 
-                LOG.debug("AjaxRequest GetFileAction resource data " + filename + " not found in resourceManager.");
+                LOG.trace("AjaxRequest GetFileAction resource data " + filename + " not found in resourceManager.");
 
                 // 2. try: create a managed resource with the given uid
                 if (null == resdata) {
@@ -173,7 +175,7 @@ public class GetFileAction extends DocumentFilterAction {
                 // if we've got the resource data, set it as request result
                 if (null != resdata) {
                     try {
-                        final String mimeType = FileHelper.getMimeType(resourceName);
+                        final String mimeType = DocFileHelper.getMimeType(resourceName);
                         final ByteArrayFileHolder fileHolder = new ByteArrayFileHolder(resdata);
 
                         fileHolder.close();
@@ -188,17 +190,20 @@ public class GetFileAction extends DocumentFilterAction {
 
             // try getting the graphic from the document's zip archive
             if (null == requestResult) {
+                LOG.trace("AjaxRequest GetFileAction image must be retrieved from document stream");
+
                 // always use the current version of the document
                 request.putParameter("version", "0");
-                final StreamInfo streamInfo = FileHelper.getDocumentStream(m_services, session, request);
-                final InputStream documentStm = streamInfo.documentStream;
+                final String folderId = request.getParameter("folder_id");
+                final StorageHelper storageHelper = new StorageHelper(m_services, session, folderId);
+                final StreamInfo streamInfo = DocFileHelper.getDocumentStream(m_services, session, request, storageHelper);
+                final InputStream documentStm = streamInfo.getDocumentStream();
 
                 if (null != documentStm) {
+                    LOG.trace("AjaxRequest GetFileAction document stream successfully retrieved - try to get substream for resource data " + filename);
                     final String[] mimeType = { "" };
                     final InputStream resultStm = getZipEntryStream(documentStm, session, resourceName, mimeType);
 
-                    IOUtils.closeQuietly(documentStm);
-
                     if (null != resultStm) {
                         byte[] buffer = null;
 
@@ -212,11 +217,25 @@ public class GetFileAction extends DocumentFilterAction {
 
                         if (null != buffer) {
                             requestResult = createFileRequestResult(request, buffer, mimeType[0], null);
-                            LOG.debug("AjaxRequest GetFileAction resource data " + filename + " found in document stream.");
+                            LOG.trace("AjaxRequest GetFileAction resource data " + filename + " successfully retrieved.");
                         } else {
-                            LOG.error("AjaxRequest GetFileAction resource data " + filename + " not found in resource manager & document stream.");
+                            LOG.warn("AjaxRequest GetFileAction resource data " + filename + " not found.");
                         }
                     }
+
+                    IOUtils.closeQuietly(documentStm);
+
+                    try {
+                        streamInfo.close();
+                    } catch (IOException e) {
+                        LOG.warn("Could not correctly close IDBasedFileAccess instance", e);
+                    }
+                } else {
+                    try {
+                        streamInfo.close();
+                    } catch (IOException e) {
+                        LOG.warn("Could not correctly close IDBasedFileAccess instance", e);
+                    }
                 }
             }
         } else {
@@ -250,7 +269,7 @@ public class GetFileAction extends DocumentFilterAction {
                 for (ZipEntry zipEntry = null; (null == resultStm) && ((zipEntry = zipInputStm.getNextEntry()) != null);) {
                     final String curEntryName = zipEntry.getName();
 
-                    if (curEntryName.equals(FileHelper.OX_RESCUEDOCUMENT_DOCUMENTSTREAM_NAME)) {
+                    if (curEntryName.equals(DocFileHelper.OX_RESCUEDOCUMENT_DOCUMENTSTREAM_NAME)) {
                         // check for resources contained within the original rescue document
                         byte[] entryBuffer = null;
 
@@ -305,7 +324,7 @@ public class GetFileAction extends DocumentFilterAction {
                             }
                             if (null == resultStm) {
                                 resultStm = new ByteArrayInputStream(entryBuffer);
-                                mimeType[0] = FileHelper.getMimeType(resourceName);
+                                mimeType[0] = DocFileHelper.getMimeType(resourceName);
                             }
                         }
                     }
@@ -328,7 +347,7 @@ public class GetFileAction extends DocumentFilterAction {
     final private byte[] ensureImageResolution(byte[] entryBuffer, ServerSession session, String fileExtension) {
 
         // we will check the image dimensions and scale down if necessary
-        int maxImageSize = ConfigurationHelper.getIntegerOfficeConfigurationValue(m_services, session, "//module/documentImageSize", 1280);
+        final int maxImageSize = ConfigurationHelper.getIntegerOfficeConfigurationValue(m_services, session, "//module/documentImageSize", 1280);
         if(maxImageSize>0) {
 
             final Iterator<ImageReader> iterReader = ImageIO.getImageReadersBySuffix(fileExtension);
