@@ -8,7 +8,7 @@
  *
  *    In some countries OX, OX Open-Xchange, open xchange and OXtender
  *    as well as the corresponding Logos OX Open-Xchange and OX are registered
- *    trademarks of the Open-Xchange, Inc. group of companies.
+ *    trademarks.
  *    The use of the Logos is not covered by the GNU General Public License.
  *    Instead, you are allowed to use these Logos according to the terms and
  *    conditions of the Creative Commons License, Version 2.5, Attribution,
@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2014 Open-Xchange, Inc.
+ *     Copyright (C) 2016 OX Software GmbH
  *     Mail: info@open-xchange.com
  *
  *
@@ -64,7 +64,7 @@ import com.openexchange.office.FilterException;
 import com.openexchange.office.IImporter;
 import com.openexchange.office.tools.DocumentFormatHelper.OfficeDocumentType;
 import com.openexchange.office.tools.ErrorCode;
-import com.openexchange.office.tools.FileHelper;
+import com.openexchange.office.tools.DocFileHelper;
 import com.openexchange.office.tools.MimeTypeHelper;
 import com.openexchange.office.tools.Resource;
 import com.openexchange.office.tools.ResourceManager;
@@ -143,21 +143,21 @@ public class OXDocumentHelper {
                 while ((entry = zipInputStm.getNextEntry()) != null) {
                     final String entryName = entry.getName();
 
-                    if (entryName.equals(FileHelper.OX_DOCUMENT_EXTENDEDDATA)) {
+                    if (entryName.equals(DocFileHelper.OX_DOCUMENT_EXTENDEDDATA)) {
                         try {
                             // read document identifier
                             extendedDataBuffer = IOUtils.toByteArray(zipInputStm);
                         } catch (IOException e) {
                             LOG.error("RT connection: unable to retrieve extended data stream, exception catched", e);
                         }
-                    } else if (entryName.equals(FileHelper.OX_RESCUEDOCUMENT_DOCUMENTSTREAM_NAME)) {
+                    } else if (entryName.equals(DocFileHelper.OX_RESCUEDOCUMENT_DOCUMENTSTREAM_NAME)) {
                         try {
                             // read original document
                             documentBuffer = IOUtils.toByteArray(zipInputStm);
                         } catch (IOException e) {
                             LOG.error("RT connection: unable to retrieve original document stream, exception catched", e);
                         }
-                    } else if (entryName.equals(FileHelper.OX_RESCUEDOCUMENT_OPERATIONSSTREAM_NAME)) {
+                    } else if (entryName.equals(DocFileHelper.OX_RESCUEDOCUMENT_OPERATIONSSTREAM_NAME)) {
                         try {
                             // read original document
                             final String op = IOUtils.toString(zipInputStm);
@@ -166,9 +166,9 @@ public class OXDocumentHelper {
                         } catch (IOException e) {
                             LOG.error("RT connection: unable to retrieve operations stream, exception catched", e);
                         }
-                    } else if (entryName.startsWith(FileHelper.OX_RESCUEDOCUMENT_RESOURCESTREAM_NAME_PREFIX)) {
+                    } else if (entryName.startsWith(DocFileHelper.OX_RESCUEDOCUMENT_RESOURCESTREAM_NAME_PREFIX)) {
                         // read resource and put into the resource manager, if not already contained
-                        final String resourceName = entryName.substring(FileHelper.OX_RESCUEDOCUMENT_RESOURCESTREAM_NAME_PREFIX.length());
+                        final String resourceName = entryName.substring(DocFileHelper.OX_RESCUEDOCUMENT_RESOURCESTREAM_NAME_PREFIX.length());
 
                         if (!m_resourceManager.containsResource(Resource.getUIDFromResourceName(resourceName))) {
                             byte[] resourceBuffer = null;
@@ -245,7 +245,7 @@ public class OXDocumentHelper {
                 try {
 	                User user = SessionUtils.getUserInfo(session, m_services);
                     if (null != user) {
-                        userLangCode = FileHelper.mapUserLanguageToLangCode(user.getPreferredLanguage());
+                        userLangCode = DocFileHelper.mapUserLanguageToLangCode(user.getPreferredLanguage());
                     }
                 } catch (Exception e) {
                 	// nothing to do.
