@@ -208,7 +208,7 @@ final class TableChanges implements TableChange {
     }
 
     protected void determineRange(JSONObject formatProps) {
-        if (formatProps != null && formatProps.hasAndNotNull("column") || mIsColumnDeletion) {
+        if (formatProps != null && (formatProps.hasAndNotNull("column") || formatProps.hasAndNotNull("cell")) || mIsColumnDeletion) {
             hasColumnEffect = Boolean.TRUE;
         } else {
             hasColumnEffect = Boolean.FALSE;
@@ -241,8 +241,9 @@ final class TableChanges implements TableChange {
                 } else if (tableStyleableElement instanceof TableTableRowElement && hasRowEffect
                     || tableStyleableElement instanceof TableTableColumnElement && hasColumnEffect) {
                     // if the complete column or row is selected
-                    if (tableStyleableElement instanceof TableTableColumnElement && rowEndNo == Table.MAX_ROW_NUMBER && rowStartNo == 0
-                        || tableStyleableElement instanceof TableTableRowElement && columnEndNo == Table.MAX_COLUMN_NUMBER && columnStartNo == 0) {
+                    if (tableStyleableElement instanceof TableTableColumnElement && rowEndNo == (Table.MAX_ROW_NUMBER - 1) && rowStartNo == 0
+                        || tableStyleableElement instanceof TableTableRowElement && columnEndNo == (Table.MAX_COLUMN_NUMBER_CALC - 1) && columnStartNo == 0
+                        || tableStyleableElement instanceof TableTableRowElement && columnEndNo == (Table.MAX_COLUMN_NUMBER_EXCEL - 1) && columnStartNo == 0) {
                         JsonOperationConsumer.setAttributes(null, tableStyleableElement, null, null, mFormatProps, Boolean.TRUE);
                     } else {
                         JsonOperationConsumer.setAttributes(null, tableStyleableElement, null, null, mFormatProps, Boolean.FALSE);
@@ -818,10 +819,6 @@ final class TableChanges implements TableChange {
     }
 
     public void setRowEnd(int rowEndNo) {
-        if (mRowEndNo < 0) {
-            mRowEndNo = MAX_ROW_NUMBER;
-        } else {
-            mRowEndNo = rowEndNo;
-        }
+        mRowEndNo = rowEndNo;
     }
 }
