@@ -770,7 +770,7 @@ public class OdfTableRow {
 
 		int index = nStart;
 		for (int i = 0; i < nCount; i++) {
-			OdfTableCell cell = getCellByIndex(index);
+			OdfTableCell cell = getCellByIndex(index);            
 			cell.splitRepeatedCells();
 			if (cell.isCoveredElement() && coverCell != null) {
 				coverCell.setColumnSpannedNumber(coverCell.getColumnSpannedNumber() - cell.getColumnsRepeatedNumber());
@@ -780,11 +780,19 @@ public class OdfTableRow {
 				maRowElement.removeChild(cell.getOdfElement());
 				i += cell.getColumnsRepeatedNumber() - 1;
 			} else if (!cell.isCoveredElement()) {
-				if (i + cell.getColumnSpannedNumber() <= nCount) {
+                int columnSpan = cell.getColumnSpannedNumber();
+				if (i + columnSpan <= nCount) {
 					maRowElement.removeChild(cell.getOdfElement());
-					i += cell.getColumnSpannedNumber() - 1;
+					i += columnSpan - 1;
 				} else {
-					removeCellByIndex(index + 1, nCount - i);
+                    cell.setColumnSpannedNumber(columnSpan - 1);
+                    OdfElement nextCell = OdfElement.getNextSiblingElement(cell.mCellElement);
+                    // Recently some office application do not use <table:covered-table-cell> elements any longer
+                    if(nextCell instanceof TableCoveredTableCellElement){
+                        // only delete the next child if the next IS a <table:covered-table-cell> element
+                        removeCellByIndex(index + 1, nCount - i);
+                    }
+					
 				}
 			}
 		}
