@@ -1076,7 +1076,7 @@ public class OdfPackage implements Closeable {
 			}
 			if (is == null) {
 				logValidationError(OdfPackageConstraint.MANIFEST_NOT_IN_PACKAGE, getBaseURI());
-				return;
+				throw new IOException("parseManifest: manifest not found");
 			}
 			XMLReader xmlReader = getXMLReader();
 			xmlReader.setEntityResolver(getEntityResolver());
