@@ -28,13 +28,14 @@ import org.json.JSONObject;
 import org.odftoolkit.odfdom.component.OdfOperationDocument;
 import org.odftoolkit.odfdom.doc.OdfDocument;
 import org.odftoolkit.odfdom.pkg.OdfPackage;
+import org.xml.sax.SAXException;
 
 import com.openexchange.office.FilterException;
+import com.openexchange.office.FilterException.ErrorCode;
 import com.openexchange.office.tools.ConfigurationHelper;
 import com.openexchange.office.tools.ResourceManager;
 import com.openexchange.server.ServiceLookup;
 import com.openexchange.session.Session;
-import com.openexchange.office.FilterException.ErrorCode;
 
 /**
  * The access point to the ODF Toolkit, obfuscating all OX Office dependencies
@@ -82,10 +83,12 @@ public class OdfOperationDoc {
     }
 
     private static final String MODULE = "//module/";
+    private static final String SPREADSHEET = "//spreadsheet/";
     private static final String DEBUG_OPERATIONS = "debugoperations";
     private static final String MAX_TABLE_COLUMNS = "maxTableColumns";
     private static final String MAX_TABLE_ROWS = "maxTableRows";
     private static final String MAX_TABLE_CELLS = "maxTableCells";
+    private static final String MAX_SHEETS = "maxSheets";
 
     public OdfOperationDoc(Session session, ServiceLookup _services, InputStream inputDocumentStream, ResourceManager resourceManager, Map<String, Object> configuration) throws Exception {
         mServiceLookup = _services;
@@ -98,6 +101,8 @@ public class OdfOperationDoc {
         configuration.put(MAX_TABLE_ROWS, maxTableRows);
         int maxTableCells = ConfigurationHelper.getIntegerOfficeConfigurationValue(_services, session, MODULE + MAX_TABLE_CELLS, 1500);
         configuration.put(MAX_TABLE_CELLS, maxTableCells);
+        int maxSheets = ConfigurationHelper.getIntegerOfficeConfigurationValue(_services, session, SPREADSHEET + MAX_SHEETS, 200);
+        configuration.put(MAX_SHEETS, maxSheets);
         mDocument = new OdfOperationDocument(inputDocumentStream, (null != resourceManager) ? resourceManager.getByteArrayTable() : null, configuration);
     }
 
@@ -107,7 +112,7 @@ public class OdfOperationDoc {
      * @return the operations as JSON
      */
     // ToDo OX - JSONObject is to be considered..
-    public JSONObject getOperations() {
+    public JSONObject getOperations() throws SAXException, FilterException {
         JSONObject ops = mDocument.getOperations();
         if (ops != null) {
             LOG.log(Level.FINER, "\n\n*** ALL OPERATIONS:\n{0}", mDocument.getOperations().toString());
@@ -171,7 +176,7 @@ public class OdfOperationDoc {
         LOG.finest("Overwriting ODT document status ID " + STATUS_ID_FILE);
         pkg.insert(statusId.getBytes(), STATUS_ID_FILE, "text/plain");
     }
-    
+
     /**
      * Read the status ID - which reflects the latest changes of the document,
      * used as cashing ID of web representation to enable performance
@@ -180,7 +185,7 @@ public class OdfOperationDoc {
         OdfPackage pkg = mDocument.getPackage();
         String statusId = null;
         if (pkg != null && pkg.contains(STATUS_ID_FILE)) {
-            // ..from the ODF ZIP 
+            // ..from the ODF ZIP
             byte[] revisionByteArray = pkg.getBytes(STATUS_ID_FILE);
             if (revisionByteArray != null && revisionByteArray.length != 0) {
                 BufferedReader reader = new BufferedReader(new InputStreamReader(new ByteArrayInputStream(revisionByteArray)));
