@@ -8,7 +8,7 @@
  *
  *    In some countries OX, OX Open-Xchange, open xchange and OXtender
  *    as well as the corresponding Logos OX Open-Xchange and OX are registered
- *    trademarks of the Open-Xchange, Inc. group of companies.
+ *    trademarks.
  *    The use of the Logos is not covered by the GNU General Public License.
  *    Instead, you are allowed to use these Logos according to the terms and
  *    conditions of the Creative Commons License, Version 2.5, Attribution,
@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2012 Open-Xchange, Inc.
+ *     Copyright (C) 2016 OX Software GmbH
  *     Mail: info@open-xchange.com
  *
  *
@@ -54,21 +54,16 @@ import java.io.IOException;
 import java.io.InputStream;
 import java.math.BigInteger;
 import java.util.List;
+import java.util.concurrent.atomic.AtomicInteger;
 import java.util.zip.ZipEntry;
 import java.util.zip.ZipInputStream;
 
-import javax.xml.bind.JAXBElement;
-import javax.xml.bind.JAXBException;
-import javax.xml.bind.Unmarshaller;
-
 import org.apache.commons.io.IOUtils;
-import org.docx4j.IndexedNode;
 import org.docx4j.dml.Theme;
 import org.docx4j.jaxb.Context;
-import org.docx4j.openpackaging.exceptions.Docx4JException;
 import org.docx4j.openpackaging.exceptions.InvalidFormatException;
+import org.docx4j.openpackaging.packages.OpcPackage;
 import org.docx4j.openpackaging.packages.WordprocessingMLPackage;
-import org.docx4j.openpackaging.parts.DefaultXmlPart;
 import org.docx4j.openpackaging.parts.Part;
 import org.docx4j.openpackaging.parts.PartName;
 import org.docx4j.openpackaging.parts.PeoplePart;
@@ -77,16 +72,18 @@ import org.docx4j.openpackaging.parts.WordprocessingML.DocumentSettingsPart;
 import org.docx4j.openpackaging.parts.WordprocessingML.FontTablePart;
 import org.docx4j.openpackaging.parts.WordprocessingML.MainDocumentPart;
 import org.docx4j.openpackaging.parts.WordprocessingML.StyleDefinitionsPart;
+import org.docx4j.openpackaging.parts.relationships.Namespaces;
 import org.docx4j.openpackaging.parts.relationships.RelationshipsPart;
 import org.docx4j.relationships.Relationship;
+import org.docx4j.relationships.Relationships;
 import org.docx4j.w15.CTPeople;
-import org.docx4j.w15.CTPerson;
 import org.docx4j.wml.CTLanguage;
+import org.docx4j.wml.CTSettings;
+import org.docx4j.wml.ContentAccessor;
 import org.docx4j.wml.DocDefaults;
 import org.docx4j.wml.DocDefaults.RPrDefault;
 import org.docx4j.wml.Fonts;
 import org.docx4j.wml.Fonts.Font;
-import org.docx4j.wml.CTSettings;
 import org.docx4j.wml.ObjectFactory;
 import org.docx4j.wml.P;
 import org.docx4j.wml.R;
@@ -95,14 +92,10 @@ import org.docx4j.wml.SectPr;
 import org.docx4j.wml.Styles;
 import org.docx4j.wml.Styles.LatentStyles;
 import org.docx4j.wml.Styles.LatentStyles.LsdException;
-import org.docx4j.wml.Tbl;
-import org.docx4j.wml.TblPr;
-import org.docx4j.wml.Tc;
 import org.docx4j.wml.Tr;
 import org.json.JSONArray;
 import org.json.JSONObject;
 import org.json.JSONTokener;
-import org.w3c.dom.Document;
 
 import com.openexchange.office.DocumentProperties;
 import com.openexchange.office.FilterException;
@@ -110,10 +103,7 @@ import com.openexchange.office.FilterException.ErrorCode;
 import com.openexchange.office.ooxml.docx.operations.ApplyOperationHelper;
 import com.openexchange.office.ooxml.docx.operations.CreateOperationHelper;
 import com.openexchange.office.ooxml.docx.tools.Component;
-import com.openexchange.office.ooxml.docx.tools.Component.MainContext;
 import com.openexchange.office.ooxml.docx.tools.Component.ParagraphComponent;
-import com.openexchange.office.ooxml.docx.tools.Component.TableComponent;
-import com.openexchange.office.ooxml.docx.tools.Component.TcComponent;
 import com.openexchange.office.ooxml.docx.tools.Component.TextRun_Base;
 import com.openexchange.office.ooxml.docx.tools.Component.TrComponent;
 import com.openexchange.office.tools.ConfigurationHelper;
@@ -123,27 +113,21 @@ import com.openexchange.session.Session;
 
 public class OperationDocument extends com.openexchange.office.ooxml.OperationDocument {
 
-    final private WordprocessingMLPackage opcPackage;
+    private WordprocessingMLPackage opcPackage;
 
     public OperationDocument(Session session, ServiceLookup _services, InputStream _inputDocumentStream, ResourceManager _resourceManager, DocumentProperties _documentProperties)
         throws FilterException {
 
         super(session, _services, _inputDocumentStream, _resourceManager, _documentProperties);
         try {
-        	
+
         	inputDocumentStream = checkDocumentComplexity(_inputDocumentStream);
-        	
+
             opcPackage = WordprocessingMLPackage.load(inputDocumentStream);
         }
-        catch(Docx4JException e) {
-            ErrorCode errorCode = ErrorCode.CRITICAL_ERROR;
-            if(e.getCause() instanceof java.security.InvalidKeyException) {
-                errorCode = ErrorCode.WRONG_PASSWORD;
-            }
-            else if(e.getCause() instanceof org.apache.poi.EncryptedDocumentException) {
-                errorCode = ErrorCode.UNSUPPORTED_ENCRYPTION_USED;
-            }
-            throw new FilterException(e, errorCode);
+        catch(Throwable e) {
+            removeMemoryListener();
+            throw getRethrowException(e);
         }
     }
 
@@ -165,8 +149,18 @@ public class OperationDocument extends com.openexchange.office.ooxml.OperationDo
             // creating a fontlist (QuickOffice won't load documents without this part)
             getFontList(true);
         }
-        catch(Exception e) {
-            throw new FilterException(e, ErrorCode.CRITICAL_ERROR);
+        catch(Throwable e) {
+            removeMemoryListener();
+            throw getRethrowException(e);
+        }
+    }
+
+    private void setContext(String target) {
+        if(target.isEmpty()) {
+            setContextPart(null);
+        }
+        else {
+            setContextPart(getPackage().getMainDocumentPart().getRelationshipsPart(false).getPart(target));
         }
     }
 
@@ -181,7 +175,8 @@ public class OperationDocument extends com.openexchange.office.ooxml.OperationDo
                 final JSONArray aOperations = new JSONArray(new JSONTokener(applyOperations));
                 for (i = 0; i < aOperations.length(); i++) {
                     op = (JSONObject) aOperations.get(i);
-                    String opName = op.getString("name");
+                    setContext(op.optString("target", ""));
+                    final String opName = op.getString("name");
                     if (opName.equals("insertParagraph"))
                         applyOperationHelper.insertParagraph(op.getJSONArray("start"), op.optJSONObject("attrs"));
                     else if (opName.equals("delete"))
@@ -213,7 +208,7 @@ public class OperationDocument extends com.openexchange.office.ooxml.OperationDo
                     else if (opName.equals("insertField"))
                         applyOperationHelper.insertField(op.getJSONArray("start"), op.getString("type"), op.getString("representation"), op.optJSONObject("attrs"));
                     else if (opName.equals("insertDrawing"))
-                        applyOperationHelper.insertDrawing(op.getJSONArray("start"), op.getString("type").toUpperCase(), op.optJSONObject("attrs"));
+                        applyOperationHelper.insertDrawing(op.getJSONArray("start"), op.getString("type"), op.optJSONObject("attrs"));
                     else if (opName.equals("insertStyleSheet"))
                         applyOperationHelper.insertStyleSheet(op.getString("type"), op.getString("styleId"), op.getString("styleName"), op.getJSONObject("attrs"), op.optString("parent"), op.optBoolean("hidden"), op.getInt("uiPriority"), op.optBoolean("default"));
                     else if (opName.equals("deleteStylesheet"))
@@ -237,7 +232,25 @@ public class OperationDocument extends com.openexchange.office.ooxml.OperationDo
 
                 // set user language if not already set in the document
                 applyOperationHelper.setDocumentLanguageIfNotSet(getUserLanguage());
-                applyOperationHelper.postFixNonConformance();
+
+                // postfix non conformance of paragraphs in tables and unique ids (maindocumentPart/headerPart/footerPart)
+                final AtomicInteger uniqueId = new AtomicInteger(1000000);
+                final MainDocumentPart mainDocumentPart = getPackage().getMainDocumentPart();
+                setContextPart(null);
+                final Component.RootComponent rootComponent = new Component.RootComponent(mainDocumentPart);
+                applyOperationHelper.postFixNonConformance(rootComponent.getNextChildComponent(null, null), uniqueId);
+                final RelationshipsPart mainRelationshipsPart = mainDocumentPart.getRelationshipsPart();
+                final Relationships relationships = mainRelationshipsPart.getRelationships();
+                if(relationships!=null) {
+                    for(Relationship relationship:relationships.getRelationship()) {
+                        final String type = relationship.getType();
+                        if(type.equals(Namespaces.HEADER)||type.equals(Namespaces.FOOTER)) {
+                            setContextPart(mainRelationshipsPart.getPart(relationship));
+                            final Component.RootComponent headerFooterComponent = new Component.RootComponent((ContentAccessor)getContextPart());
+                            applyOperationHelper.postFixNonConformance(headerFooterComponent.getNextChildComponent(null, null), uniqueId);
+                        }
+                    }
+                }
             }
             catch(Exception e) {
                 String message = e.getMessage();
@@ -260,6 +273,7 @@ public class OperationDocument extends com.openexchange.office.ooxml.OperationDo
         createOperationHelper.CreateStyleOperations();
         createOperationHelper.CreateThemeOperations();
         createOperationHelper.CreateListOperations();
+        createOperationHelper.CreateHeaderFooterOperations();
         createOperationHelper.createOperations();
         createOperationHelper.createDocumentDefaults(getUserLanguage());
         aOperations.put("operations", operationsArray);
@@ -273,10 +287,28 @@ public class OperationDocument extends com.openexchange.office.ooxml.OperationDo
     }
 
     @Override
-    public Theme getTheme() {
-        ThemePart themePart = getPackage().getMainDocumentPart().getThemePart();
-        if( themePart == null )
-            return null;
+    public void setPackage(OpcPackage p) {
+       opcPackage = (WordprocessingMLPackage)p;
+    }
+
+    @Override
+    public Part getContextPart() {
+    	return contextPart!=null ? contextPart : getPackage().getMainDocumentPart();
+    }
+
+    @Override
+    public Theme getTheme()
+    	throws FilterException {
+
+    	ThemePart themePart = getPackage().getMainDocumentPart().getThemePart();
+        if(themePart == null) {
+        	try {
+        		themePart = getDefaultThemePart(new PartName("/word/theme/theme1.xml"));
+        	}
+        	catch(InvalidFormatException e) {
+        		throw new FilterException("docx filter, could not create default theme", ErrorCode.CRITICAL_ERROR, e);
+        	}
+        }
         return themePart.getJaxbElement();
     }
 
@@ -389,7 +421,7 @@ public class OperationDocument extends com.openexchange.office.ooxml.OperationDo
             ctLanguage.setBidi("");
         }
     }
-    
+
     @Override
     protected void switchToNonTemplateDocument() {
     	super.switchToNonTemplateDocument();
@@ -398,7 +430,7 @@ public class OperationDocument extends com.openexchange.office.ooxml.OperationDo
     @Override
     protected void switchToTemplateDocument() {
     	super.switchToTemplateDocument();
-    	
+
     	final MainDocumentPart mainDocumentPart = getPackage().getMainDocumentPart();
         final RelationshipsPart mainRelationshipsPart = mainDocumentPart.getRelationshipsPart();
         removePart(mainRelationshipsPart, "/word/stylesWithEffects.xml");
@@ -408,7 +440,8 @@ public class OperationDocument extends com.openexchange.office.ooxml.OperationDo
         removePart(mainRelationshipsPart, "/word/printerSettings/printerSettings3.bin");
 
         // removing changeIds from the document
-    	removeRSids(new Component.MainDocumentComponent(mainDocumentPart).getChildComponent());
+        final Component.RootComponent rootComponent = new Component.RootComponent(mainDocumentPart);
+    	removeRSids(rootComponent.getNextChildComponent(null, null));
 
     	// removing rsIds from settings if available
     	final DocumentSettingsPart documentSettingsPart = mainDocumentPart.getDocumentSettingsPart();
@@ -427,7 +460,7 @@ public class OperationDocument extends com.openexchange.office.ooxml.OperationDo
 
     private void removeRSids(Component c) {
     	while(c!=null) {
-    		removeRSids(c.getChildComponent());
+    		removeRSids(c.getNextChildComponent(null, null));
     		if(c instanceof ParagraphComponent) {
     			final P p = (P)c.getObject();
     			p.setRsidDel(null);
@@ -460,7 +493,7 @@ public class OperationDocument extends com.openexchange.office.ooxml.OperationDo
 
     	InputStream returnValue = null;
 
-    	int maxWordCount  = ConfigurationHelper.getIntegerOfficeConfigurationValue(getServiceLookup(), getSession(), "//text/maxWordCount", 50000);
+    	final int maxWordCount  = ConfigurationHelper.getIntegerOfficeConfigurationValue(getServiceLookup(), getSession(), "//text/maxWordCount", 50000);
         if(maxWordCount<=0) {
         	return _inputStream;
         }
@@ -495,8 +528,8 @@ public class OperationDocument extends com.openexchange.office.ooxml.OperationDo
 		        	}
 		        }
 			    zipInputStream.closeEntry();
-			    
-			    // the document.xml size of a document with 50000 words -> 3,5mb 
+
+			    // the document.xml size of a document with 50000 words -> 3,5mb
 			    // the same document with only 25000 words -> 2,4mb
 			    // so we assume 25000 words are about 1,1mb and 1mb is for the bottom
 			    // of the barrel such as styles etc
@@ -517,8 +550,8 @@ public class OperationDocument extends com.openexchange.office.ooxml.OperationDo
 		}
         return returnValue;
     }
-    
-    
+
+
     private void insertPredefinedLatentStyles(Styles styles) {
 
         final ObjectFactory objectFactory = new ObjectFactory();
