@@ -8,7 +8,7 @@
  *
  *    In some countries OX, OX Open-Xchange, open xchange and OXtender
  *    as well as the corresponding Logos OX Open-Xchange and OX are registered
- *    trademarks of the Open-Xchange, Inc. group of companies.
+ *    trademarks.
  *    The use of the Logos is not covered by the GNU General Public License.
  *    Instead, you are allowed to use these Logos according to the terms and
  *    conditions of the Creative Commons License, Version 2.5, Attribution,
@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2012 Open-Xchange, Inc.
+ *     Copyright (C) 2016 OX Software GmbH
  *     Mail: info@open-xchange.com
  *
  *
@@ -57,9 +57,7 @@ import java.util.List;
 import javax.xml.bind.JAXBElement;
 
 import org.docx4j.jaxb.Context;
-import org.docx4j.IndexedNode;
 import org.docx4j.openpackaging.packages.WordprocessingMLPackage;
-import org.docx4j.openpackaging.parts.WordprocessingML.MainDocumentPart;
 import org.docx4j.wml.CTBorder;
 import org.docx4j.wml.CTHeight;
 import org.docx4j.wml.CTShd;
@@ -74,12 +72,8 @@ import org.docx4j.wml.CTTrPrBase;
 import org.docx4j.wml.ObjectFactory;
 import org.docx4j.wml.STBorder;
 import org.docx4j.wml.STTblLayoutType;
-import org.docx4j.wml.SectPr;
-import org.docx4j.wml.SectPr.PgMar;
-import org.docx4j.wml.SectPr.PgSz;
 import org.docx4j.wml.Tbl;
 import org.docx4j.wml.TblBorders;
-import org.docx4j.wml.TblGrid;
 import org.docx4j.wml.TblGridBase;
 import org.docx4j.wml.TblGridCol;
 import org.docx4j.wml.TblPr;
@@ -90,13 +84,13 @@ import org.docx4j.wml.TcPr;
 import org.docx4j.wml.TcPrInner;
 import org.docx4j.wml.TcPrInner.GridSpan;
 import org.docx4j.wml.TcPrInner.TcBorders;
-import org.docx4j.wml.TrPr;
 import org.json.JSONArray;
 import org.json.JSONException;
 import org.json.JSONObject;
 
+import com.openexchange.office.FilterException;
 import com.openexchange.office.ooxml.docx.OperationDocument;
-import com.openexchange.office.ooxml.docx.tools.Component.TableContext;
+import com.openexchange.office.ooxml.docx.tools.Component.TableComponent;
 import com.openexchange.office.ooxml.tools.Commons;
 
 public class Table {
@@ -161,7 +155,7 @@ public class Table {
         return tableGrid;
     }
 
-    public static void setTableGrid(OperationDocument operationDocument, Tbl tbl, TblGridBase tblGridBase, JSONArray tableGrid)
+    public static void setTableGrid(OperationDocument operationDocument, TableComponent tableComponent, TblGridBase tblGridBase, JSONArray tableGrid)
         throws JSONException {
 
         if (tblGridBase == null)
@@ -177,6 +171,10 @@ public class Table {
 	                gridCols.add(tblGridCol);
 	            }
 	        }
+	        if(tableComponent==null) {
+	            return;
+	        }
+	        final Tbl tbl = (Tbl)tableComponent.getObject();
 	        final TblPr tblPr = tbl.getTblPr();
 	        if(tblPr==null) {
 	        	return;
@@ -190,7 +188,7 @@ public class Table {
 		        if(tblW.getType()==null||tblW.getType().equals("dxa")) {
 		        	tableWidth = tblW.getW().doubleValue();
 		        }
-		        else if(tbl.getParent() instanceof MainDocumentPart) {
+		        else if(!(tbl.getParent() instanceof Tc)) {
 		        	if(tblW.getType().equals("auto")||tblW.getType().equals("pct")) {
 		        		tableWidth = Double.valueOf(Utils.getPageWidth(operationDocument.getPackage().getMainDocumentPart(), 19000));
 		        		if(tblW.getType().equals("pct")) {
@@ -232,8 +230,8 @@ public class Table {
         }
     }
 
-    public static void applyTableProperties(OperationDocument operationDocument, JSONObject tableProperties, Tbl tbl, TblGridBase tblGridBase, CTTblPrBase tblPr)
-        throws JSONException {
+    public static void applyTableProperties(OperationDocument operationDocument, JSONObject tableProperties, TableComponent tableComponent, TblGridBase tblGridBase, CTTblPrBase tblPr)
+        throws FilterException, JSONException {
 
         if(tableProperties==null)
             return;
@@ -285,10 +283,10 @@ public class Table {
                     }
                     Utils.initShdFromJSONColor(operationDocument, (JSONObject)value, shd);
 
-                    if(tbl!=null) {
-	                    Component tableRowComponent = TableContext.getNextComponent(0, new IndexedNode<Object>(tbl), -1);                    
+                    if(tableComponent!=null) {
+	                    Component tableRowComponent = tableComponent.getNextChildComponent(null, null);
 	                    while(tableRowComponent!=null) {
-	                    	Component tableCellComponent = tableRowComponent.getChildComponent();
+	                    	Component tableCellComponent = tableRowComponent.getNextChildComponent(null, null);
 	                        while(tableCellComponent!=null) {
 	                            Tc tc = (Tc)tableCellComponent.getNode().getData();;
 	                            TcPr tcPr = tc.getTcPr();
@@ -346,7 +344,7 @@ public class Table {
         }
         if(newTableWidth!=null) {
 	        tblPr.setTblW(createTblWidthFromJSON(objectFactory, tblPr, newTableWidth));
-	
+
 	        CTTblLayoutType tblLayout = tblPr.getTblLayout();
 	        if(tblLayout==null) {
 	            tblLayout = objectFactory.createCTTblLayoutType();
@@ -356,7 +354,7 @@ public class Table {
 	        tblLayout.setType(STTblLayoutType.FIXED);
         }
         if(newTableWidth!=null||newTableGrid!=null) {
-            setTableGrid(operationDocument, tbl, tblGridBase, newTableGrid);
+            setTableGrid(operationDocument, tableComponent, tblGridBase, newTableGrid);
     	}
     }
 
@@ -505,7 +503,7 @@ public class Table {
     }
 
     public static void applyCellProperties(OperationDocument operationDocument, JSONObject cellProperties, TcPrInner tcPr)
-        throws JSONException {
+        throws FilterException, JSONException {
 
         if(cellProperties==null)
             return;
@@ -664,7 +662,7 @@ public class Table {
     }
 
     private static CTBorder createCTBorderFromJSON(OperationDocument operationDocument, ObjectFactory objectFactory, Object parent, Object borderProperties )
-        throws JSONException {
+        throws FilterException, JSONException {
 
         CTBorder ctBorder = null;
         if(borderProperties instanceof JSONObject) {
