@@ -8,7 +8,7 @@
  *
  *    In some countries OX, OX Open-Xchange, open xchange and OXtender
  *    as well as the corresponding Logos OX Open-Xchange and OX are registered
- *    trademarks of the Open-Xchange, Inc. group of companies.
+ *    trademarks.
  *    The use of the Logos is not covered by the GNU General Public License.
  *    Instead, you are allowed to use these Logos according to the terms and
  *    conditions of the Creative Commons License, Version 2.5, Attribution,
@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2012 Open-Xchange, Inc.
+ *     Copyright (C) 2016 OX Software GmbH
  *     Mail: info@open-xchange.com
  *
  *
@@ -59,12 +59,10 @@ import org.docx4j.XmlUtils;
 import org.docx4j.jaxb.Context;
 import org.docx4j.openpackaging.exceptions.InvalidFormatException;
 import org.docx4j.openpackaging.exceptions.PartUnrecognisedException;
-import org.docx4j.openpackaging.parts.WordprocessingML.MainDocumentPart;
 import org.docx4j.wml.CTRPrChange;
 import org.docx4j.wml.ContentAccessor;
 import org.docx4j.wml.DelText;
 import org.docx4j.wml.P;
-import org.docx4j.wml.PPr;
 import org.docx4j.wml.ParaRPr;
 import org.docx4j.wml.R;
 import org.docx4j.wml.RPr;
@@ -73,82 +71,17 @@ import org.docx4j.wml.RStyle;
 import org.docx4j.wml.RunDel;
 import org.docx4j.wml.RunIns;
 import org.docx4j.wml.Text;
-import org.json.JSONArray;
 import org.json.JSONException;
 import org.json.JSONObject;
 import org.jvnet.jaxb2_commons.ppp.Child;
 
+import com.openexchange.office.FilterException;
 import com.openexchange.office.ooxml.docx.OperationDocument;
-import com.openexchange.office.ooxml.docx.tools.Component.DrawingComponent;
-import com.openexchange.office.ooxml.docx.tools.Component.ParagraphComponent;
-import com.openexchange.office.ooxml.docx.tools.Component.PictVMLComponent;
-import com.openexchange.office.ooxml.docx.tools.Component.Placeholder_Base;
 import com.openexchange.office.ooxml.docx.tools.Component.TextRun_Base;
 import com.openexchange.office.ooxml.tools.Commons;
 
 public class TextUtils{
 
-    public static void splitParagraph(ParagraphComponent paragraphComponent, int textPosition) {
-
-    	final P paragraph = (P)paragraphComponent.getObject();
-
-        Component component = getComponentNumber(paragraphComponent.getChildComponent(), textPosition);
-        if(component!=null) {
-        	component.splitStart(textPosition);
-        }
-        // creating our new paragraph
-        final P destParagraph = Context.getWmlObjectFactory().createP();
-        destParagraph.setParent(paragraph.getParent());
-        final IndexedNodeList<Object> content = Utils.getContent(paragraph.getParent());
-        content.add(paragraphComponent.getNode().getIndex()+1, destParagraph);
-        final PPr sourceParagraphProperties = paragraph.getPPr();
-        if(sourceParagraphProperties!=null){
-            final PPr destParagraphProperties = XmlUtils.deepCopy(sourceParagraphProperties);
-            // no inheritance for pageBreakBefore attribute... this attribute is always false
-            destParagraphProperties.setPageBreakBefore(null);
-            destParagraphProperties.setParent(destParagraph);
-            destParagraph.setPPr(destParagraphProperties);
-        }
-
-        // moving textRuns from behind textPosition into our new paragraph
-        component = paragraphComponent.getChildComponent();
-        RPr lastRPr = null;
-        while(component!=null) {
-            if(textPosition>=component.getComponentNumber()&&textPosition<component.getNextComponentNumber()) {
-            	final int index = component.getContextChildNode().getIndex();
-            	final int count = paragraph.getContent().size() - index;
-            	if(count>0) {
-            		IndexedNodeList.moveNodes(paragraph.getContent(), destParagraph.getContent(), index, destParagraph.getContent().size(), count, destParagraph);
-            	}
-                break;
-            } else if (component instanceof TextRun_Base) {
-                lastRPr = ((TextRun_Base)component).getTextRun().getRPr();
-            }
-            component = component.getNextComponent();
-        }
-
-        // taking care of paragraph attributes
-        if(lastRPr!=null) {
-
-            // if available, we have to get the character attributes from the last textrun
-            PPr paraProps = destParagraph.getPPr();
-            if(paraProps==null) {
-                paraProps = Context.getWmlObjectFactory().createPPr();
-                paraProps.setParent(destParagraph);
-                destParagraph.setPPr(paraProps);
-            }
-
-            // 30793 ... only setting character attributes if no listStyle is used at the paragraph
-            if(paraProps.getNumPr()==null||paraProps.getNumPr().getNumId()==null) {
-                ParaRPr paraRPr = cloneRPrToParaRPr(lastRPr);
-                if(paraRPr!=null) {
-                    paraRPr.setParent(paraProps);
-                    paraProps.setRPr(paraRPr);
-                }
-            }
-        }
-    }
-    
     public static void copyRPrBase(RPrBase rDest, RPrBase rSource) {
         rDest.setB(rSource.getB());
         rDest.setBCs(rSource.getBCs());
@@ -188,7 +121,7 @@ public class TextUtils{
         rDest.setVanish(rSource.getVanish());
         rDest.setVertAlign(rSource.getVertAlign());
         rDest.setW(rSource.getW());
-        rDest.setWebHidden(rSource.getWebHidden());    	
+        rDest.setWebHidden(rSource.getWebHidden());
     }
 
     public static RPr cloneParaRPrToRPr(ParaRPr _paraRPr) {
@@ -215,20 +148,6 @@ public class TextUtils{
         return rPr;
     }
 
-    public static void mergeParagraph(ParagraphComponent paragraphComponent) {
-
-    	final Component nextParagraphComponent = paragraphComponent.getNextComponent();
-    	if(nextParagraphComponent instanceof ParagraphComponent) {
-        	final P paragraph = (P)paragraphComponent.getObject();
-        	final IndexedNodeList<Object> sourceContent = ((P)nextParagraphComponent.getObject()).getContent();
-            final IndexedNodeList<Object> destContent = paragraph.getContent();
-            if(sourceContent.size()>0) {
-            	IndexedNodeList.moveNodes(sourceContent, destContent, 0, destContent.size(), sourceContent.size(), paragraph);
-            }
-        	Utils.getContent(paragraph.getParent()).remove(nextParagraphComponent.getNode().getIndex());
-    	}
-    }
-
     private static void delTextToText(int index, Object o) {
     	if(o instanceof ContentAccessor) {
     		final List<Object> content = ((ContentAccessor)o).getContent();
@@ -246,19 +165,39 @@ public class TextUtils{
     	}
     }
 
-    public static void setTextRunAttributes(OperationDocument operationDocument, JSONObject attrs,
-    		TextRun_Base textRunComponent, boolean insertedComponent)
-        throws JAXBException, JSONException, InvalidFormatException, PartUnrecognisedException {
+    public static JSONObject forceRemoveChangeTrack(JSONObject attrs)
+    	throws JSONException {
+
+    	if(attrs==null) {
+    		attrs = new JSONObject(1);
+    	}
+		JSONObject changes = attrs.optJSONObject("changes");
+		if(changes == null) {
+			changes = new JSONObject(3);
+  			changes.put("inserted", JSONObject.NULL);
+    		changes.put("removed", JSONObject.NULL);
+    		changes.put("modified", JSONObject.NULL);
+			attrs.put("changes", changes);
+		}
+		else {
+			if(!changes.has("inserted")) {
+				changes.put("inserted", JSONObject.NULL);
+			}
+			if(!changes.has("removed")) {
+        		changes.put("removed", JSONObject.NULL);
+			}
+			if(!changes.has("modified")) {
+				changes.put("modified", JSONObject.NULL);
+			}
+		}
+    	return attrs;
+    }
+
+    public static void setTextRunAttributes(OperationDocument operationDocument, JSONObject attrs, TextRun_Base textRunComponent)
+        throws FilterException, JAXBException, JSONException, InvalidFormatException, PartUnrecognisedException {
 
     	final P paragraph = (P)textRunComponent.getContextObject();
 
-        if(textRunComponent instanceof Placeholder_Base) {
-            if(textRunComponent instanceof DrawingComponent)
-                Drawings.applyProperties(operationDocument, attrs.optJSONObject("drawing"), (DrawingComponent)textRunComponent);
-            else if(textRunComponent instanceof PictVMLComponent)
-                PictVML.applyProperties(attrs.optJSONObject("drawing"), (PictVMLComponent)textRunComponent);
-        }
-        
         int changeTrackFlags = Component.CT_NONE;
         Object attrsInserted = null;
         Object attrsRemoved  = null;
@@ -300,10 +239,6 @@ public class TextUtils{
         		}
         	}
         }
-        if(changeTrackFlags==Component.CT_NONE&&insertedComponent) {
-        	changeTrackFlags = Component.CT_DELETED | Component.CT_INSERTED;
-        }
-
         final IndexedNode<Object> textRunNode = textRunComponent.getTextRunNode();
         final R textRun = (R)textRunNode.getData();
         RPr rPr = textRun.getRPr();
@@ -335,7 +270,7 @@ public class TextUtils{
             		if(rPrChange==null) {
 	                	rPrChange = Context.getWmlObjectFactory().createCTRPrChange();
 	                	rPrChange.setParent(rPr);
-	                	rPr.setRPrChange(rPrChange);			                	
+	                	rPr.setRPrChange(rPrChange);
             		}
             		org.docx4j.wml.CTRPrChange.RPr rPrC = rPrChange.getRPr();
             		if(rPrC==null) {
@@ -388,18 +323,18 @@ public class TextUtils{
 	                        hyperlinkNode = new IndexedNode<Object>(hyperlink, childNode.getIndex());
 	                        paragraph.getContent().setNode(childNode.getIndex(), hyperlinkNode);
 	                        hyperlink.getContent().addNode(childNode);
-	                        textRunComponent.setHyperlinkNode(hyperlinkNode);
+	                        textRunComponent.insertHyperlink(hyperlinkNode);
 	                        ((Child)childNode.getData()).setParent(hyperlink);
 	                	}
 	                	final P.Hyperlink hyperlink = (P.Hyperlink)hyperlinkNode.getData();
-                        hyperlink.setId(Commons.setUrl(operationDocument.getPackage().getMainDocumentPart(), hyperlink.getId(), (String)url));
+                        hyperlink.setId(Commons.setUrl(operationDocument.getContextPart(), hyperlink.getId(), (String)url));
 	                }
 	                else {
 	                	// removing url
 	                	if(hyperlinkNode!=null) {
 	                		paragraph.getContent().setNode(hyperlinkNode.getIndex(), childNode);
 	                		((Child)childNode.getData()).setParent(paragraph);
-	                		textRunComponent.setHyperlinkNode(null);
+	                		textRunComponent.removeHyperlink();
 	                	}
 	                }
                 }
@@ -420,7 +355,7 @@ public class TextUtils{
             		textRun.setParent(runDel);
             		((IndexedNodeList<Object>)textRunParent.getContent()).setNode(textRunNode.getIndex(), delNode);
             		runDel.getContent().addNode(textRunNode);
-            		textRunComponent.setRunDelNode(delNode);
+            		textRunComponent.insertRunDelNode(delNode);
 
         			// changing text to delText
         			final IndexedNodeList<Object> textRunContent = textRun.getContent();
@@ -448,7 +383,7 @@ public class TextUtils{
 	    		    delTextToText(0, delNode.getData());
 	    		    delNodeParentContent.remove(delNode.getIndex());
 	    		    IndexedNodeList.moveNodes(delNodeContent, delNodeParentContent, 0, delNode.getIndex(), delNodeContent.size(), delNodeParent);
-	    			textRunComponent.setRunDelNode(null);
+	    			textRunComponent.removeRunDelNode();
     			}
     		}
     	}
@@ -469,7 +404,7 @@ public class TextUtils{
             		((Child)newChildNode.getData()).setParent(runIns);
             		((IndexedNodeList<Object>)newParent.getContent()).setNode(newChildNode.getIndex(), insertNode);
             		runIns.getContent().addNode(newChildNode);
-            		textRunComponent.setRunInsNode(insertNode);
+            		textRunComponent.insertRunInsNode(insertNode);
             	}
     			Utils.applyTrackInfoFromJSON(operationDocument, (JSONObject)attrsInserted, (RunIns)insertNode.getData());
     		}
@@ -482,62 +417,9 @@ public class TextUtils{
         			final IndexedNodeList<Object> insertNodeContent = (IndexedNodeList<Object>)((ContentAccessor)insertNode.getData()).getContent();
         			insertNodeParentContent.remove(insertNode.getIndex());
         			IndexedNodeList.moveNodes(insertNodeContent, insertNodeParentContent, 0, insertNode.getIndex(), insertNodeContent.size(), insertNodeParent);
-        			textRunComponent.setRunInsNode(null);
+        			textRunComponent.removeRunInsNode();
     			}
     		}
     	}
     }
- 
-    public static Component getComponentNumber(Component c, int componentNumber) {
-    	while(c!=null&&c.getNextComponentNumber()<=componentNumber) {
-    		c = c.getNextComponent();
-    	}
-    	return c;
-    }
-
-    public static Component getComponent(MainDocumentPart mainDocumentPart, JSONArray position, int positionCount) {
-    	try {
-	    	Component c = new Component.MainDocumentComponent(mainDocumentPart);
-	    	for(int i=0; c!=null&&i<positionCount;i++) {
-		    	c = getComponentNumber(c.getChildComponent(), position.getInt(i));
-	    	}
-	    	return c;
-    	}
-    	catch(JSONException e) {
-    		// ups
-    	}
-		return null;
-    }
-
-    public static boolean insertComponentNumber(Component parent, Component newComponent, int componentNumber) {
-    	final Component c = getComponentNumber(parent.getChildComponent(), componentNumber);
-    	final IndexedNodeList<Object> indexedNodeList = (IndexedNodeList<Object>)((ContentAccessor)parent.getObject()).getContent();
-		((Child)newComponent.getObject()).setParent(parent.getObject());
-		final int index = c!=null&&c.getComponentNumber()==componentNumber?c.getNode().getIndex():indexedNodeList.size();
-		indexedNodeList.add(index, newComponent.getObject());
-		newComponent.setComponentNumber(componentNumber);
-		newComponent.setContextNode(parent.getNode());
-		newComponent.setNode(indexedNodeList.getNode(index));
-		return true;
-    }
-
-    public static boolean insertComponent(MainDocumentPart mainDocumentPart, JSONArray insertPosition, Component newComponent) {
-    	try {
-	    	Component c = new Component.MainDocumentComponent(mainDocumentPart);
-	    	for(int i=0; c!=null&&i<insertPosition.length();) {
-    			final int componentNumber = insertPosition.getInt(i++);
-    			if(i==insertPosition.length()) {
-    				return insertComponentNumber(c, newComponent, componentNumber);
-    			}
-    			else {
-    				c = getComponentNumber(c.getChildComponent(), componentNumber);
-    			}
-	    	}
-	    	return false;
-    	}
-    	catch(JSONException e) {
-    		// ups
-    	}
-    	return true;
-    }
 }
