@@ -8,7 +8,7 @@
  *
  *    In some countries OX, OX Open-Xchange, open xchange and OXtender
  *    as well as the corresponding Logos OX Open-Xchange and OX are registered
- *    trademarks of the Open-Xchange, Inc. group of companies.
+ *    trademarks.
  *    The use of the Logos is not covered by the GNU General Public License.
  *    Instead, you are allowed to use these Logos according to the terms and
  *    conditions of the Creative Commons License, Version 2.5, Attribution,
@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2012 Open-Xchange, Inc.
+ *     Copyright (C) 2016 OX Software GmbH
  *     Mail: info@open-xchange.com
  *
  *
@@ -80,6 +80,7 @@ import org.json.JSONArray;
 import org.json.JSONException;
 import org.json.JSONObject;
 
+import com.openexchange.office.FilterException;
 import com.openexchange.office.ooxml.docx.OperationDocument;
 import com.openexchange.office.ooxml.tools.Commons;
 
@@ -129,7 +130,7 @@ public class Utils {
     }
 
     public static void initBorderColorFromJSONColor(OperationDocument operationDocument, JSONObject jsonColor, CTBorder border)
-        throws JSONException {
+        throws FilterException, JSONException {
 
     	if(border==null||!jsonColor.has("type")) {
     		return;
@@ -142,7 +143,7 @@ public class Utils {
     }
 
     public static void initShdFromJSONColor(OperationDocument operationDocument, JSONObject jsonColor, CTShd shd)
-    	throws JSONException {
+    	throws FilterException, JSONException {
 
     	if(shd==null||!jsonColor.has("type")) {
     		return;
@@ -156,7 +157,7 @@ public class Utils {
     }
 
     public static void initColorFromJSONColor(OperationDocument operationDocument, JSONObject jsonColor, Color color)
-        throws JSONException {
+        throws FilterException, JSONException {
 
     	if(color==null||!jsonColor.has("type")) {
     		return;
@@ -167,9 +168,9 @@ public class Utils {
     	color.setThemeShade(tintShadeTransformation.themeShade);
     	color.setVal(tintShadeTransformation.Color);
     }
-    
+
     private static TintShadeTransformation createTintShadeTransformationFromJSONColor(OperationDocument operationDocument, JSONObject jsonColor)
-    	throws JSONException {
+    	throws FilterException, JSONException {
 
     	final TintShadeTransformation tintShadeTransformation = new TintShadeTransformation();
 
@@ -352,7 +353,7 @@ public class Utils {
         }
         return sectPr;
     }
-    
+
     public static long getPageWidth(MainDocumentPart mainDocPart, long defaultWidth) {
     	final SectPr sectPr = getDocumentProperties(mainDocPart);
     	if(sectPr!=null) {
@@ -401,7 +402,7 @@ public class Utils {
 
     public static JSONObject createJSONFromTrackInfo(com.openexchange.office.ooxml.docx.OperationDocument operationDocument, CTTrackChange changeTrack)
     	throws JSONException {
- 
+
 		final JSONObject trackInfoDesc = new JSONObject(2);
 		final String author = changeTrack.getAuthor();
 		if(author!=null) {
@@ -434,11 +435,11 @@ public class Utils {
 		}
 		return trackInfoDesc;
     }
-    
+
     public static void applyTrackInfoFromJSON(com.openexchange.office.ooxml.docx.OperationDocument operationDocument, JSONObject trackInfo, CTTrackChange changeTrack) {
 
     		final org.docx4j.w15.ObjectFactory peopleObjectFactory = new org.docx4j.w15.ObjectFactory();
-    	
+
         	if(trackInfo!=null) {
             	try {
             		String uidAuthor = changeTrack.getAuthor();
