@@ -8,7 +8,7 @@
  *
  *    In some countries OX, OX Open-Xchange, open xchange and OXtender
  *    as well as the corresponding Logos OX Open-Xchange and OX are registered
- *    trademarks of the Open-Xchange, Inc. group of companies.
+ *    trademarks.
  *    The use of the Logos is not covered by the GNU General Public License.
  *    Instead, you are allowed to use these Logos according to the terms and
  *    conditions of the Creative Commons License, Version 2.5, Attribution,
@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2012 Open-Xchange, Inc.
+ *     Copyright (C) 2016 OX Software GmbH
  *     Mail: info@open-xchange.com
  *
  *
@@ -51,6 +51,8 @@ package com.openexchange.office.ooxml.pptx;
 
 import java.io.InputStream;
 
+import org.docx4j.jaxb.Context;
+
 import com.openexchange.office.DocumentProperties;
 import com.openexchange.office.FilterException;
 import com.openexchange.office.IExporter;
@@ -74,6 +76,7 @@ public class Exporter implements IExporter {
     public Exporter(ServiceLookup _services) {
         super();
         services = _services;
+        Context.getWmlObjectFactory();
     }
 
     /*
@@ -84,13 +87,19 @@ public class Exporter implements IExporter {
     public InputStream createDocument(Session session, InputStream documentStm, String applyOperations, ResourceManager resourceManager, DocumentProperties documentProperties, boolean createFinalDocument)
         throws FilterException {
 
+        OperationDocument operationDocument = null;
     	try {
-	        final OperationDocument operationDocument = new OperationDocument(session, services, documentStm, resourceManager, documentProperties);
+	        operationDocument = new OperationDocument(session, services, documentStm, resourceManager, documentProperties);
 	        operationDocument.setCreateFinalDocument(createFinalDocument);
 	        return operationDocument.createDocument(applyOperations);
     	}
     	catch(Throwable e) {
-    		throw OperationDocument.rethrowException(e);
+    		throw OperationDocument.getRethrowException(e);
     	}
+        finally {
+            if(operationDocument!=null) {
+                operationDocument.removeMemoryListener();
+            }
+        }
     }
 }
