@@ -8,7 +8,7 @@
  *
  *    In some countries OX, OX Open-Xchange, open xchange and OXtender
  *    as well as the corresponding Logos OX Open-Xchange and OX are registered
- *    trademarks of the Open-Xchange, Inc. group of companies.
+ *    trademarks.
  *    The use of the Logos is not covered by the GNU General Public License.
  *    Instead, you are allowed to use these Logos according to the terms and
  *    conditions of the Creative Commons License, Version 2.5, Attribution,
@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2012 Open-Xchange, Inc.
+ *     Copyright (C) 2016 OX Software GmbH
  *     Mail: info@open-xchange.com
  *
  *
@@ -86,76 +86,91 @@ import org.xlsx4j.sml.STHorizontalAlignment;
 import org.xlsx4j.sml.STPatternType;
 import org.xlsx4j.sml.STUnderlineValues;
 import org.xlsx4j.sml.STVerticalAlignment;
+import org.xlsx4j.sml.SheetData;
 import org.xlsx4j.sml.SmlUtils;
 import org.xlsx4j.sml.SmlUtils.CellRef;
 import org.xlsx4j.sml.Worksheet;
 
 import com.openexchange.log.LogFactory;
+import com.openexchange.office.FilterException;
+import com.openexchange.office.ooxml.tools.AttrsMode;
 import com.openexchange.office.ooxml.tools.Commons;
 import com.openexchange.office.ooxml.xlsx.OperationDocument;
-import com.openexchange.office.ooxml.xlsx.operations.ApplyOperationHelper;
-import com.openexchange.office.ooxml.xlsx.tools.Utils;
 
 
 public class CellUtils {
 
     protected static Log log = LogFactory.getLog(CellUtils.class);
 
-    public static void applyCellProperties(OperationDocument operationDocument, WorksheetPart worksheetPart, JSONObject attrs, Cell cell, CTStylesheet stylesheet, Map<Long, Long> styleCache)
-        throws JSONException {
+    public static void applyCellPropertiesToCell(OperationDocument operationDocument, WorksheetPart worksheetPart, SheetData sheetData, JSONObject attrs, AttrsMode attrsMode, Row row, Cell cell, CTStylesheet stylesheet, Map<Long, Long> styleCache)
+        throws FilterException, JSONException {
 
-        if(attrs==null) {
-            cell.setS(0L);
-            removeHyperlink(worksheetPart.getJaxbElement(), new SmlUtils.CellRef(cell.getColumn(), ((Row)cell.getParent()).getRow()));
-            return;
+        if(attrsMode==AttrsMode.REPLACE) {
+            // TODO: removing Hyperlinks needs to get optimized
+            removeHyperlink(worksheetPart.getJaxbElement(), new SmlUtils.CellRef(cell.getColumn(), row.getRow()));
         }
-    	if(styleCache!=null) {
-    		final Long newStyle = styleCache.get(cell.getS());
-    		if(newStyle!=null) {
-    			cell.setS(newStyle);
-    			return;
-    		}
+        final long oldAutoStyle = cell.getStyle();
+        final long newAutoStyle = applyAutoStyle(operationDocument, oldAutoStyle, attrs, attrsMode, stylesheet, styleCache, worksheetPart, row, cell);
+    	if(oldAutoStyle!=newAutoStyle) {
+    	    cell.setS(newAutoStyle);
+            sheetData.applyCachedCellData(cell);
     	}
-        Long newStyleIndex=null;
-        if(attrs.has("styleId")) {
-            final Object styleId = attrs.opt("styleId");
-            if(styleId instanceof String) {
-                final ApplyOperationHelper applyOperationHelper = operationDocument.getApplyOperationHelper();
-                if(applyOperationHelper!=null) {
-                    newStyleIndex = applyOperationHelper.getStyleIndex((String)styleId);
+    }
+
+    public static long applyAutoStyle(OperationDocument operationDocument, long oldAutoStyle, JSONObject attrs, AttrsMode attrsMode, CTStylesheet stylesheet, Map<Long, Long> styleCache, WorksheetPart worksheetPart, Row row, Cell cell)
+        throws FilterException, JSONException {
+
+        Long newAutoStyle = null;
+        if(attrs!=null) {
+            if(styleCache!=null) {
+                newAutoStyle = styleCache.get(oldAutoStyle);
+            }
+            if(newAutoStyle==null) {
+                CTXf detachedXf;
+                if(attrsMode==AttrsMode.REPLACE) {
+                    detachedXf = getDetachedXfFromStyle(stylesheet, operationDocument.getApplyOperationHelper().getStyleIndex(attrs.optString("styleId", null)));
+                }
+                else {
+                    final Long newStyle = attrs.has("styleId")?operationDocument.getApplyOperationHelper().getStyleIndex(attrs.optString("styleId", null)):null;
+                    detachedXf = getDetachedXfFromAutoStyle(stylesheet, oldAutoStyle, newStyle);
+                }
+                final CTXf cellStyleXf = stylesheet.getCellStyleXfsByIndex(detachedXf.getXfId());
+
+                final JSONObject characterProperties = attrs.optJSONObject("character");
+                if (characterProperties!=null) {
+                    applyCharacterProperties(operationDocument, worksheetPart, row, cell, characterProperties, detachedXf, stylesheet, cellStyleXf);
+                }
+                final JSONObject cellProperties = attrs.optJSONObject("cell");
+                if(cellProperties!=null) {
+                    applyCellProperties(operationDocument, cellProperties, detachedXf, stylesheet, cellStyleXf);
+                }
+                long index = stylesheet.getOrApplyCellXf(detachedXf);
+                if(index>=0) {
+                    newAutoStyle = Long.valueOf(index);
+                    if(styleCache!=null) {
+                        styleCache.put(Long.valueOf(oldAutoStyle), newAutoStyle);
+                    }
                 }
             }
+        }
+        else {
+            if(attrsMode==AttrsMode.REPLACE) {
+                newAutoStyle = Long.valueOf(0);
+            }
             else {
-                newStyleIndex = 0L;
+                newAutoStyle = oldAutoStyle;
             }
         }
-        final CTXf detachedXf = getDetachedXf(stylesheet, cell.getS(), newStyleIndex);
-        final CTXf cellStyleXf = stylesheet.getCellStyleXfsByIndex(detachedXf.getXfId());
-
-        JSONObject characterProperties = attrs.optJSONObject("character");
-        if (characterProperties != null) {
-            applyCharacterProperties(operationDocument, worksheetPart, cell, characterProperties, detachedXf, stylesheet, cellStyleXf);
-        }
-        JSONObject cellProperties = attrs.optJSONObject("cell");
-        if(cellProperties!=null) {
-            applyCellProperties(operationDocument, cellProperties, detachedXf, stylesheet, cellStyleXf);
-        }
-        long index = stylesheet.getOrApplyCellXf(detachedXf);
-        if(index>=0) {
-            if(styleCache!=null) {
-            	styleCache.put(cell.getS(), index);
-            }
-            cell.setS(index);
-        }
+        return newAutoStyle!=null?newAutoStyle.longValue():0;
     }
 
     public static JSONObject createCellProperties(Cell cell, CTStylesheet stylesheet)
         throws JSONException {
 
         JSONObject jsonCellProperties = null;
-        if(cell!=null&&cell.getS()>0) {
+        if(cell!=null&&cell.getStyle()>0) {
             jsonCellProperties = new JSONObject();
-            jsonCellProperties.put("styleId", "a" + Long.toString(cell.getS()));
+            jsonCellProperties.put("styleId", "a" + Long.toString(cell.getStyle()));
         }
         return jsonCellProperties!=null&&jsonCellProperties.length()>0 ? jsonCellProperties : null;
     }
@@ -178,11 +193,7 @@ public class CellUtils {
         }
         CTFill ctFill = stylesheet.getFillByIndex(fillId);
         if(ctFill!=null) {
-            ctFill = XmlUtils.deepCopy(ctFill, Context.getJcSML());
-            if(ctFill==null) {
-                throw new RuntimeException("xlsx export: CTFill deepCopy fails");
-            }
-            return ctFill;
+            return ctFill.clone();
         }
         log.warn("xlsx export: could not get CTFill for Id");
         return Context.getsmlObjectFactory().createCTFill();
@@ -207,7 +218,7 @@ public class CellUtils {
     }
 
     private static CTBorderPr applyBorder(OperationDocument operationDocument, JSONObject borderProperties, CTStylesheet stylesheet, CTBorderPr _borderPr)
-        throws JSONException {
+        throws FilterException, JSONException {
 
         CTBorderPr borderPr = _borderPr!=null?_borderPr:Context.getsmlObjectFactory().createCTBorderPr();
 
@@ -327,7 +338,7 @@ public class CellUtils {
     }
 
     public static void applyCellProperties(OperationDocument operationDocument, JSONObject cellProperties, CTXf xf, CTStylesheet stylesheet, CTXf cellStyleXf)
-        throws JSONException {
+        throws FilterException, JSONException {
 
         final ObjectFactory objectFactory = Context.getsmlObjectFactory();
 
@@ -743,8 +754,8 @@ public class CellUtils {
     }
 
     @SuppressWarnings("null")
-    public static void applyCharacterProperties(OperationDocument operationDocument, WorksheetPart worksheetPart, Cell cell, JSONObject characterProperties, CTXf xf, CTStylesheet stylesheet, CTXf cellStyleXf)
-        throws JSONException {
+    public static void applyCharacterProperties(OperationDocument operationDocument, WorksheetPart worksheetPart, Row row, Cell cell, JSONObject characterProperties, CTXf xf, CTStylesheet stylesheet, CTXf cellStyleXf)
+        throws FilterException, JSONException {
 
         final ObjectFactory objectFactory = Context.getsmlObjectFactory();
 
@@ -972,7 +983,7 @@ public class CellUtils {
             else if(attr.equals("url")) {
                 if(worksheetPart!=null&&cell!=null) {
                     Worksheet worksheet = worksheetPart.getJaxbElement();
-                    final SmlUtils.CellRef cellRef = new CellRef(cell.getColumn(), ((Row)cell.getParent()).getRow());
+                    final SmlUtils.CellRef cellRef = new CellRef(cell.getColumn(), row.getRow());
                     removeHyperlink(worksheet, cellRef);
                     CTHyperlinks hyperlinks = worksheet.getHyperlinks();
                     if(value instanceof String) {
@@ -1066,56 +1077,79 @@ public class CellUtils {
         return jsonCharacterProperties.length()>0?jsonCharacterProperties:null;
     }
 
-    public static CTXf getDetachedXf(CTStylesheet stylesheet, long cellXfIndex, Long newStyleIndex) {
+    private static CTXf createDetachedDefaultXf() {
+        final CTXf detachedDefaultXf = Context.getsmlObjectFactory().createCTXf();
+        detachedDefaultXf.setXfId(Long.valueOf(0));
+        detachedDefaultXf.setFillId(Long.valueOf(0));
+        detachedDefaultXf.setFontId(Long.valueOf(0));
+        detachedDefaultXf.setNumFmtId(Long.valueOf(0));
+        detachedDefaultXf.setBorderId(Long.valueOf(0));
+        return detachedDefaultXf;
+    }
+    public static CTXf getDetachedXfFromStyle(CTStylesheet stylesheet, Long styleIndex) {
+
+        CTXf detachedXf = null;
+
+        // we assume that the first style is an empty default style and is containing only
+        // zero indexes, for this case we don't clone and are using the objectFactory
+        if(styleIndex.longValue()>0) {
+            final CTXf cellStyleXfSource = stylesheet.getCellStyleXfsByIndex(styleIndex);
+            if(cellStyleXfSource!=null) {
+                detachedXf = cellStyleXfSource.clone(false);
+                detachedXf.setXfId(styleIndex);
+            }
+        }
+        if(detachedXf==null) {
+            detachedXf = createDetachedDefaultXf();
+        }
+        return detachedXf;
+    }
+
+    public static CTXf getDetachedXfFromAutoStyle(CTStylesheet stylesheet, long cellXfIndex, Long newStyleIndex) {
 
         CTXf detachedXf;
 
         final CTXf xfSource = stylesheet.getCellXfByIndex(cellXfIndex);         // current auto-attributes
         if(newStyleIndex==null) {
-            detachedXf = xfSource==null?Context.getsmlObjectFactory().createCTXf():XmlUtils.deepCopy(xfSource, Context.getJcSML());
+            detachedXf = xfSource==null?createDetachedDefaultXf():xfSource.clone(true);
         }
         else {
             final CTXf cellStyleXfSource = stylesheet.getCellStyleXfsByIndex(newStyleIndex);
             if(cellStyleXfSource==null) {
-                log.warn("xlsx export : applyCellProperties, could not get cellStyleXfsByIndex..!!");
-                detachedXf = Context.getsmlObjectFactory().createCTXf();
+                detachedXf = createDetachedDefaultXf();
             }
             else {
-                detachedXf = XmlUtils.deepCopy(cellStyleXfSource, Context.getJcSML());
+                detachedXf = cellStyleXfSource.clone(true);
+                detachedXf.setXfId(newStyleIndex);
             }
-            detachedXf.setXfId(newStyleIndex);
-            if(xfSource.isApplyBorder()!=null&&xfSource.isApplyBorder().booleanValue()) {
+            if(detachedXf.isApplyBorder()!=null&&!detachedXf.isApplyBorder().booleanValue()) {
                 detachedXf.setApplyBorder(true);
                 detachedXf.setBorderId(xfSource.getBorderId());
             }
-            if(xfSource.isApplyAlignment()!=null&&xfSource.isApplyAlignment().booleanValue()) {
+            if(detachedXf.isApplyAlignment()!=null&&!detachedXf.isApplyAlignment().booleanValue()) {
                 detachedXf.setApplyAlignment(true);
                 final CTCellAlignment cellAlignmentSource = xfSource.getAlignment();
-                detachedXf.setAlignment(cellAlignmentSource==null?null:XmlUtils.deepCopy(cellAlignmentSource, Context.getJcSML()));
+                detachedXf.setAlignment(cellAlignmentSource!=null?cellAlignmentSource.clone():null);
             }
-            if(xfSource.isApplyFill()!=null&&xfSource.isApplyFill().booleanValue()) {
+            if(detachedXf.isApplyFill()!=null&&!detachedXf.isApplyFill().booleanValue()) {
                 detachedXf.setApplyFill(true);
                 detachedXf.setFillId(xfSource.getFillId());
             }
-            if(xfSource.isApplyFont()!=null&&xfSource.isApplyFont().booleanValue()) {
+            if(detachedXf.isApplyFont()!=null&&!detachedXf.isApplyFont().booleanValue()) {
                 detachedXf.setApplyFont(true);
                 detachedXf.setFontId(xfSource.getFontId());
             }
-            if(xfSource.isApplyNumberFormat()!=null&&xfSource.isApplyNumberFormat().booleanValue()) {
+            if(detachedXf.isApplyNumberFormat()!=null&&!detachedXf.isApplyNumberFormat().booleanValue()) {
                 detachedXf.setApplyNumberFormat(true);
                 detachedXf.setNumFmtId(xfSource.getNumFmtId());
             }
-            if(xfSource.isApplyProtection()!=null&&xfSource.isApplyProtection().booleanValue()) {
+            if(detachedXf.isApplyProtection()!=null&&!detachedXf.isApplyProtection().booleanValue()) {
                 detachedXf.setApplyProtection(true);
                 final CTCellProtection cellProtectionSource = xfSource.getProtection();
-                detachedXf.setProtection(cellProtectionSource==null?null:XmlUtils.deepCopy(cellProtectionSource, Context.getJcSML()));
-            }
-            if(xfSource.isPivotButton()) {
-                detachedXf.setPivotButton(true);
-            }
-            if(xfSource.isQuotePrefix()) {
-                detachedXf.setQuotePrefix(true);
+                detachedXf.setProtection(cellProtectionSource!=null?cellProtectionSource.clone():null);
             }
+            detachedXf.setPivotButton(xfSource.isPivotButton());
+            detachedXf.setQuotePrefix(xfSource.isQuotePrefix());
         }
         return detachedXf;
     }
