@@ -8,7 +8,7 @@
  *
  *    In some countries OX, OX Open-Xchange, open xchange and OXtender
  *    as well as the corresponding Logos OX Open-Xchange and OX are registered
- *    trademarks of the Open-Xchange, Inc. group of companies.
+ *    trademarks.
  *    The use of the Logos is not covered by the GNU General Public License.
  *    Instead, you are allowed to use these Logos according to the terms and
  *    conditions of the Creative Commons License, Version 2.5, Attribution,
@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2012 Open-Xchange, Inc.
+ *     Copyright (C) 2016 OX Software GmbH
  *     Mail: info@open-xchange.com
  *
  *
@@ -96,7 +96,7 @@ public class Drawings {
 
     protected static Log log = LogFactory.getLog(Drawings.class);
 
-    public static void createDrawingOperations(JSONArray operationsArray, org.docx4j.openpackaging.parts.DrawingML.Drawing drawingsPart, int sheetIndex)
+    public static void createDrawingOperations(OperationDocument operationDocument, JSONArray operationsArray, org.docx4j.openpackaging.parts.DrawingML.Drawing drawingsPart, int sheetIndex)
         throws Exception {
 
         final org.docx4j.dml.spreadsheetdrawing.CTDrawing drawings = drawingsPart.getJaxbElement();
@@ -162,11 +162,11 @@ public class Drawings {
             else {
                 throw new FilterException("XLSX import: unknown anchor type for drawing.", ErrorCode.CRITICAL_ERROR);
             }
-
+            attrs.put("drawing", drawingProperties);
             final HashMap<String, Object> drawingPropertyMap = DMLGraphic.getDrawingType(drawingsPart, anchor);
             final String drawingType = drawingPropertyMap.containsKey("type") ? (String)drawingPropertyMap.get("type") : "undefined";
             if(drawingType.equals("image")) {
-                DrawingPic.createProperties(drawingProperties, drawingsPart, anchor.getPic());
+                DrawingPic.createProperties(operationDocument, attrs, drawingsPart, anchor.getPic());
             }
             final JSONObject insertDrawingOperation = new JSONObject();
             insertDrawingOperation.put("name", "insertDrawing");
@@ -218,23 +218,18 @@ public class Drawings {
                         }
                     }
                     attrs.put("chart", chartProperties);
-                    DMLHelper.createJsonFromChartShapeProperties(attrs, cs.getSpPr());
+                    DMLHelper.createJsonFromShapeProperties(attrs, cs.getSpPr(), false);
                 }
             }
-            if(drawingProperties.length()>0) {
-                attrs.put("drawing", drawingProperties);
-                insertDrawingOperation.put("attrs", attrs);
-            } else if(attrs.length()>0){
-                insertDrawingOperation.put("attrs", attrs);
-            }
+            insertDrawingOperation.put("attrs", attrs);
             operationsArray.put(insertDrawingOperation);
 
             if(drawingPropertyMap.containsKey("chartObject")) {
                 DMLChartSpace.createChartSpaceOperations(operationsArray, jsonStart, (CTChartSpace)drawingPropertyMap.get("chartObject"));
                 DMLChartSpace.createShapeOperations(attrs, jsonStart, (CTChartSpace)drawingPropertyMap.get("chartObject"));
             }
-            
-            
+
+
         }
         return;
     }
@@ -284,7 +279,7 @@ public class Drawings {
                 nonVisualGraphicProps.setCNvPr(nonVisualDrawingProps);
             }
         }
-        
+
         DMLHelper.applyNonVisualDrawingProperties(drawingProperties, nonVisualDrawingProps);
     }
 
@@ -299,12 +294,13 @@ public class Drawings {
         anchor = applyAnchorAttributes(drawingIndex, drawingPart, drawingProperties);
 
         // we have to create a valid drawing otherwise excel wont open... at least we are creating an default empty rect shape
+        final JSONObject imageAttrs = attrs.optJSONObject("image");
         if(drawingType.equals("image")) {
             String imageUrl = null;
-            if(drawingProperties!=null) {
-                imageUrl = Commons.getImageUrlFromImageData(operationDocument.getResourceManager(), drawingProperties.optString("imageData"), "xl/media/");
+            if(imageAttrs!=null) {
+                imageUrl = Commons.getImageUrlFromImageData(operationDocument.getResourceManager(), imageAttrs.optString("imageData"), "xl/media/");
                 if(imageUrl==null) {
-                    imageUrl = drawingProperties.optString("imageUrl", null);
+                    imageUrl = imageAttrs.optString("imageUrl", null);
                 }
             }
             if(imageUrl!=null) {
