@@ -8,7 +8,7 @@
  *
  *    In some countries OX, OX Open-Xchange, open xchange and OXtender
  *    as well as the corresponding Logos OX Open-Xchange and OX are registered
- *    trademarks of the Open-Xchange, Inc. group of companies.
+ *    trademarks.
  *    The use of the Logos is not covered by the GNU General Public License.
  *    Instead, you are allowed to use these Logos according to the terms and
  *    conditions of the Creative Commons License, Version 2.5, Attribution,
@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2012 Open-Xchange, Inc.
+ *     Copyright (C) 2016 OX Software GmbH
  *     Mail: info@open-xchange.com
  *
  *
@@ -189,7 +189,7 @@ public class ValidationUtils {
     }
 
     private static List<IDataValidations> getDataValidations(OperationDocument operationDocument, int sheetIndex) {
-        return operationDocument.getDataValidations(getWorksheet(operationDocument, sheetIndex));
+        return OperationDocument.getDataValidations(getWorksheet(operationDocument, sheetIndex));
     }
 
     private static IDataValidation getDataValidation(OperationDocument operationDocument, int sheetIndex, int index) {
