@@ -8,7 +8,7 @@
  *
  *    In some countries OX, OX Open-Xchange, open xchange and OXtender
  *    as well as the corresponding Logos OX Open-Xchange and OX are registered
- *    trademarks of the Open-Xchange, Inc. group of companies.
+ *    trademarks.
  *    The use of the Logos is not covered by the GNU General Public License.
  *    Instead, you are allowed to use these Logos according to the terms and
  *    conditions of the Creative Commons License, Version 2.5, Attribution,
@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2012 Open-Xchange, Inc.
+ *     Copyright (C) 2016 OX Software GmbH
  *     Mail: info@open-xchange.com
  *
  *
@@ -64,7 +64,6 @@ import java.util.Arrays;
 import java.util.Comparator;
 import java.util.HashSet;
 import java.util.List;
-import java.util.Map;
 import java.util.Set;
 import java.util.zip.ZipEntry;
 import java.util.zip.ZipInputStream;
@@ -80,13 +79,15 @@ import org.apache.commons.logging.Log;
 import org.docx4j.dml.Theme;
 import org.docx4j.docProps.core.CoreProperties;
 import org.docx4j.docProps.core.dc.elements.SimpleLiteral;
-import org.docx4j.openpackaging.contenttype.ContentTypes;
+import org.docx4j.jaxb.Context;
 import org.docx4j.openpackaging.contenttype.ContentTypeManager.NonPersistContent;
+import org.docx4j.openpackaging.contenttype.ContentTypes;
+import org.docx4j.openpackaging.exceptions.Docx4JException;
 import org.docx4j.openpackaging.exceptions.InvalidFormatException;
 import org.docx4j.openpackaging.io3.Save;
 import org.docx4j.openpackaging.packages.OpcPackage;
 import org.docx4j.openpackaging.parts.DocPropsCorePart;
-import org.docx4j.openpackaging.parts.DocPropsExtendedPart;
+import org.docx4j.openpackaging.parts.Part;
 import org.docx4j.openpackaging.parts.PartName;
 import org.docx4j.openpackaging.parts.ThemePart;
 import org.docx4j.openpackaging.parts.relationships.RelationshipsPart;
@@ -100,14 +101,16 @@ import com.openexchange.office.FilterException;
 import com.openexchange.office.FilterException.ErrorCode;
 import com.openexchange.office.tools.ConfigurationHelper;
 import com.openexchange.office.tools.ResourceManager;
+import com.openexchange.office.tools.memory.MemoryObserver;
+import com.openexchange.office.tools.memory.MemoryObserver.MemoryListener;
 import com.openexchange.server.ServiceLookup;
 import com.openexchange.session.Session;
 
 abstract public class OperationDocument {
-	
+
 	public class ChangeTrackAuthor {
 
-		private String author;
+		private final String author;
 
 		private XMLGregorianCalendar date;
 
@@ -122,19 +125,22 @@ abstract public class OperationDocument {
 				}
 			}
 		}
-		public boolean equals(Object p) {
+		@Override
+        public boolean equals(Object p) {
 		    boolean v = author.compareToIgnoreCase(((ChangeTrackAuthor)p).author) == 0;
 		    if(v) {
 		    	updateDate(((ChangeTrackAuthor)p).date);
 		    }
 		    return v;
 		}
+        @Override
         public int hashCode() {
             return 0;
         }
 	}
 	public static Comparator<ChangeTrackAuthor> ChangeTrackAuthorComparator = new Comparator<ChangeTrackAuthor>() {
-		public int compare(ChangeTrackAuthor a1, ChangeTrackAuthor a2) {
+		@Override
+        public int compare(ChangeTrackAuthor a1, ChangeTrackAuthor a2) {
 
 			if(a1.date==null) {
 				return a2.date==null ? DatatypeConstants.EQUAL : DatatypeConstants.GREATER;
@@ -144,7 +150,7 @@ abstract public class OperationDocument {
 			}
 		}
 	};
-	
+
 
     private final static Log LOG = LogFactory.getLog(OperationDocument.class);
 
@@ -156,6 +162,8 @@ abstract public class OperationDocument {
     protected final boolean             saveDebugOperations;
     private boolean                     createFinalDocument = false;
     private Set<ChangeTrackAuthor> 		changeTrackAuthors = null;
+    protected Part 						contextPart = null;
+    private MemoryListener              memoryListener = null;
 
     static final int DEFAULT_BUFFER_SIZE = 8192;
 
@@ -166,6 +174,47 @@ abstract public class OperationDocument {
         this.resourceManager = resourceManager;
         this.documentProperties = documentProperties;
         saveDebugOperations = Boolean.parseBoolean(ConfigurationHelper.getOfficeConfigurationValue(services, session, "debugoperations", "false"));
+        registerMemoryListener();
+        Context.setLowMemoryAbort(false);
+    };
+
+    public void registerMemoryListener() {
+        MemoryObserver memoryObserver = (MemoryObserver)documentProperties.get(DocumentProperties.PROP_MEMORYOBSERVER);
+        if(memoryObserver!=null) {
+            if(memoryListener==null) {
+                memoryListener = new MemoryListener() {
+                    @Override
+                    public void memoryTresholdExceeded(long usedMemory, long maxMemory) {
+                        notifyLowMemory();
+                    }
+                };
+                memoryObserver.addListener(memoryListener);
+            }
+            if(MemoryObserver.isUsageThresholdExceeded()) {
+                notifyLowMemory();
+            }
+        }
+    }
+
+    public void removeMemoryListener() {
+        if(memoryListener!=null) {
+            MemoryObserver memoryObserver = (MemoryObserver)documentProperties.get(DocumentProperties.PROP_MEMORYOBSERVER);
+            if(memoryObserver!=null) {
+                memoryObserver.removeListener(memoryListener);
+                memoryListener = null;
+            }
+        }
+    }
+
+    private void notifyLowMemory() {
+        LOG.info("OOXML Filter: Low memory notification received");
+        Context.setLowMemoryAbort(true);
+        final OpcPackage opcPackage = getPackage();
+        if(opcPackage!=null) {
+            opcPackage.setSourcePartStore(null);
+            opcPackage.setContentTypeManager(null);
+            setPackage(null);
+        }
     }
 
     public InputStream createDocument(String applyOperations)
@@ -321,7 +370,7 @@ abstract public class OperationDocument {
         		}
         	}
 
-        	// always removing thumbnails when saving 
+        	// always removing thumbnails when saving
         	removePart(getPackage().getRelationshipsPart(), "/docProps/thumbnail.jpeg");
 
         	final Save saver = new Save(getPackage());
@@ -372,7 +421,7 @@ abstract public class OperationDocument {
 
 
         } catch (Throwable e) {
-        	throw rethrowException(e);
+        	throw getRethrowException(e);
         }
     }
 
@@ -398,7 +447,10 @@ abstract public class OperationDocument {
 
     abstract public OpcPackage getPackage();
 
-    abstract public Theme getTheme();
+    abstract public void setPackage(OpcPackage opcPackage);
+
+    abstract public Theme getTheme()
+    	throws FilterException;
 
     public ResourceManager getResourceManager() {
         return resourceManager;
@@ -411,8 +463,11 @@ abstract public class OperationDocument {
     public String getUserLanguage() {
         return documentProperties.optString(DocumentProperties.PROP_USER_LANGUAGE, "");
     }
-    
-    public static FilterException rethrowException(Throwable e) {
+
+    public static FilterException getRethrowException(Throwable e) {
+        if(Context.isLowMemoryAbort()) {
+            return new FilterException("FilterException...", ErrorCode.MEMORY_USAGE_MIN_FREE_HEAP_SPACE_REACHED);
+        }
     	if(e instanceof FilterException) {
     		final FilterException filterException = (FilterException)e;
     		if(filterException.getErrorcode()==ErrorCode.COMPLEXITY_TOO_HIGH) {
@@ -426,12 +481,22 @@ abstract public class OperationDocument {
     	else if (e instanceof OutOfMemoryError) {
     		return new FilterException(e, ErrorCode.MEMORY_USAGE_MIN_FREE_HEAP_SPACE_REACHED);
     	}
+    	else if(e instanceof Docx4JException) {
+            ErrorCode errorCode = ErrorCode.CRITICAL_ERROR;
+            if(e.getCause() instanceof java.security.InvalidKeyException) {
+                errorCode = ErrorCode.WRONG_PASSWORD;
+            }
+            else if(e.getCause() instanceof org.apache.poi.EncryptedDocumentException) {
+                errorCode = ErrorCode.UNSUPPORTED_ENCRYPTION_USED;
+            }
+            return new FilterException(e, errorCode);
+    	}
     	else {
     		LOG.error(e.getMessage(), e);
     		return new FilterException(e, ErrorCode.CRITICAL_ERROR);
     	}
     }
-    
+
     public long getFreeHeapSpace() {
         final MemoryMXBean memoryMXBean = ManagementFactory.getMemoryMXBean();
         final MemoryUsage heapMemoryUsage = memoryMXBean.getHeapMemoryUsage();
@@ -446,7 +511,7 @@ abstract public class OperationDocument {
     	resetCoreProperties();
     	removePart(getPackage().getRelationshipsPart(), "/docProps/app.xml");
 
-    	// removing extendedData 
+    	// removing extendedData
         final List<NonPersistContent> nonPersistContentList = getPackage().getContentTypeManager().getNonPersistContent();
         for(int i=0; i<nonPersistContentList.size(); i++) {
         	final NonPersistContent nonPersistContent = nonPersistContentList.get(i);
@@ -511,22 +576,22 @@ abstract public class OperationDocument {
     	else if(value instanceof JAXBElement<?>) {
     		if(((JAXBElement<?>)value).getDeclaredType().equals("org.docx4j.docProps.core.dc.elements.SimpleLiteral")) {
         		final SimpleLiteral o = (SimpleLiteral)((JAXBElement<?>)value).getValue();
-        		if((((SimpleLiteral)o).getLang()==null||((SimpleLiteral)o).getLang().isEmpty())&&
-            		(((SimpleLiteral)o).getContent().isEmpty())) {
+        		if((o.getLang()==null||o.getLang().isEmpty())&&
+            		(o.getContent().isEmpty())) {
             		return null;
             	}
     		}
     	}
     	return value;
     }
-    
+
     public void addChangeTrackAuthor(String author, XMLGregorianCalendar date) {
     	if(changeTrackAuthors==null) {
     		changeTrackAuthors = new HashSet<OperationDocument.ChangeTrackAuthor>();
     	}
     	changeTrackAuthors.add(new OperationDocument.ChangeTrackAuthor(author, date));
     }
-    
+
     public JSONArray getChangeTrackAuthors() {
     	if(changeTrackAuthors==null||changeTrackAuthors.isEmpty())
     		return null;
@@ -541,6 +606,12 @@ abstract public class OperationDocument {
     	return authors;
     }
 
+    public abstract Part getContextPart();
+
+    public void setContextPart(Part part) {
+    	contextPart = part;
+    }
+
     protected ThemePart getDefaultThemePart(PartName partName) {
 
         final String themeStr =
