@@ -8,7 +8,7 @@
  *
  *    In some countries OX, OX Open-Xchange, open xchange and OXtender
  *    as well as the corresponding Logos OX Open-Xchange and OX are registered
- *    trademarks of the Open-Xchange, Inc. group of companies.
+ *    trademarks.
  *    The use of the Logos is not covered by the GNU General Public License.
  *    Instead, you are allowed to use these Logos according to the terms and
  *    conditions of the Creative Commons License, Version 2.5, Attribution,
@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2012 Open-Xchange, Inc.
+ *     Copyright (C) 2016 OX Software GmbH
  *     Mail: info@open-xchange.com
  *
  *
@@ -152,7 +152,7 @@ final public class DMLChartSpace {
 				final JSONObject insertDrawingOperation = operationsArray.getJSONObject(operationsArray.length() - 1);
 				boolean valueLabel = false;
 				boolean curved = false;
-				
+
 				if (chartSer instanceof CTScatterChart){
 					CTScatterStyle style = ((CTScatterChart) chartSer).getScatterStyle();
 					if (style != null && (style.getVal() == STScatterStyle.SMOOTH || style.getVal() == STScatterStyle.SMOOTH_MARKER)){
@@ -164,7 +164,7 @@ final public class DMLChartSpace {
 						curved = true;
 					}
 				}
-				
+
 				CTDLbls lbl = chartSer.getDLbls();
 				if (lbl != null && lbl.getShowVal() != null && lbl.getShowVal().isVal()) {
 					valueLabel = true;
@@ -279,16 +279,16 @@ final public class DMLChartSpace {
 					if (marker != null && marker.getSymbol() != null) {
 						series.put("marker", marker.getSymbol().getVal().value());
 					}
-					
-					
+
+
 					if (series.length() == 0) {
 						//TODO: log the broken series?
 						continue;
 					}
-					
+
 					final JSONObject attrs = Commons.surroundJSONObject("series", series);
-					DMLHelper.createJsonFromChartShapeProperties(attrs, ser.getSpPr());
-					
+					DMLHelper.createJsonFromShapeProperties(attrs, ser.getSpPr(), false);
+
 					if (series.length() > 0) {
 						final JSONObject insertChartDataSeriesOperation = new JSONObject();
 						insertChartDataSeriesOperation.put("name", "insertChartDataSeries");
@@ -297,7 +297,7 @@ final public class DMLChartSpace {
 						insertChartDataSeriesOperation.put("attrs", attrs);
 						operationsArray.put(insertChartDataSeriesOperation);
 					}
-					
+
 				}
 
 				if (curved || valueLabel || varyColors != null || chartSer instanceof CTPieChart) {
@@ -438,12 +438,12 @@ final public class DMLChartSpace {
 					axes.add(createValAx());
 				}
 				plotArea.getAreaChartOrArea3DChartOrLineChart().set(0, newListSer);
-				
+
 				final CTBoolean smooth = new CTBoolean();
 				smooth.setVal(false);
-				
+
 				newListSer.setVaryColors(oldListSer.getVaryColors());
-				
+
 				for (final ISerContent serContent : oldListSer.getSer()) {
 					final ISerContent newContent;
 					if (serContent.getClass().equals(type)) {
@@ -458,7 +458,7 @@ final public class DMLChartSpace {
 						newContent.setTx(serContent.getTx());
 						newContent.setVal(serContent.getVal());
 						newContent.setDLbls(serContent.getDLbls());
-						
+
 						if (newContent instanceof CTDoughnutChart) {
 							handleStandardDonutChart((CTDoughnutChart) newContent, chartProperties);
 						} else if (newContent instanceof CTPieChart) {
@@ -495,7 +495,7 @@ final public class DMLChartSpace {
 						}else{
 							axes.get(i).setCrossAx(getUnsignedInt(0));
 						}
-						axid.set(i, getUnsignedInt(i));						
+						axid.set(i, getUnsignedInt(i));
 					}
 				}
 			}
@@ -529,13 +529,13 @@ final public class DMLChartSpace {
 			final String stacking = chartProperties.getString("stacking");
 			listSer.setGrouping(stacking);
 		}
-		
+
 		final String stacking = listSer.getStacking();
 		if (listSer instanceof CTBarChart) {
 			handleOverlap((CTBarChart) listSer, stacking);
 		}
-		
-		
+
+
 		if (chartProperties.has("curved")) {
 			if (listSer instanceof CTLineChart || listSer instanceof CTScatterChart) {
 				final CTBoolean smooth = new CTBoolean();
@@ -575,7 +575,7 @@ final public class DMLChartSpace {
 			lbl.setShowPercent(getBoolean(false));
 			lbl.setShowBubbleSize(getBoolean(false));
 			lbl.setShowLeaderLines(getBoolean(false));
-			
+
 			CTShapeProperties spr = lbl.getSpPr();
 			if (spr == null) {
 				spr = new CTShapeProperties();
@@ -584,12 +584,12 @@ final public class DMLChartSpace {
 				final CTLineProperties ln = new CTLineProperties();
 				ln.setNoFill(new CTNoFillProperties());
 				spr.setLn(ln);
-				
+
 				spr.setEffectLst(new CTEffectList());
 			}
-			
-			
-						
+
+
+
 			CTTextBody txPr = lbl.getTxPr();
 			if(txPr==null){
 				txPr = new CTTextBody();
@@ -608,28 +608,28 @@ final public class DMLChartSpace {
 			final CTTextParagraph p = new CTTextParagraph();
 			p.setPPr(prop);
 			paras.add(p);
-			
+
 			listSer.setDLbls(lbl);
-			
+
 			for (final ISerContent serContent : listSer.getSer()) {
 				serContent.setDLbls(lbl);
 			}
 		}
-	
+
 		if (fill != null) {
 			CTShapeProperties spr = plotArea.getSpPr();
 			if(spr==null){
 				spr = new CTShapeProperties();
 				plotArea.setSpPr(spr);
 			}
-			
+
 			final JSONObject fillHolder = new JSONObject();
 			fillHolder.put("fill", fill);
-			DMLHelper.createChartShapePropertiesFromJson(spr, fillHolder);
+			DMLHelper.applyShapePropertiesFromJson(spr, fillHolder);
 			chartSpace.setSpPr(spr);
 			chartSpace.setRoundedCorners(getBoolean(false));
 		}
-		
+
 		if (listSer instanceof CTScatterChart) {
 			handleStandardScatterChart((CTScatterChart) listSer, chartProperties);
 
@@ -659,12 +659,7 @@ final public class DMLChartSpace {
 
 	public static void applyShapeProperties(JSONObject attrs, CTChartSpace chartSpace) throws Exception {
 		final CTPlotArea plotArea = chartSpace.getChart().getPlotArea();
-		CTShapeProperties sp = plotArea.getSpPr();
-		if (sp == null) {
-			sp = new CTShapeProperties();
-			plotArea.setSpPr(sp);
-		}
-		DMLHelper.createChartShapePropertiesFromJson(sp, attrs);
+		plotArea.setSpPr(DMLHelper.applyShapePropertiesFromJson(plotArea.getSpPr(), attrs));
 	}
 
 	public static void createShapeOperations(JSONObject attrs, JSONArray jsonStart, CTChartSpace chartSpace) throws JSONException {
@@ -674,7 +669,7 @@ final public class DMLChartSpace {
 			sp = new CTShapeProperties();
 			plotArea.setSpPr(sp);
 		}
-		DMLHelper.createJsonFromChartShapeProperties(attrs, sp);
+		DMLHelper.createJsonFromShapeProperties(attrs, sp, false);
 	}
 
 	private static void deleteEmptyContentLists(IListSer listSer) {
@@ -753,16 +748,16 @@ final public class DMLChartSpace {
 			serCont.setOrder(getUnsignedInt(i));
 		}
 	}
-	
+
 	public static void setDataSeriesAttributes(CTChartSpace chartSpace, String sheetName, int series, JSONObject attrs) throws JSONException {
 
 		final IListSer listSer = chartSpace.getChart().getPlotArea().getAreaChartOrArea3DChartOrLineChart().get(0);
 		final List<ISerContent> serContentList = listSer.getSer();
 		final ISerContent serContent = serContentList.get(series);
 		setDataseriesAttrs(serContentList, serContent, sheetName, attrs);
-		
+
 	}
-	
+
 	public static void insertChartSpace(CTChartSpace chartSpace, String sheetName, int series, JSONObject attrs) throws JSONException {
 
 		final IListSer listSer = chartSpace.getChart().getPlotArea().getAreaChartOrArea3DChartOrLineChart().get(0);
@@ -770,12 +765,12 @@ final public class DMLChartSpace {
 		final ISerContent serContent = listSer.createSer();
 		serContentList.add(series, serContent);
 		setDataseriesAttrs(serContentList, serContent, sheetName, attrs);
-		
+
 	}
 
 	private static void setDataseriesAttrs(List<ISerContent> serContentList, ISerContent serContent, String sheetName, JSONObject attrs) throws JSONException {
 
-		
+
 
 		if (attrs != null) {
 			final JSONObject attrSeries = attrs.optJSONObject("series");
@@ -808,7 +803,7 @@ final public class DMLChartSpace {
 					}
 				}
 				serContent.setTx(serTx);
-				
+
 				// names
 				final Object names = attrSeries.opt("names");
 				CTAxDataSource cat = serContent.getCat();
@@ -852,7 +847,7 @@ final public class DMLChartSpace {
 					insertSeriesAttribute(sheetName, val, values);
 				}
 				serContent.setVal(val);
-				
+
 
 				// bubbles
 				final Object bubbles = attrSeries.opt("bubbles");
@@ -862,7 +857,7 @@ final public class DMLChartSpace {
 
 					insertSeriesAttribute(sheetName, bub, bubbles);
 				}
-				
+
 				if (serContent instanceof CTScatterSer) {
 					handleStandardScatterSer((CTScatterSer) serContent);
 				}
@@ -920,7 +915,7 @@ final public class DMLChartSpace {
 		 * CTCatAx CTSerAx CTValAx CTDateAx
 		 */
 		final List<IAxisDescription> axList = plotArea.getValAxOrCatAxOrDateAx();
-		
+
 		if (listSer instanceof CTBubbleChart || listSer instanceof CTScatterChart)
 		{
 			axList.add(createValAx(0,1));
@@ -955,7 +950,7 @@ final public class DMLChartSpace {
 		catAx.setSpPr(DMLHelper.getHiddenShapeProperties());
 		return catAx;
 	}
-	
+
 	private static CTValAx createValAx() {
 		return createValAx(1, 0);
 	}
@@ -1050,10 +1045,10 @@ final public class DMLChartSpace {
 			createAxId(listSer.getAxId());
 		}
 		listSer.setGrouping("standard");
-		
+
 		return listSer;
 	}
-	
+
 
 	private static void handleStandardScatterSer(CTScatterSer serContent) {
 		final CTShapeProperties shape = new CTShapeProperties();
@@ -1081,11 +1076,11 @@ final public class DMLChartSpace {
 			handleStandardScatterSer((CTScatterSer) cont);
 		}
 	}
-	
+
 	private static void handleStandardPieChart(CTPieChart pie, JSONObject chartAttrs) {
 		pie.setFirstSliceAng(new CTFirstSliceAng());
 	}
-	
+
 	private static void handleStandardDonutChart(CTDoughnutChart donut, JSONObject chartAttrs) {
 		final CTHoleSize holeSize = new CTHoleSize();
 		holeSize.setVal((short) 60);
@@ -1112,8 +1107,8 @@ final public class DMLChartSpace {
 			barDir = "bar";
 		}
 		listSer.setBarDirection(barDir);
-		
-		
+
+
 		if (listSer instanceof CTBarChart) {
 			String stacking = null;
 			if (chartAttrs != null) {
@@ -1121,7 +1116,7 @@ final public class DMLChartSpace {
 			}
 			handleOverlap((CTBarChart) listSer, stacking);
 		}
-		
+
 		return listSer;
 	}
 
@@ -1239,7 +1234,7 @@ final public class DMLChartSpace {
 		}
 		return dirString + view;
 	}
-	
+
 	public static void setLegendFromAttrs(CTChart chart, JSONObject attrs) throws JSONException {
 		final String pos = attrs.getJSONObject("legend").optString("pos", "off");
 		if (pos.equals("off")) {
@@ -1250,7 +1245,7 @@ final public class DMLChartSpace {
 				legend = new CTLegend();
 				chart.setLegend(legend);
 			}
-			
+
 			CTTextBody txPr = legend.getTxPr();
 			if (txPr == null) {
 				txPr = new CTTextBody();
@@ -1259,10 +1254,10 @@ final public class DMLChartSpace {
 			DMLHelper.handleStandardTypes(txPr);
 
 			DMLHelper.setCharacterFromAttrs(txPr, attrs);
-			
+
 			legend.setOverlay(new CTBoolean());
 			legend.getOverlay().setVal(false);
-			
+
 			CTLegendPos legendPos = legend.getLegendPos();
 			if (legendPos == null) {
 				legendPos = new CTLegendPos();
@@ -1287,7 +1282,7 @@ final public class DMLChartSpace {
 			legendPos.setVal(stpos);
 		}
 	}
-	
+
 	public static JSONObject createJsonFromProperties(CTTextBody props) throws JSONException {
 		JSONObject character = null;
 		if (props != null) {
@@ -1300,10 +1295,11 @@ final public class DMLChartSpace {
 				if (prop != null) {
 					final CTTextCharacterProperties defPr = prop.getDefRPr();
 					if (defPr != null) {
-						
+
 						// color
 						if (defPr.getSolidFill() != null) {
-							character = DMLHelper.createJsonColorFromSolidColorFillProperties(defPr.getSolidFill());
+						    character = new JSONObject();
+							DMLHelper.createJsonColorFromSolidColorFillProperties(character, defPr.getSolidFill());
 						} else if (defPr.getNoFill() != null) {
 							character = new JSONObject();
 							Logger.getAnonymousLogger().warning("CtTextbody has a no fill property, result is set to null");
