@@ -8,7 +8,7 @@
  *
  *    In some countries OX, OX Open-Xchange, open xchange and OXtender
  *    as well as the corresponding Logos OX Open-Xchange and OX are registered
- *    trademarks of the Open-Xchange, Inc. group of companies.
+ *    trademarks.
  *    The use of the Logos is not covered by the GNU General Public License.
  *    Instead, you are allowed to use these Logos according to the terms and
  *    conditions of the Creative Commons License, Version 2.5, Attribution,
@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2012 Open-Xchange, Inc.
+ *     Copyright (C) 2016 OX Software GmbH
  *     Mail: info@open-xchange.com
  *
  *
@@ -82,13 +82,11 @@ abstract public class CreateOperationHelper {
         throws Exception;
 
     public void CreateThemeOperations()
-        throws JSONException {
+        throws FilterException, JSONException {
 
-        Theme theme = getOperationDocument().getTheme();
-        if (theme==null)
-            return;
+    	final Theme theme = getOperationDocument().getTheme();
 
-        String themeName = theme.getName();
+    	String themeName = theme.getName();
         CTColorScheme colorScheme = theme.getThemeElements().getClrScheme();
         final JSONObject themeObject = new JSONObject();
         final JSONObject colorSchemes = new JSONObject();
@@ -120,7 +118,11 @@ abstract public class CreateOperationHelper {
     public void setOperationsArray(JSONArray _operationsArray) {
     	operationsArray = _operationsArray;
     }
-    
+
+    public ThemeFonts getThemeFonts() {
+    	return themeFonts;
+    }
+
     public void addSetDocumentAttributesOperation(JSONObject attrs)
         throws JSONException {
 
