@@ -8,7 +8,7 @@
  *
  *    In some countries OX, OX Open-Xchange, open xchange and OXtender
  *    as well as the corresponding Logos OX Open-Xchange and OX are registered
- *    trademarks of the Open-Xchange, Inc. group of companies.
+ *    trademarks.
  *    The use of the Logos is not covered by the GNU General Public License.
  *    Instead, you are allowed to use these Logos according to the terms and
  *    conditions of the Creative Commons License, Version 2.5, Attribution,
@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2012 Open-Xchange, Inc.
+ *     Copyright (C) 2016 OX Software GmbH
  *     Mail: info@open-xchange.com
  *
  *
@@ -742,9 +742,25 @@ public class OperationHelper {
             writer.append(System.getProperty("line.separator"));
         	writer.append(uid + ":LAUNCHSTART:" + performanceData.optLong("launchStartAbsolute", 0) + ":" + performanceData.optInt("launchStartDuration", 0));
             writer.append(System.getProperty("line.separator"));
-        	writer.append(uid + ":LOADSTART:" + performanceData.optLong("loadStartAbsolute", 0) + ":" + performanceData.optInt("loadStartDuration", 0));
+        	writer.append(uid + ":APPCONSTRUCTED:" + performanceData.optLong("appConstructedAbsolute", 0) + ":" + performanceData.optInt("appConstructedDuration", 0));
             writer.append(System.getProperty("line.separator"));
-        	writer.append(uid + ":LOADEND:" + performanceData.optLong("loadEndAbsolute", 0) + ":" + performanceData.optInt("loadEndDuration", 0));
+        	writer.append(uid + ":GUIPREPARED:" + performanceData.optLong("guiPreparedAbsolute", 0) + ":" + performanceData.optInt("guiPreparedDuration", 0));
+            writer.append(System.getProperty("line.separator"));
+        	writer.append(uid + ":IMPORTHANDLERSTART:" + performanceData.optLong("importHandlerStartAbsolute", 0) + ":" + performanceData.optInt("importHandlerStartDuration", 0));
+            writer.append(System.getProperty("line.separator"));
+        	writer.append(uid + ":CREATENEWDOCSTART:" + performanceData.optLong("createNewDocStartAbsolute", 0) + ":" + performanceData.optInt("createNewDocStartDuration", 0));
+            writer.append(System.getProperty("line.separator"));
+        	writer.append(uid + ":CREATENEWDOCAFTERREQUEST:" + performanceData.optLong("createNewDocAfterRequestAbsolute", 0) + ":" + performanceData.optInt("createNewDocAfterRequestDuration", 0));
+            writer.append(System.getProperty("line.separator"));
+        	writer.append(uid + ":PREVIEWSTART:" + performanceData.optLong("previewStartAbsolute", 0) + ":" + performanceData.optInt("previewStartDuration", 0));
+            writer.append(System.getProperty("line.separator"));
+        	writer.append(uid + ":AFTERLEAVEBUSYEARLY:" + performanceData.optLong("afterLeaveBusyEarlyAbsolute", 0) + ":" + performanceData.optInt("afterLeaveBusyEarlyDuration", 0));
+            writer.append(System.getProperty("line.separator"));
+        	writer.append(uid + ":IMPORTDOCSTART:" + performanceData.optLong("importDocStartAbsolute", 0) + ":" + performanceData.optInt("importDocStartDuration", 0));
+            writer.append(System.getProperty("line.separator"));
+        	writer.append(uid + ":CONNECTSTART:" + performanceData.optLong("connectStartAbsolute", 0) + ":" + performanceData.optInt("connectStartDuration", 0));
+            writer.append(System.getProperty("line.separator"));
+        	writer.append(uid + ":CONNECTEND:" + performanceData.optLong("connectEndAbsolute", 0) + ":" + performanceData.optInt("connectEndDuration", 0));
             writer.append(System.getProperty("line.separator"));
         	writer.append(uid + ":PREPROCESSINGSTART:" + performanceData.optLong("preProcessingStartAbsolute", 0) + ":" + performanceData.optInt("preProcessingStartDuration", 0));
             writer.append(System.getProperty("line.separator"));
@@ -759,8 +775,12 @@ public class OperationHelper {
         	writer.append(uid + ":POSTPROCESSINGEND:" + performanceData.optLong("postProcessingEndAbsolute", 0) + ":" + performanceData.optInt("postProcessingEndDuration", 0));
             writer.append(System.getProperty("line.separator"));
         	writer.append(uid + ":EDITMODE:" + performanceData.optLong("editModeAbsolute", 0) + ":" + performanceData.optInt("editModeDuration", 0));
+            writer.append(System.getProperty("line.separator"));
+        	writer.append(uid + ":DOCUMENTIMPORTED:" + performanceData.optLong("documentImportedAbsolute", 0) + ":" + performanceData.optInt("documentImportedDuration", 0));
             writer.append(System.getProperty("line.separator"));
         	writer.append(uid + ":LEAVEBUSY:" + performanceData.optLong("leaveBusyAbsolute", 0) + ":" + performanceData.optInt("leaveBusyDuration", 0));
+            writer.append(System.getProperty("line.separator"));
+        	writer.append(uid + ":GUIINITIALIZED:" + performanceData.optLong("guiInitializedAbsolute", 0) + ":" + performanceData.optInt("guiInitializedDuration", 0));
             writer.append(System.getProperty("line.separator"));
         	writer.append(uid + ":TRIGGERIMPORTSUCCESS:" + performanceData.optLong("triggerImportSuccessAbsolute", 0) + ":" + performanceData.optInt("triggerImportSuccessDuration", 0));
             writer.append(System.getProperty("line.separator"));
