@@ -47,6 +47,7 @@
 package com.openxchange.office_communication.jms.core.plain;
 
 import java.util.Enumeration;
+import java.util.Map;
 import java.util.UUID;
 import java.util.concurrent.TimeUnit;
 import java.util.concurrent.TimeoutException;
@@ -54,18 +55,22 @@ import java.util.concurrent.TimeoutException;
 import javax.jms.Destination;
 import javax.jms.Message;
 import javax.jms.MessageConsumer;
+import javax.jms.MessageListener;
 import javax.jms.MessageProducer;
 import javax.jms.Queue;
 import javax.jms.Session;
 
 import org.apache.commons.lang3.StringUtils;
 import org.apache.commons.lang3.mutable.MutableBoolean;
-import org.slf4j.Logger;
-import org.slf4j.LoggerFactory;
 
 import com.openxchange.office_communication.jms.core.plain.beans.JMSBeanMapper;
 import com.openxchange.office_communication.jms.core.plain.beans.JMSMessageBean;
 import com.openxchange.office_communication.jms.core.plain.beans.JMSMessageUtils;
+import com.openxchange.office_communication.tools.logging.ELogLevel;
+import com.openxchange.office_communication.tools.logging.v2.LogContext;
+import com.openxchange.office_communication.tools.logging.v2.LogVars;
+import com.openxchange.office_communication.tools.logging.v2.Logger;
+import com.openxchange.office_communication.tools.logging.v2.Slf4JLogger;
 
 //=============================================================================
 /** Base class providing all you need to work with JMS as client.
@@ -112,7 +117,7 @@ import com.openxchange.office_communication.jms.core.plain.beans.JMSMessageUtils
 public class JMSClientBase
 {
     //-------------------------------------------------------------------------
-	public static final Logger LOG = LoggerFactory.getLogger(JMSClientBase.class);
+	private static final Logger LOG = Slf4JLogger.create(JMSClientBase.class);
 	
     //-------------------------------------------------------------------------
 	public static final String QUEUE_TYPE = "simple-client";
@@ -173,39 +178,54 @@ public class JMSClientBase
 	{
 		m_sFullQualifiedRequestQueue = sQueue;
 	}
+
+	//-------------------------------------------------------------------------
+	protected String getResponseQueueName ()
+		throws Exception
+	{
+		final Destination aResponseQueue = mem_ResponseQueue();
+		      String      sResponseQueue = "<unknown>";
+		if (
+			(aResponseQueue !=         null ) &&
+			(aResponseQueue instanceof Queue)
+		   )
+		{
+			sResponseQueue = ((Queue)aResponseQueue).getQueueName();
+		}
+		return sResponseQueue;
+	}
 	
 	//-------------------------------------------------------------------------
 	public synchronized void start ()
 	    throws Exception
 	{
-		LOG.trace ("start ...");
-
-		if (m_aResponseCollectorThread != null)
-		{
-			LOG.trace("... already started");
+		if (m_bRunning == true)
 			return;
-		}
+
 		impl_registerInQueueContext ();
+		
+		impl_listenForResponses ();
 
-		m_aResponseCollectorThread = new Thread (new Runnable ()
-		{
-			@Override
-			public void run()
-			{
-				impl_collectResponses ();
-			}
-		});
-		m_aResponseCollectorThread.start ();
-
-		LOG.trace ("started.");
+//		m_aResponseCollectorThread = new Thread (new Runnable ()
+//		{
+//			@Override
+//			public void run()
+//			{
+//				impl_collectResponses ();
+//			}
+//		});
+//		m_aResponseCollectorThread.start ();
+		
+		m_bRunning = true;
 	}
 
 	//-------------------------------------------------------------------------
 	public synchronized void stop ()
 	    throws Exception
 	{
-		LOG.trace ("stop ...");
-
+		if (m_bRunning == false)
+			return;
+		
 		// tricky :-)
 		// We reset our thread member first ...
 		// but then those instance might die ...
@@ -213,22 +233,14 @@ public class JMSClientBase
 		// will ensure those instance will live till the end of this method .-)
 
 		@SuppressWarnings("unused")
-		Thread aCollectorThreadHold = null;
-
-		synchronized (this)
-		{
-			if (m_aResponseCollectorThread == null)
-				return;
-			
-			aCollectorThreadHold       = m_aResponseCollectorThread;
-			m_aResponseCollectorThread = null;
-		}
+		Thread aCollectorThreadHold = m_aResponseCollectorThread;
+		m_aResponseCollectorThread  = null;
 		
-		synchronized (m_aShutdownSync)
-		{
-			m_aShutdownSync.setValue(true);
-			m_aShutdownSync.wait (); // TODO timeout ?
-		}
+//		synchronized (m_aShutdownSync)
+//		{
+//			m_aShutdownSync.setValue(true);
+//			m_aShutdownSync.wait (); // TODO timeout ?
+//		}
 		
 		if (m_aClientConsumer != null)
 			m_aClientConsumer.close();
@@ -238,8 +250,20 @@ public class JMSClientBase
 		
 		if (m_aSession != null)
 			m_aSession.close();
+		
+		m_bRunning = false;
+	}
 
-		LOG.trace ("stopped.");
+	//-------------------------------------------------------------------------
+	public < T extends JMSMessageBean > void sendAsynchronousNoResponse (final T aRequest)
+	    throws Exception
+	{
+		final MessageProducer aWrite      = mem_ClientProducer ();
+		final Message         aJMSRequest = impl_newMessage    ();
+		final JMSBeanMapper   aBeanMapper = mem_BeanMapper     ();
+		
+		aBeanMapper.mapBeanToMessage(aRequest, aJMSRequest);
+		aWrite.send(aJMSRequest);
 	}
 
 	//-------------------------------------------------------------------------
@@ -247,6 +271,7 @@ public class JMSClientBase
 	public < T extends JMSMessageBean > T requestSynchronous (final T aRequest)
 	    throws Exception
 	{
+		final LogContext                aLog           = LOG.inCategory ("JMS" ,"CLIENT");
 		final Destination               aResponseQueue = mem_ResponseQueue ();
 		final MessageProducer           aWrite         = mem_ClientProducer ();
 		final JMSRequestResponseManager aRRManager     = mem_RequestResponseManager ();
@@ -258,23 +283,40 @@ public class JMSClientBase
 
 		final JMSRequestResponsePair aResponseSync = aRRManager.registerRequest (aJMSRequest);
 		
-		LOG.debug ("client : send request ...");
+		aLog.forLevel   (ELogLevel.E_TRACE )
+		    .withMessage("send request ...")
+		    .withVars   (new LogVars ()
+		   				{
+							@Override
+							public void defineVars(final Map< String, Object > lVars)
+								throws Exception
+							{
+								lVars.put("request", JMSClientBase.toString(aJMSRequest));
+							}
+						})
+		    .log        ();
 		aWrite.send(aJMSRequest);
 
-		LOG.debug ("client : wait for response ...");
 		final boolean bFinished = aResponseSync.await(m_nTimeout, TimeUnit.MILLISECONDS);
 		if ( ! bFinished)
-		{
-			LOG.debug ("client : timeout ...");
-			throw new TimeoutException ("No response in tim. timeout=["+m_nTimeout+"]");
-		}
+			throw new TimeoutException ("No response in time. timeout=["+m_nTimeout+"]");
 		
-		LOG.debug ("client : got response ...");
 		final Message        aJMSResponse = aResponseSync.getResponse ();
-		System.err.println ("##### response : "+aJMSResponse);
 		final JMSMessageBean aResponse    = JMSMessageUtils.emptyBeanFitsToMessage(aJMSResponse);
 		aBeanMapper.mapMessageToBean(aJMSResponse, aResponse);
 
+		aLog.forLevel   (ELogLevel.E_TRACE    )
+		    .withMessage("return response ...")
+		    .withVars   (new LogVars ()
+		   				{
+							@Override
+							public void defineVars(final Map< String, Object > lVars)
+								throws Exception
+							{
+								lVars.put("response", JMSClientBase.toString(aJMSResponse));
+							}
+						})
+		    .log        ();
 		return (T) aResponse;
 	}
 
@@ -288,47 +330,90 @@ public class JMSClientBase
 	}
 	
 	//-------------------------------------------------------------------------
-	private void impl_collectResponses ()
+	private void impl_listenForResponses ()
+		throws Exception
 	{
-		try
+		final LogContext                aLog          = LOG.inCategory ("JMS" ,"CLIENT");
+		final MessageConsumer           aRead         = mem_ClientConsumer ();
+		final JMSRequestResponseManager aRRManager    = mem_RequestResponseManager ();
+		
+		aRead.setMessageListener(new MessageListener ()
 		{
-			LOG.trace ("start ...");
-			
-			final MessageConsumer           aRead      = mem_ClientConsumer ();
-			final JMSRequestResponseManager aRRManager = mem_RequestResponseManager ();
-			
-			while (true)
+			@Override
+			public void onMessage(final Message aJMSResponse)
 			{
-				synchronized (m_aShutdownSync)
+				try
 				{
-					if (m_aShutdownSync.booleanValue() == true)
-					{
-						LOG.trace ("accept shutdown request !");
-						m_aShutdownSync.notifyAll();
-						break;
-					}
+					aLog.forLevel   (ELogLevel.E_TRACE)
+					    .withMessage("got response ...")
+					    .log        ();
+					aRRManager.registerResponseAndNotify(aJMSResponse);
+					aJMSResponse.acknowledge();
+				}
+				catch (Throwable ex)
+				{
+					aLog.forLevel (ELogLevel.E_ERROR)
+					    .withError(ex)
+					    .log      ();
 				}
-
-				LOG.trace ("poll for response ...");
-				final Message aJMSResponse = aRead.receive(200);
-				if (aJMSResponse == null)
-					continue;
-
-				impl_dumpMessage ("RESPONSE : ", aJMSResponse);
-
-				LOG.trace ("notify response ...");
-				aRRManager.registerResponseAndNotify(aJMSResponse);
-				
-				LOG.trace ("ack response ...");
-				aJMSResponse.acknowledge();
 			}
-		}
-		catch (final Throwable ex)
-		{
-			LOG.error (ex.getMessage (), ex);
-			// TODO error handling ?!
-		}
+		});
 	}
+	
+//	//-------------------------------------------------------------------------
+//	private void impl_collectResponses ()
+//	{
+//		final LogContext aLog = LOG.inCategory ("JMS" ,"CLIENT");
+//		try
+//		{
+//			final long                      nPollTimeInMS = 1000;
+//			final MessageConsumer           aRead         = mem_ClientConsumer ();
+//			final JMSRequestResponseManager aRRManager    = mem_RequestResponseManager ();
+//			
+//			while (true)
+//			{
+//				synchronized (m_aShutdownSync)
+//				{
+//					if (m_aShutdownSync.booleanValue() == true)
+//					{
+//						m_aShutdownSync.notifyAll();
+//						break;
+//					}
+//				}
+//
+//				aLog.forLevel   (ELogLevel.E_TRACE       )
+//				    .withMessage("wait for response ..." )
+//				    .setVar     ("timeout", nPollTimeInMS)
+//				    .log        ();
+//
+//				final Message aJMSResponse = aRead.receive(nPollTimeInMS);
+//				if (aJMSResponse == null)
+//				{
+//					aLog.forLevel   (ELogLevel.E_TRACE       )
+//					    .withMessage("no response in time ...")
+//					    .log        ();
+//					continue;
+//				}
+//
+//				aLog.forLevel   (ELogLevel.E_TRACE)
+//				    .withMessage("got rsponse ...")
+//				    .log        ();
+//				aRRManager.registerResponseAndNotify(aJMSResponse);
+//				aJMSResponse.acknowledge();
+//			}
+//		}
+//		catch (final Throwable ex)
+//		{
+//			// TODO better error handling ?!
+//			// This code runs within a worker-thread ...
+//			// throwing away those exception is not an option ...
+//			// find right target to forward error ...
+//			
+//			aLog.forLevel (ELogLevel.E_ERROR)
+//			    .withError(ex)
+//			    .log      ();
+//		}
+//	}
 
 	//-------------------------------------------------------------------------
 	private void impl_registerInQueueContext ()
@@ -351,9 +436,6 @@ public class JMSClientBase
 	    }
 	    else
 	    	throw new UnsupportedOperationException ("No namspace nor any worker ID ... which queue name mode do you want to use ?");
-
-	    LOG.debug ("my consumer ID   = '"+m_sMyConsumerID   +"'");
-	    LOG.debug ("my request queue = '"+m_sMyResponseQueue+"'");
 	}
 	
 	//-------------------------------------------------------------------------
@@ -392,14 +474,10 @@ public class JMSClientBase
 	}
 
 	//-------------------------------------------------------------------------
-	private void impl_dumpMessage (final String  sDesc   ,
-								   final Message aMessage)
+	public static String toString (final Message aMessage)
      	throws Exception
 	{
-		final StringBuffer sDump = new StringBuffer ();
-		
-		sDump.append (sDesc);
-		sDump.append ("\n" );
+		final StringBuffer sString = new StringBuffer ();
 		
 		final Enumeration< ? > lProps = aMessage.getPropertyNames();
 		while (lProps.hasMoreElements())
@@ -407,10 +485,19 @@ public class JMSClientBase
 			final String sProp  = (String) lProps.nextElement();
 			final String sValue = aMessage.getStringProperty(sProp);
 			
-			sDump.append ("'"+sProp+"' = '"+sValue+"'\n");
+			sString.append (sProp+"="+sValue+"\n");
 		}
+
+		sString.append ("JMSMessageID="    +aMessage.getJMSMessageID    ()+"\n");
+		sString.append ("JMSCorrelationID="+aMessage.getJMSCorrelationID()+"\n");
+		sString.append ("JMSType="         +aMessage.getJMSType         ()+"\n");
+		sString.append ("JMSDeliveryMode=" +aMessage.getJMSDeliveryMode ()+"\n");
+		sString.append ("JMSTimestamp="    +aMessage.getJMSTimestamp    ()+"\n");
+		sString.append ("JMSExpiration="   +aMessage.getJMSExpiration   ()+"\n");
+		sString.append ("JMSDestination="  +aMessage.getJMSDestination  ()+"\n");
+		sString.append ("JMSReplyTo="      +aMessage.getJMSReplyTo      ()+"\n");
 		
-		System.out.println (sDump.toString ());
+		return sString.toString ();
 	}
 	
 	//-------------------------------------------------------------------------
@@ -459,7 +546,6 @@ public class JMSClientBase
 			
 			final Session aSession        = mem_Session ();
                           m_aRequestQueue = aSession.createQueue(sRequestQueueAbsolute);
-            LOG.debug ("request queue was defined as '"+sRequestQueueAbsolute+"' / "+m_aRequestQueue+" ...");
 		}
 		return m_aRequestQueue;
 	}
@@ -476,9 +562,8 @@ public class JMSClientBase
 			final Session     aSession               = mem_Session ();
 			final String      sResponseQueueAbsolute = m_aQueueManager.getQueueNameAbsolute(m_sMyResponseQueue);
 			final Destination aResponseQueue         = aSession.createQueue(sResponseQueueAbsolute);
-
+			
 		    m_aResponseQueue = aResponseQueue;
-			LOG.debug ("response queue was defined as '"+sResponseQueueAbsolute+"' ...");
 		}
 		return m_aResponseQueue;
 	}
@@ -523,6 +608,9 @@ public class JMSClientBase
     	return m_aBeanMapper;
     }
    
+    //-------------------------------------------------------------------------
+    private boolean m_bRunning = false;
+    
     //-------------------------------------------------------------------------
 	private String m_sClientID = null;
 	
@@ -571,8 +659,8 @@ public class JMSClientBase
     //-------------------------------------------------------------------------
     private String m_sMyResponseQueue = null;
 
-    //-------------------------------------------------------------------------
-    private MutableBoolean m_aShutdownSync = new MutableBoolean (false);
+//    //-------------------------------------------------------------------------
+//    private MutableBoolean m_aShutdownSync = new MutableBoolean (false);
     
 	//-------------------------------------------------------------------------
     private JMSBeanMapper m_aBeanMapper = null;
